IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfCompanyBrowseByStatus')
	BEGIN
		PRINT 'Dropping Procedure adfCompanyBrowseByStatus'
		DROP  Procedure  adfCompanyBrowseByStatus
	END

GO

PRINT 'Creating Procedure adfCompanyBrowseByStatus'
GO
/******************************************************************************
**		File: 
**		Name: adfCompanyBrowseByStatus
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		29.04.09	SPV				first version
**		6.05.10		KOV				 ApplyVAT
**		15.12.11	PAM				   
*******************************************************************************/
CREATE Procedure adfCompanyBrowseByStatus
	@StateSelector INT,
	@EmployeeID TIdentifier = NULL,
	@ContractSelector INT,
	@CompanyCategorySelector int,
	@CompanyCategoryID TIdentifier
AS
	SET NOCOUNT ON
	SET ARITHABORT ON

	--     
	IF dbo.adfHasAccessRightByName('ManageCompanies') = 0 AND dbo.adfHasAccessRightByName('ViewAllCompanies') = 0
		RETURN 0

	DECLARE @CurrentUserID TIdentifier, @CompanyClass TClass, @UserID TIdentifier
	
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')

	IF @EmployeeID = -1
	BEGIN
		SET @UserID = @CurrentUserID
		SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	END
	
	
	SELECT
		DISTINCT [Company].[ID],
		[Company].[Class],
		[Company].[State],
		[Company].[Flag],
		[Company].[FileAs],
		[Company].[FoundationDate],
		[Company].[LegalName],
		[Company].[KPP],
		[Company].[LegalCode],
		[Company].[BankAccountID],
		[Company].[ExecutiveEmployeeID],
		[Company].[AccountantEmployeeID],
		[Company].[Own],
		[Company].[ManagerEmployeeID],
		[Company].[CompanySizeID],
		[Company].[CompanyTurnoverID],
		[Company].[CompanyStatusID],
		[Company].[Comments],
		[Company].[Created],
		[Company].[CreatedBy],
		[Company].[Modified],
		[Company].[ModifiedBy],
		[Company].[Timestamp],
		[Company].[ApplyVAT],
		[#PhoneType#7] as Phone1,
		[#PhoneType#11] as Phone2,
		(SELECT [Street]  FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Street],
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Street2],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Country],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Country2],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Region],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Region2],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [City],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [City2],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [PostalCode],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [PostalCode2],
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Company].[ID] AND [Email].[BusinessCardClass] = [Company].[Class] AND [Email].[EmailTypeID] = 1) as Email,
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Company].[ID] AND [Email].[BusinessCardClass] = [Company].[Class] AND [Email].[EmailTypeID] = 4) as WebPage,
		CAST((CASE WHEN [UserContact].[BusinessCardID] IS NULL THEN 0 ELSE 1 END) as bit) as [Private],
		[#PhoneType#1],
		[#PhoneType#2],
		[#PhoneType#3],
		[#PhoneType#4],
		[#PhoneType#5],
		[#PhoneType#6],
		[#PhoneType#7],
		[#PhoneType#8],
		[#PhoneType#9],
		[#PhoneType#10],
		[#PhoneType#11]
	FROM
		[Company]
		LEFT OUTER JOIN [vwPhone]
			ON ([Company].[ID] = [vwPhone].[BusinessCardID] AND @CompanyClass = [vwPhone].[BusinessCardClass])
		LEFT OUTER JOIN [adfvwDocumentCategory]
			ON ([Company].[Class] = [adfvwDocumentCategory].[DocumentClass] AND [Company].[ID] = [adfvwDocumentCategory].[DocumentID])
		LEFT OUTER JOIN [UserContact]
			ON ([Company].[ID] = [UserContact].[BusinessCardID] AND [UserContact].[BusinessCardClass] = @CompanyClass AND [UserContact].[UserID] = @CurrentUserID)
	WHERE
		(
			(@StateSelector = 0) OR 
			(@StateSelector != 0 AND [Company].[State] = @StateSelector)
		)		
		AND
			[Company].[State] < 100
		AND
		(
			@ContractSelector = 0 OR
			(@ContractSelector = 1 AND EXISTS(SELECT * FROM Project WHERE [SupplierCompanyID] = [Company].[ID] OR [CustomerCompanyID]=[Company].[ID])) OR
			(@ContractSelector = 2 AND NOT EXISTS(SELECT * FROM Project WHERE [SupplierCompanyID] = [Company].[ID] OR [CustomerCompanyID]=[Company].[ID]))
		)
		AND
		(
			@EmployeeID IS NULL 
			OR
			(@EmployeeID IS NOT NULL AND [Company].[ManagerEmployeeID] = @EmployeeID)
			--(@EmployeeID IS NOT NULL AND [UserContact].[BusinessCardID] IS NOT NULL)
		)
		AND
		(
			@CompanyCategorySelector = 0 OR
			ISNULL([adfvwDocumentCategory].[CategoryID], 0) = ISNULL(@CompanyCategoryID, 0)
		)
	RETURN 0
GO
	
GRANT EXEC ON adfCompanyBrowseByStatus TO PUBLIC
GO
 