IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfSuperTimerSave')
	BEGIN
		PRINT 'Dropping Procedure adfSuperTimerSave'
		DROP  Procedure  adfSuperTimerSave
	END

GO

PRINT 'Creating Procedure adfSuperTimerSave'
GO
/******************************************************************************
**		File: 
**		Name: adfSuperTimerSave
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		15.09.09		SYV			  Billable    ActivityType
**		27.02.13	MAB				  OPENXML
*******************************************************************************/
CREATE Procedure adfSuperTimerSave
	@ID INT OUTPUT,
	@Xml XML
AS
	SET NOCOUNT ON
		
	DECLARE @UserID TIdentifier,
			@EmployeeID TIdentifier,
			@rv Tidentifier
	
	SET @UserID = dbo.adfGetCurrentUserID()
	
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

	BEGIN TRANSACTION

	IF @ID = 0
	BEGIN
		INSERT INTO [SuperTimer] ([State], [Persistent], [DocumentClass], [DocumentID], [BusinessCardClass], [BusinessCardID], 
			[CreatedBy], [FileAs], [Comments], [ActivityTypeID])
		SELECT
			@Xml.value('(/SuperTimer/State)[1]','int'),
			(CASE @Xml.value('(/SuperTimer/Persistent)[1]','varchar(1)') WHEN 'f' THEN 0 ELSE 1 END),
			@Xml.value('(/SuperTimer/DocumentClass)[1]','SMALLINT'),
			@Xml.value('(/SuperTimer/DocumentID)[1]','INT'),
			@Xml.value('(/SuperTimer/BusinessCardClass)[1]','SMALLINT'),
			@Xml.value('(/SuperTimer/BusinessCardID)[1]','INT'),
			@UserID,
			@Xml.value('(/SuperTimer/FileAs)[1]','NVARCHAR(256)'),
			@Xml.value('(/SuperTimer/Comments)[1]','NVARCHAR(max)'),
			@Xml.value('(/SuperTimer/ActivityTypeID)[1]','INT')

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		SET @ID = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN
		
		IF NOT EXISTS(SELECT * FROM [SuperTimer] WHERE [ID] = @ID AND [CreatedBy]= @UserID)
		BEGIN
			ROLLBACK TRANSACTION
			RAISERROR('#InvalidTimerID', 18, -1)
			RETURN 1
		END
		
		UPDATE [SuperTimer]
		SET
			[State] = @Xml.value('(/SuperTimer/State)[1]','int'),
			[Persistent] = (CASE @Xml.value('(/SuperTimer/Persistent)[1]','varchar(1)') 
								WHEN 'f' THEN 
									0 
								ELSE 
									1 
							END),
			[DocumentClass] = @Xml.value('(/SuperTimer/DocumentClass)[1]','SMALLINT'),
			[DocumentID] = @Xml.value('(/SuperTimer/DocumentID)[1]','INT'),
			[BusinessCardClass] = @Xml.value('(/SuperTimer/BusinessCardClass)[1]','SMALLINT'),
			[BusinessCardID] = @Xml.value('(/SuperTimer/BusinessCardID)[1]','INT'),
			[FileAs] = @Xml.value('(/SuperTimer/FileAs)[1]','NVARCHAR(256)'),
			[Comments] = @Xml.value('(/SuperTimer/Comments)[1]','NVARCHAR(max)'),
			[ActivityTypeID] = @Xml.value('(/SuperTimer/ActivityTypeID)[1]','INT')
		WHERE
			[ID] = @ID
					
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
			
		DELETE [SuperTimerHistory] WHERE [SuperTimerID] = @ID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
			
	END

	INSERT INTO [SuperTimerHistory] ([SuperTimerID], [StartTime], [EndTime])
	SELECT
		@ID,
		CONVERT(datetime, T.c.value('Start[1]','varchar(19)'), 126),
		CONVERT(datetime, T.c.value('End[1]','varchar(19)'), 126)
	FROM @XML.nodes('/SuperTimer/Entries/Entry') AS T(c)

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DECLARE @State INT, @VATRate TPercent
	
	SELECT @State = [State] FROM [SuperTimer] WHERE [ID] = @ID
	SET @VATRate = dbo.fnPjm5GetVATRate()
	
	DECLARE @TimeEntry TABLE ([ID] INT)
	
	IF @State = 3 AND EXISTS(SELECT * FROM [SuperTimerHistory] WHERE [SuperTimerID] = @ID)
	BEGIN
		DECLARE @InitialState TState
		SET @InitialState = dbo.adfwfGetInitialState('6719512d-42ee-4848-a57e-f76500e67ee7')
		IF @InitialState IS NULL
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		DECLARE TimerEntries CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
			SELECT
				[SuperTimer].[DocumentClass],
				[SuperTimer].[DocumentID],
				[SuperTimer].[BusinessCardClass],
				[SuperTimer].[BusinessCardID],
				[SuperTimer].[FileAs],
				[SuperTimer].[Comments],
				[SuperTimer].[ActivityTypeID],
				[SuperTimerHistory].[StartTime],
				[SuperTimerHistory].[EndTime]
			FROM
				[SuperTimer] INNER JOIN [SuperTimerHistory]
					ON ([SuperTimer].[ID] = [SuperTimerHistory].[SuperTimerID])
			WHERE	
				[SuperTimer].[ID] = @ID
		OPEN TimerEntries

		DECLARE @DocumentClass TClass, @DocumentID TIdentifier, @StartTime TDateTime, @EndTime TDateTime,
			@Duration TCount, @TimeEntryClass TClass, @ProjectClass TClass, @TaskClass TClass, 
			@TaskRequestClass TClass, @IssueClass TClass, @ServiceRequestClass TClass, @ServiceAssignmentClass TCLass,
			@BusinessCardClass TClass, @BusinessCardID TIdentifier, @FileAs TName, @Comments TNotes,
			@ActivityTypeID TIdentifier, @IsTimeEntryType bit
		
		SELECT 
			@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry'),
			@ProjectClass = dbo.adfGetClassByName('Pjm5.Project'),
			@TaskClass = dbo.adfGetClassByName('Pjm5.Task'),
			@TaskRequestClass = dbo.adfGetClassByName('Pjm5.TaskRequest'),
			@IssueClass = dbo.adfGetClassByName('Pjm5.Issue'),
			@ServiceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest'),
			@ServiceAssignmentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
		
		FETCH NEXT FROM TimerEntries INTO @DocumentClass, @DocumentID, @BusinessCardClass, @BusinessCardID, 
			@FileAs, @Comments, @ActivityTypeID, @StartTime, @EndTime
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @Duration = DATEDIFF(minute, @StartTime, @EndTime)
			DECLARE @ProjectID TIdentifier, @TaskID TIdentifier, @AssignmentID TIdentifier, @Rate TMoney,
				@CurrencyCode TCode3, @RoundedDuration TCount, @Billable TBool

			IF @FileAs IS NULL OR @FileAs = ''
			BEGIN
				SELECT
					@FileAs = [FileAs]
				FROM
					[Document]
				WHERE
					[Document].[Class] = @DocumentClass AND [Document].[ID] = @DocumentID
			END
				
			SET @ProjectID = dbo.fnPjm5GetDocumentProject(@DocumentClass, @DocumentID)				
			IF @DocumentClass = @TaskClass
				SET @TaskID = @DocumentID
			ELSE
				SET @TaskID = NULL
			
			IF @DocumentClass IN (@TaskRequestClass, @IssueClass, @ServiceRequestClass, @ServiceAssignmentClass)
				SET @IsTimeEntryType = 1
			ELSE
				SET @IsTimeEntryType = 0
				
			IF @ProjectID IS NOT NULL
			BEGIN
				SET @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @EmployeeID)
				SET @Rate = dbo.fnPjm5GetEmployeeRate(@EmployeeID, @ProjectID, 0, null, 0)
				SELECT @CurrencyCode = [CurrencyCode] FROM [Project] WHERE [ID] = @ProjectID
				SELECT
					@RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, [RoundingInterval], [RoundingMode])
				FROM
					[Project]
				WHERE
					[ID] = @ProjectID
				IF @ActivityTypeID IS NULL
				BEGIN
					DECLARE @var sql_variant, @ActivityTypeIsMandatory bit
					
					EXEC adfParameterGet 'ActivityTypeIsMandatory', 'Pjm5', @var OUTPUT
					IF @var IS NULL
						SET @ActivityTypeIsMandatory = 1
					ELSE
						SET @ActivityTypeIsMandatory = CAST(@var as BIT)
					IF @ActivityTypeIsMandatory = 1
					BEGIN
						SET @ActivityTypeID = dbo.fnPjm5GetDefaultActivity(@ProjectID, @EmployeeID)
					END
				END
				SELECT 
					@Billable=[Billable]
				FROM
					[Project]
				WHERE
					[ID]=@ProjectID
				IF @ActivityTypeID IS NOT NULL
				BEGIN
					SELECT 
						@Billable=[Billable]
					FROM
						[ProjectActivityType]				
					WHERE
						[ProjectID]=@ProjectID AND
						[ActivityTypeID]=@ActivityTypeID
				END
			END
			ELSE
			BEGIN
				SET @AssignmentID = NULL
				SET @Rate = 0
				SET @CurrencyCode = 'RUB'
				SET @RoundedDuration = @Duration
				SET @Billable = 0
			END

			DECLARE @Lang TLanguage
			SET @Lang = dbo.adfGetLanguage()
			
			IF @FileAs IS NULL OR @FileAs = ''
			BEGIN
				IF @Lang = 'ru'
					SET @FileAs = '( )'
				ELSE
					SET @FileAs = '(no subject)'
			END
/************************************************************Project CHECK***************************************************/
			IF NOT EXISTS(	SELECT *
							FROM 
								[vwAssignment]
							WHERE 
								[ProjectID] = @ProjectID AND [EmployeeID] = @EmployeeID AND [State] = 1)
			BEGIN
				SET @ProjectID = NULL
				SET @DocumentID = NULL
				SET @TaskID = NULL
			END

			IF NOT EXISTS(	SELECT *
							FROM 
								[Project]
							WHERE 
								[ID] = @ProjectID AND [State] = 2)
			BEGIN
				SET @ProjectID = NULL
				SET @DocumentID = NULL
				SET @TaskID = NULL
			END
/**************************************************************Task Check****************************************************/
			IF (@DocumentClass = @TaskClass) 
			BEGIN
				IF NOT EXISTS(	SELECT * 
								FROM 
									[TaskAssignment] as [T] 
									INNER JOIN [vwAssignment] as [A] ON ([T].[AssignmentID] = [A].[ID]) 
								WHERE [T].[TaskID] = @TaskID AND [A].[EmployeeID] = @EmployeeID AND [T].[State] = 1)
					SET @TaskID = NULL
				IF NOT EXISTS(	SELECT * 
								FROM
									[Task]
								WHERE [State] in (2) AND [ID] = @TaskID)
					SET @TaskID = NULL
			END
/**************************************************************TaskRequest Check*********************************************/
			IF (@DocumentClass = @TaskRequestClass) 
			BEGIN
				IF NOT EXISTS(	SELECT * 
								FROM
									[TaskRequest]
								WHERE [State] in (2) AND [ID] = @DocumentID)
					SET @DocumentID = NULL
			END
/**************************************************************Issue Check***************************************************/
			IF (@DocumentClass = @IssueClass) 
			BEGIN
				IF NOT EXISTS(	SELECT * 
								FROM
									[Issue]
								WHERE [State] in (2,3,4,6) AND [ID] = @DocumentID)
					SET @DocumentID = NULL
			END
/**************************************************************Service Request Check*****************************************/
			IF (@DocumentClass = @ServiceRequestClass) 
			BEGIN
				IF NOT EXISTS(	SELECT * 
								FROM
									[ServiceRequest]
								WHERE [State] in (2,3) AND [ID] = @DocumentID)
					SET @DocumentID = NULL
			END
/**************************************************************Service Assignment Check**************************************/
			IF (@DocumentClass = @ServiceAssignmentClass) 
			BEGIN
				IF NOT EXISTS(	SELECT * 
								FROM
									[ServiceAssignment]
								WHERE [State] in (1) AND [ID] = @DocumentID)
					SET @DocumentID = NULL
			END			
/****************************************************************************************************************************/	
			INSERT INTO [TimeEntry]
				([Flag], [State], [FileAs], [ActivityTypeID], [EmployeeID], [AssignmentID], [ProjectID], [DocumentClass], [DocumentID], [TaskID], 
				[StartTime], [Duration], [RoundedDuration], [Billable], 
				[Overtime], [Rate], [CurrencyCode], [VATRate], 
				[Comments], [SuperTimerID])
			VALUES
				(0, @InitialState, @FileAs, @ActivityTypeID, @EmployeeID, @AssignmentID, @ProjectID,
				CASE @IsTimeEntryType WHEN 1 THEN @DocumentClass ELSE NULL END,
				CASE @IsTimeEntryType WHEN 1 THEN @DocumentID ELSE NULL END,
				@TaskID,
				@StartTime, @Duration, @RoundedDuration, @Billable,
				0, ISNULL(@Rate, 0), @CurrencyCode, @VATRate, @Comments, @ID)
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
						
			DECLARE @TimeEntryID TIdentifier
			
			SET @TimeEntryID = SCOPE_IDENTITY()
			
			INSERT INTO @TimeEntry VALUES(@TimeEntryID)
			
			BEGIN TRY
				EXEC pjm5TimeEntryAutoApprove @TimeEntryID
			END TRY
			BEGIN CATCH
			END CATCH;
			
			/*EXEC @rv = pjm6TaskAssignmentRemainingUpdate @TimeEntryID
			IF @rv = 1
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END*/
			
			IF (@DocumentClass IS NOT NULL AND 	@DocumentClass NOT IN (@ProjectClass, @TaskClass) AND @IsTimeEntryType = 0)
			BEGIN				
				INSERT INTO [Attachment] 
					([DocumentClass], [DocumentID], [AttachmentTypeID], [Name],
					[LinkDocumentClass], [LinkDocumentID])
				SELECT
					@TimeEntryClass, 
					@TimeEntryID, 
					2, 
					[FileAs],
					[Class],
					[ID]
				FROM
					[Document]
				WHERE
					[Class] = @DocumentClass AND [ID] = @DocumentID
				IF @@ERROR != 0
				BEGIN
					ROLLBACK TRANSACTION
					RETURN 1
				END
			END			
			IF @BusinessCardClass IS NOT NULL
			BEGIN
				INSERT INTO [DocumentContact]
					([DocumentClass], [DocumentID], [BusinessCardClass], [BusinessCardID])
				VALUES
					(@TimeEntryClass, @TimeEntryID, @BusinessCardClass, @BusinessCardID)
				IF @@ERROR != 0
				BEGIN
					ROLLBACK TRANSACTION
					RETURN 1
				END
			END
			FETCH NEXT FROM TimerEntries INTO @DocumentClass, @DocumentID, @BusinessCardClass, @BusinessCardID, 
				@FileAs, @Comments, @ActivityTypeID, @StartTime, @EndTime
		END
		CLOSE TimerEntries
		DEALLOCATE TimerEntries
	END

	SELECT 
		[TimeEntry].[ID], 
		[TimeEntry].[Class],
		[TimeEntry].[State],
		[TimeEntry].[FileAs]
	FROM 
		@TimeEntry as [T] INNER JOIN [TimeEntry]
			ON ([T].[ID] = [TimeEntry].[ID])
	
	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXEC ON adfSuperTimerSave TO PUBLIC
GO
