IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfSecurityPatch')
	BEGIN
		PRINT 'Dropping Procedure adfSecurityPatch'
		DROP  Procedure  adfSecurityPatch
	END

GO

PRINT 'Creating Procedure adfSecurityPatch'
GO
/******************************************************************************
**		File: 
**		Name: adfSecurityPatch
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		11.03.13	SOV				 OpenXml  Xml 
*******************************************************************************/
CREATE Procedure adfSecurityPatch
	@Xml XML
AS
	SET NOCOUNT ON
	SET QUOTED_IDENTIFIER ON

	DECLARE @NotUsedRight int
	SELECT @NotUsedRight = [ID] FROM [Right] WHERE [Name] = 'NotUsed'
	
	UPDATE
		[TransitionTemplate]
	SET
		[RightID] = @NotUsedRight
	FROM
		[TransitionTemplate]
	WHERE
		NOT EXISTS (
			SELECT 
				[XmlTable].value('Guid[1]', 'uniqueidentifier'),
				[XmlTable].value('State[1]', 'INT')
			FROM
				@Xml.nodes('/SecurityDataSet/State') AS List(XmlTable)
				INNER JOIN [Class] 
					ON [Class].[Guid] = [XmlTable].value('Guid[1]', 'uniqueidentifier')
			WHERE
				[Class].[Class] = [TransitionTemplate].[Class] AND
				(
					[XmlTable].value('State[1]', 'INT') = [TransitionTemplate].[FromState] OR
					[XmlTable].value('State[1]', 'INT') = [TransitionTemplate].[ToState]
				)
			)
	IF @@error != 0
		RETURN 1

	UPDATE
		[TransitionTemplate]
	SET
		[RightID] = @NotUsedRight
	FROM
		[TransitionTemplate]
	WHERE
		NOT EXISTS (
			SELECT 
				[XmlTable].value('Guid[1]', 'uniqueidentifier'),
				[XmlTable].value('FromState[1]', 'INT'),
				[XmlTable].value('ToState[1]', 'INT')
			FROM
				@Xml.nodes('/SecurityDataSet/TransitionTemplate') AS List(XmlTable)
				INNER JOIN [Class] 
					ON [Class].[Guid] =  [XmlTable].value('Guid[1]', 'uniqueidentifier')
			WHERE
				[Class].[Class] = [TransitionTemplate].[Class] AND
				ISNULL([XmlTable].value('FromState[1]', 'INT'), -1) = ISNULL([TransitionTemplate].[FromState], -1) AND
				ISNULL([XmlTable].value('ToState[1]', 'INT'), -1) = ISNULL([TransitionTemplate].[ToState], -1)
			)
	IF @@error != 0
		RETURN 1

	RETURN 0
GO

 