﻿IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfUserDeleteByID')
	BEGIN
		PRINT 'Dropping Procedure adfUserDeleteByID'
		DROP  Procedure  adfUserDeleteByID
	END

GO

PRINT 'Creating Procedure adfUserDeleteByID'
GO
/******************************************************************************
**		File: adfUserDeleteByID.sql
**		Name: adfUserDeleteByID
**		Desc: Процедура удаляет учетную запись для указанного UserID
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: anton.paramonov
**		Date: 16.03.2012	
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfUserDeleteByID
	@UserID TSysname,
	@CheckRight	TBool = 1
AS
	SET NOCOUNT ON
	DECLARE 
		@result INT,
		@ErrorMessage TName
	
	IF @CheckRight = 1
	BEGIN
		EXEC @result = adfAccessRightCheck 'ManageUsers'
		IF @result != 0
			RETURN @result
	END

	-- Если существуют важные объекты системы, то не удалять учетные данные
	IF EXISTS(SELECT *FROM [Attachment] WHERE [CreatedBy] = @UserID)
		RETURN 0
	IF EXISTS(SELECT *FROM [DocumentItem] WHERE [CheckedOutBy] = @UserID)
		RETURN 0
	IF EXISTS(SELECT *FROM [DocumentItemReadProtocol] WHERE [UserID] = @UserID)
		RETURN 0	
	IF EXISTS(SELECT *FROM [DocumentUserState] WHERE [UserID] = @UserID)
		RETURN 0
	IF EXISTS(SELECT *FROM [DocumentVersion] WHERE [CreatedBy] = @UserID)
		RETURN 0
	IF EXISTS(SELECT *FROM [Note] WHERE [CreatedBy] = @UserID)
		RETURN 0
	IF EXISTS(SELECT *FROM [Transition] WHERE [UserID] = @UserID)
		RETURN 0

	BEGIN TRANSACTION

	UPDATE [Employee]
	SET
		[UserID] = NULL
	WHERE
		[UserID] = @UserID

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE FROM [CalendarEmployee] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [CalendarProject] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [CalendarResource] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [ExchangeAttributesForSync] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [ExchangeDocumentSync] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [ExchangeSync] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [IssueProject] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	--DELETE FROM [Presence] WHERE [ID] = @UserID
	--IF @@ERROR != 0
	--BEGIN
	--	ROLLBACK TRANSACTION
	--	RETURN 1
	--END

	DELETE FROM [ReminderSetting] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [UserReminder] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE FROM [SearchFolder] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE FROM [Sticker] WHERE [RecipientUserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [SubscriptionRule] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	--DELETE FROM [SuperTimer] WHERE [CreatedBy] = @UserID
	--IF @@ERROR != 0
	--BEGIN
	--	ROLLBACK TRANSACTION
	--	RETURN 1
	--END

	DELETE FROM [UserContact] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [UserFavoriteFolder] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [UserNTLoginMapping] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE FROM [UserParameter] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE FROM [UserRole] WHERE [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE [Trustee] WHERE [Trustee].[ID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
		
	COMMIT TRANSACTION
	RETURN 0
GO

GRANT EXEC ON adfUserDeleteByID TO PUBLIC
GO


