IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfwfDocumentDeleteInternal')
	BEGIN
		PRINT 'Dropping Procedure adfwfDocumentDeleteInternal'
		DROP  Procedure  adfwfDocumentDeleteInternal
	END

GO

PRINT 'Creating Procedure adfwfDocumentDeleteInternal'
GO
/******************************************************************************
**		File: 
**		Name: adfwfDocumentDeleteInternal
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfwfDocumentDeleteInternal
	@DocumentID TIdentifier,
	@TransitionTemplateID TIdentifier
AS
	DECLARE @Class TClass,
			@FromState TState,
			@Right TSysname,
			@SPValidate TSysname,
			@SPBefore TSysname,
			@SPAfter TSysname,
			@result INT,
			@rows INT

	SET NOCOUNT ON

	SELECT
		@Class = [TransitionTemplate].[Class],
		@FromState = [TransitionTemplate].[FromState],
		@Right = [Right].[Name],
		@SPValidate = [TransitionTemplate].[SPValidate],
		@SPBefore = [TransitionTemplate].[SPBefore],
		@SPAfter = [TransitionTemplate].[SPAfter]
	FROM
		[TransitionTemplate] INNER JOIN [Right]
			ON ([TransitionTemplate].[RightID] = [Right].[ID])
	WHERE
		[TransitionTemplate].[ID] = @TransitionTemplateID
	AND
		[TransitionTemplate].[ToState] IS NULL
		
	EXEC @result = dbo.adfAccessRightCheck @Right
	IF @result != 0
		RETURN @result

	IF @SPValidate IS NOT NULL
	BEGIN
		EXEC @result = adfwfRunProcedure @SPValidate, @DocumentID, @TransitionTemplateID
		IF @result != 0
		BEGIN
			RETURN @result
		END
	END
	
	IF @SPBefore IS NOT NULL
	BEGIN
		EXEC @result = adfwfRunProcedure @SPBefore, @DocumentID, @TransitionTemplateID
		IF @result != 0
		BEGIN
			RETURN @result
		END
	END

	IF EXISTS(SELECT * FROM [DimensionClass] WHERE [DimensionClass].[Class] = @Class)
		DELETE
			[Dimension]
		WHERE
			[Dimension].[Class] = @Class AND [Dimension].[ID] = @DocumentID
		AND
			[Dimension].[State] = @FromState
	ELSE
		DELETE
			[Document]
		WHERE
			[Document].[Class] = @Class AND [Document].[ID] = @DocumentID
		AND
			[Document].[State] = @FromState
		
	SELECT @result = @@error, @rows = @@rowcount
	
	IF @result != 0 
	BEGIN
		RETURN @result
	END
		
	IF @rows = 0
	BEGIN
		RAISERROR('#InvalidDocumentOrState', 18, -1)
		RETURN 1
	END
	
	IF @SPAfter IS NOT NULL
	BEGIN
		EXEC @result = adfwfRunProcedure @SPAfter, @DocumentID, @TransitionTemplateID
		IF @result != 0
		BEGIN
			RETURN @result
		END
	END

	RETURN 0
GO
