﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[TimeEntryGet]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure TimeEntryGet'
	drop procedure [exch].[TimeEntryGet]
end
go

print 'Creating procedure TimeEntryGet'
go

create procedure [exch].[TimeEntryGet] @UserID TIdentifier, @ID TIdentifier
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	with [TimeEntry] ([Class], [ID], [State], [FileAs], [Comments], [StartTime], [EndTime], [Duration], [RowVersion], [Created], [Modified]) as
	(
		select
			[T].[Class],
			[T].[ID],
			[T].[State],
			[T].[FileAs],
			[T].[Comments],
			[T].[StartTime],
			dateadd(minute, [T].[Duration], [T].[StartTime]) as [EndTime],
			[T].[Duration],
			cast([T].[Timestamp] as bigint) as [RowVersion],
			[T].[Created],
			[T].[Modified]
		from	
			[dbo].[TimeEntry] as [T]
		where
			[T].[ID] = @ID
	),
	[Reminder] ([ID], [EventTime], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			min([R].[EventTime]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[TimeEntry] as [T] inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [T].[Class] and [R].[DocumentID] = [T].[ID] and [T].[ID] = @ID)
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[UR].[State] = 1
		and
			[R].[EventTime] > getdate()
		group by
			[R].[DocumentID]
	)
	select
		1							as [Tag],
		0							as [Parent],
		[TimeEntry].[ID]			as [TimeEntry!1!ID],
		[TimeEntry].[State]			as [TimeEntry!1!State],
		[TimeEntry].[FileAs]		as [TimeEntry!1!FileAs],
		[TimeEntry].[StartTime]		as [TimeEntry!1!Start],
		[TimeEntry].[EndTime]		as [TimeEntry!1!End],
		[R].[EventTime]				as [TimeEntry!1!Reminder],
		[TimeEntry].[Comments]		as [TimeEntry!1!Comments],
		[TimeEntry].[Created]		as [TimeEntry!1!Created],
		[TimeEntry].[Modified]		as [TimeEntry!1!Modified],
		(case when [TimeEntry].[RowVersion] > isnull([R].[RowVersion], 0) then [TimeEntry].[RowVersion] else [R].[RowVersion] end)
									as [TimeEntry!1!RowVersion],
		[L].[ExchangeID]			as [TimeEntry!1!ExchangeID],
		[L].[SyncTime]				as [TimeEntry!1!SyncTime]
	from	
		[TimeEntry] left outer join [exch].[ExchangeLink] as [L]
			on ([TimeEntry].[Class] = [L].[DocumentClass] and [TimeEntry].[ID] = [L].[DocumentID] and [L].[UserID] = @UserID)
		left outer join [Reminder] as [R]
			on ([TimeEntry].[ID] = [R].[ID])
	for xml explicit;

	
	return 0;
end

go
