IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetRevenuePaid]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetRevenuePaid'
		DROP FUNCTION [dbo].[fnReportGetRevenuePaid]
	END
GO

PRINT 'Creating function fnReportGetRevenuePaid'
GO

/******************************************************************************
**		File: fnReportGetRevenuePaid.sql
**		Name: fnReportGetRevenuePaid
**
**              
**		Return values: 
**		    :
**		-ID 
**		-     ,  ,     
**			          
**		-  ,   ,            
**			   			
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 23/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2010	MAN				First Version
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetRevenuePaid
(
	@ProjectXML			XML,
	@PeriodStart		TDateTime,
	@PeriodEnd			TDateTime,
	@CurrencyCode		TCode3
)
RETURNS  @Result TABLE 
(
	ProjectID	Tidentifier,
	Value		TMoney
)
AS
BEGIN
DECLARE
		@CalculationClass TClass,
		@StatementClass TClass,
		@InvoiceClass TClass,
		@TimeEntryClass TClass,
		@ExpenseClass TClass,
		@ApprovedState TState
		
	SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET	@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	
	DECLARE @TimeInFinance TABLE
	(
		DocumentID			TIdentifier,
		LinkClass			TClass,
		LinkDocumentID		TIdentifier,
		State				TState,
		Date				TDateTime,
		ThroughCalculation	TFlag
	)
	INSERT INTO @TimeInFinance(DocumentID,LinkClass,LinkDocumentID,State,Date,ThroughCalculation )
	SELECT [DocumentID],[LinkClass],[LinkDocumentID],[State],[Date],[ThroughCalculation]
	FROM fnReportGetDocumentInFinance(@TimeEntryClass,@PeriodStart, @PeriodEnd,	@ProjectXML)
	
	DECLARE @ExpenseInFinance TABLE
	(
		DocumentID			TIdentifier,
		LinkClass			TClass,
		LinkDocumentID		TIdentifier,
		State				TState,
		Date				TDateTime,
		ThroughCalculation	TFlag
	)
	INSERT INTO @ExpenseInFinance(DocumentID,LinkClass,LinkDocumentID,State,Date,ThroughCalculation )
	SELECT [DocumentID],[LinkClass],[LinkDocumentID],[State],[Date],[ThroughCalculation]
	FROM fnReportGetDocumentInFinance(@ExpenseClass,@PeriodStart, @PeriodEnd,	@ProjectXML)
	
	INSERT INTO @Result
	(
		ProjectID	
	)
	SELECT
		ROW.value('@ProjectID','TIdentifier') AS [ProjectID]
	FROM
		@ProjectXML.nodes('/row') AS ROW(ROW)
	
	
	UPDATE @Result
	SET Value = [TimePaid].[Value]
	FROM
	(
		SELECT 
			[vwTimeEntry].[ProjectID],
			SUM
			(
				CASE 
					WHEN [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 1 
						THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] / ( 1 + [vwTimeEntry].[VATRate] )
					WHEN
						( [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 0  )
						OR
						( [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 1  )
						THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate]
					WHEN [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 0 
						THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] * ( 1 + [vwTimeEntry].[VATRate] )
				END 
				* ISNULL(( [PaymentDetail].[PaymentValue] / [Statement].[TotalWithVAT] ),1)
				* dbo.pjm6fnCurrencyGetRate
					(
						[vwTimeEntry].[CurrencyCode],
						[vwTimeEntry].[StartTime], 
						@CurrencyCode
					)
				
			) AS [Value]
		FROM
			[vwTimeEntry]
			INNER JOIN [Project]
				ON [Project].[ID] = [vwTimeEntry].[ProjectID]
			INNER JOIN @TimeInFinance [TIFS]
				ON [TIFS].[DocumentID] = [vwTimeEntry].[ID] AND [TIFS].[LinkClass] = @StatementClass
			INNER JOIN [Statement]
				ON [Statement].[ID] = [TIFS].[LinkDocumentID]
			
			LEFT OUTER JOIN @TimeInFinance [TIFI]
				ON [vwTimeEntry].[ID] = [TIFI].[DocumentID] AND [TIFI].[LinkClass] = @InvoiceClass
			LEFT OUTER JOIN [PaymentDetail] 
				ON [PaymentDetail].[InvoiceID] = ISNULL([TIFI].[LinkDocumentID], 0)
				OR
				[PaymentDetail].[InvoiceID] IN
				(
					SELECT
						[StatementAdvanceInvoice].[AdvanceInvoiceID]
					FROM
						[StatementAdvanceInvoice]
					WHERE
						[StatementAdvanceInvoice].[StatementID] = [Statement].[ID]
				)
		GROUP BY [vwTimeEntry].[ProjectID]
	) AS [TimePaid]
	WHERE
		[@Result].[ProjectID] = [TimePaid].[ProjectID]
		
	UPDATE @Result
	SET Value = ISNULL([@Result].[Value],0) + ISNULL([ExpensePaid].[Value],0)
	FROM
	(
		SELECT 
			[Expense].[ProjectID],
			SUM
			(
				[Expense].[TotalWithVATPC]
				* ( [PaymentDetail].[PaymentValue] / [Statement].[TotalWithVAT] )
				* dbo.pjm6fnCurrencyGetRate
					(
						[Expense].[ToCurrencyCode],
						[Expense].[Date],
						@CurrencyCode
					)
			) AS [Value]
		FROM
			[Expense]
			INNER JOIN [Project]
				ON [Project].[ID] = [Expense].[ProjectID]
			INNER JOIN @ExpenseInFinance [EIFS]
				ON [EIFS].[DocumentID] = [Expense].[ID] AND [EIFS].[LinkClass] = @StatementClass
			INNER JOIN [Statement]
				ON [Statement].[ID] = [EIFS].[LinkDocumentID]
			
			LEFT OUTER JOIN @ExpenseInFinance [EIFI]
				ON [Expense].[ID] = [EIFI].[DocumentID] AND [EIFI].[LinkClass] = @InvoiceClass
			LEFT OUTER JOIN [PaymentDetail] 
				ON [PaymentDetail].[InvoiceID] = ISNULL([EIFI].[LinkDocumentID], 0)
				OR
				[PaymentDetail].[InvoiceID] IN
				(
					SELECT
						[StatementAdvanceInvoice].[AdvanceInvoiceID]
					FROM
						[StatementAdvanceInvoice]
					WHERE
						[StatementAdvanceInvoice].[StatementID] = [Statement].[ID]
				)
		GROUP BY [Expense].[ProjectID]
	) AS [ExpensePaid]
	WHERE
		[@Result].[ProjectID] = [ExpensePaid].[ProjectID]

RETURN
END
GO