IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCreate'
		DROP PROCEDURE [dbo].[pjm6BudgetCreate]
	END
GO

PRINT 'Creating procedure pjm6BudgetCreate'
GO

/******************************************************************************
**		File: pjm6BudgetCreate.sql
**		Name: pjm6BudgetCreate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 24/09/2010 14:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		21.02.13	MAB				      
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetCreate]
@BudgetType	TIdentifier,
@ProjectID	TIdentifier,
@StartDate	TDate			= NULL,
@EndDate	TDate			= NULL,
@RecurrenceType TIdentifier = NULL,
@Occurrences	TCount		= NULL,
@Interval		TCount		= NULL
AS
	SET NOCOUNT ON

	DECLARE
		@State				TState,
		@DocumentClass		TClass,
		@ProjectTypeID		TIdentifier,
		@BudgetName			TName,
		@ProjectNumber		TName,
		@CurrencyCode		TCode3,
		@ApplyVAT			TBool,
		@VATRate			TPercent,
		@RatesWithVAT		TBool,
		@ProjectState		TState,
		@value				TVariant,
		@ID					TIdentifier,
		@RecurrenceID		TIdentifier,
		@Class				TClass,
		@Lang				TLanguage,
		@rv					int,
		@CompanyOwn			TBool,
		@PlanProfitability	TPercent
	
	IF dbo.fnPjm6CanEditBudgetForProject(@ProjectID) != 1
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		

	SET @Class = dbo.adfGetClassByName('Pjm6.Budget')
	SET @Lang = dbo.adfGetLanguage()

	SET @State = dbo.adfwfGetInitialState('8E95426E-83B7-4486-8EAD-0191CB63891A')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SELECT
		@CompanyOwn			= [Company].[Own],
		@DocumentClass		= [Project].[Class],
		@ProjectTypeID		= [Project].[ProjectTypeID],
		@ProjectState		= [Project].[State],
		@ProjectNumber		= [Project].[Number],
		@CurrencyCode		= [Project].[CurrencyCode],
		@ApplyVAT			= [Project].[ApplyVAT],
		@RatesWithVAT		= [Project].[RatesWithVAT],
		@StartDate = CASE WHEN @BudgetType = 1 THEN [Project].[Date] ELSE @StartDate END,
		@EndDate = CASE WHEN @BudgetType = 1 THEN [Project].[EndDate] ELSE @EndDate END,
		@PlanProfitability	= [Company].[PlanProfitability]
	FROM
		[Project] LEFT JOIN [Company]
		ON [Project].[CustomerCompanyID] = [Company].[ID]
	WHERE
		[Project].[ID] = @ProjectID
	
	IF @ProjectTypeID > 1
	BEGIN
		RAISERROR('#wrongprojecttype', 18, -1)
		RETURN 1
	END

	IF @ProjectState NOT IN (1, 2, 3, 5, 6)
	BEGIN
		RAISERROR('#ProjectIsNotActive', 18, -1)
		RETURN 1
	END

	IF EXISTS(SELECT *FROM [Task] WHERE ProjectID = @ProjectID AND [SubprojectID] = NULL AND [State] = 2)
	BEGIN
		RAISERROR('#projecthastaskplanning', 18, -1)
		RETURN 1
	END

	IF EXISTS(SELECT *FROM [Budget] 
		INNER JOIN [Document]
			ON [Document].[Class] = [Budget].[Class] AND [Document].[ID] = [Budget].[ID]
		INNER JOIN [RecurrencePattern]
			ON [Document].[RecurrencePatternID] = [RecurrencePattern].[ID] OR [Document].[RecurrencePatternID] IS NULL
		WHERE [DocumentClass] = @DocumentClass AND [DocumentID] = @ProjectID 
			AND (@BudgetType = 1 OR (@BudgetType > 1 AND [Budget].[State] IN (1, 2))))
	BEGIN
		RAISERROR('#budgetisalreadycreated', 18, -1)
		RETURN 1
	END
	
	IF (@BudgetType > 1 AND EXISTS(SELECT *FROM [Budget] WHERE [DocumentClass] = @DocumentClass 
		AND [DocumentID] = @ProjectID AND ((@StartDate Between [Budget].[StartDate] AND [Budget].[EndDate])
		OR (@EndDate Between [Budget].[StartDate] AND [Budget].[EndDate]) OR 
		([Budget].[StartDate] Between @StartDate AND @EndDate)
		OR ([Budget].[EndDate] Between @StartDate AND @EndDate))))
	BEGIN
		RAISERROR('#crossingbudgetperiod', 18, -1)
		RETURN 1
	END
		
	IF @ApplyVAT = 1
	BEGIN
		EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
		SET @VATRate = CAST(@value as decimal(18,4))
	END
	
	IF @BudgetType != 1
	BEGIN
		SET @StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) as datetime)
		SET @EndDate = CAST(CONVERT(varchar(8), @EndDate, 112) as datetime)
	END

	IF @Lang = 'ru'
		SET @BudgetName = '   ''' + @ProjectNumber + ''''
	ELSE IF @Lang = 'en'
		SET @BudgetName = 'Budget for project ''' + @ProjectNumber + ''''

	BEGIN TRANSACTION

	IF @RecurrenceType IS NOT NULL AND @BudgetType >= 2
	BEGIN
		INSERT INTO [RecurrencePattern]
			([StartDate], [EndDate], [RecurrenceType], [Occurrences],
			[Interval], [DayOfWeekMask], [Instance], [MonthOfYear], [DayOfMonth])
		VALUES
			(@StartDate, NULL, @RecurrenceType, @Occurrences,
			@Interval, 0, NULL, NULL, NULL)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @RecurrenceID = SCOPE_IDENTITY()
	END

	IF @CompanyOwn IS NULL OR @CompanyOwn = 1 OR @PlanProfitability IS NULL
	BEGIN
		EXEC adfParameterGet @Name='PlanProfitability', @Group='Pjm7', @Value = @value OUTPUT
		SET @PlanProfitability = CAST(@value as decimal(18,4))
	END

	IF @ProjectState IN (5 ,6)
		SET @State = 6

	INSERT INTO [Budget]
		([Class], [State], [Flag], [FileAs], [CurrencyCode], [DocumentClass], [DocumentID], [BudgetTypeID], [StartDate], [EndDate],
		[WorkBudgetBottom], [WorkBudgetHigh], [WorkBudgetBottomEqualsPlan], [WorkBudgetHighEqualsPlan],
		[ExpenseBudgetBottom], [ExpenseBudgetHigh], [ExpenseBudgetBottomEqualsPlan], [ExpenseBudgetHighEqualsPlan],
		[VATRate], [VATIsIncluded],
		[DiscountViewWork], [DiscountPercentWork], [DiscountViewExpense], [DiscountPercentExpense], 
		[PlanningActivityForWork], [PlanningEmployeeForWork], [PlanningQualificationForWork], [PlanningRateForWork],
		[PlanningExpenseTypeForExpense], [PlanningEmployeeForExpense], [PlanningPriceForExpense],
		[PlanningDateForWork],[PlanningDateForExpense], [TimeEntryAccount], [ExpenseAccount],
		[TimeEntrySendingForApprovalAccount], [PlanProfitability], [ExpenseSendingForApprovalAccount], [PlanPurchases]
		)
	VALUES
		(@Class, @State, 0, @BudgetName, @CurrencyCode, @DocumentClass, @ProjectID, @BudgetType, @StartDate, @EndDate,
		 0, 0, 1, 1,
		 0, 0, 1, 1, 
		 @VATRate, @RatesWithVAT, 
		 0, NULL, 0, NULL,
		 0, 0, 0, 1, 
		 1, 0, 1,
		 0, 0, 0, 1,
		 1, @PlanProfitability, 1, 0
		 )
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	SET @ID = SCOPE_IDENTITY()

	IF @RecurrenceID IS NOT NULL
	BEGIN
		UPDATE
			[Document]
		SET
			[RecurrencePatternID] = @RecurrenceID
		WHERE
			[Class] = @Class AND [ID] = @ID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	--  
	EXEC @rv = pjm6BudgetSystemGroupsInsert @ID
	IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	/*
	IF @ProjectState = 2
	BEGIN
		EXEC @rv = pjm6BudgetChangeState @ID, 2
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END*/
	--EXEC pjm6BudgetGet @ID
	
	COMMIT TRANSACTION
	
	SELECT @ID AS [ID]
	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCreate TO PUBLIC
GO
