IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5DocumentItemChangeState]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5DocumentItemChangeState'
		DROP PROCEDURE [dbo].[pjm5DocumentItemChangeState]
	END
GO

PRINT 'Creating procedure pjm5DocumentItemChangeState'
GO

/******************************************************************************
**		File: pjm5DocumentItemChangeState.sql
**		Name: pjm5DocumentItemChangeState
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm5DocumentItemChangeState
	@ID TIdentifier,
	@ToState TState
AS
	DECLARE @FromState TState,
			@TransitionTemplateID TIdentifier,
			@UserID TIdentifier,
			@RightID TIdentifier,
			@Class TClass,
			@Version TCount,
			@CreatedBy TIdentifier,
			@FolderID TIdentifier,
			@VersionControl TBool,
			@PublicationControl TBool,
			@FolderPublication TBool,
			@Extension TName,
			@CaseID TIdentifier,
			@rv int
	
	SET NOCOUNT ON
	
	SELECT
		@Class = [DocumentItem].[Class],
		@FromState = [DocumentItem].[State],
		@Version = [DocumentItem].[LatestVersion],
		@Extension = [DocumentItem].[Extension],
		@FolderID = [Folder].[ID],
		@VersionControl = [Folder].[VersionControl],
		@CreatedBy = [DocumentItem].[CreatedBy],
		@PublicationControl = [Folder].[PublicationControl],
		@CaseID = [DocumentCard].[CaseID]
	FROM
		[DocumentItem]
		INNER JOIN [DocumentCard]
			ON [DocumentCard].[ID] = [DocumentItem].[DocumentCardID]
		INNER JOIN [Folder]
			ON [Folder].[ID] = [DocumentCard].[FolderID]
	WHERE
		[DocumentItem].[ID] = @ID
		
	IF @FromState = @ToState
	BEGIN
		RAISERROR('#invalidargument', 18, -1)
		RETURN 1
	END
	
	
	SELECT
		@TransitionTemplateID = [ID],
		@RightID = [RightID]
	FROM
		[TransitionTemplate]
	WHERE
		[TransitionTemplate].[FromState] = @FromState AND [TransitionTemplate].[ToState] = @ToState
	AND
		[TransitionTemplate].[Class] = @Class
		
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#invalidoperation', 18, -1)
		RETURN 1
	END
	
	SET @TransitionTemplateID = dbo.adfCheckTransitionRights(@TransitionTemplateID, @RightID, dbo.adfGetCurrentUserID())
	
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SET @UserID = dbo.adfGetCurrentUserID()
	SET @FolderPublication = 1
	IF @PublicationControl = 1 AND @CaseID IS NULL
	BEGIN
		SET @FolderPublication = dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'FolderPublication') |
			dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'FolderOwner')
	END
	IF @FolderPublication = 0 AND @FromState = 1 AND @ToState = 2
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	BEGIN TRANSACTION
	IF @ToState = 3
	BEGIN
		EXEC @rv = pjm5DocumentItemCheckOut @FolderID, @ID, @Version, @CreatedBy, @Extension
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		IF @FromState != 4
		BEGIN
			EXEC pjm5DocumentItemCheckOutNotification @ID
		END
	END
	
	IF @FromState = 3 AND @ToState = 4
	BEGIN
		EXEC @rv = pjm5DocumentItemCheckIn @ID, @Version, @VersionControl
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	IF @FromState = 1 AND @ToState = 2
	BEGIN
		EXEC @rv = pjm5DocumentItemCheckIn @ID, @Version, @VersionControl
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		EXEC pjm5DocumentItemPublicatedNotification @ID
	END

	IF @FromState = 3 AND @ToState = 2
	BEGIN
		
		SELECT TOP 1 @ToState = [TransitionTemplate].[FromState]
		FROM
			[Transition]
			INNER JOIN [TransitionTemplate]
				ON [TransitionTemplate].[ID] = [Transition].[TransitionTemplateID]
		WHERE
			[Transition].[Class] = @Class AND 
			[Transition].[DocumentID] = @ID AND
			[TransitionTemplate].[ToState] = 3 AND
			[TransitionTemplate].[FromState] != 3
		ORDER BY
			[Transition].[Created] DESC
	
		EXEC @rv = pjm5DocumentItemUndoCheckOut @ID, @Version
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		EXEC pjm5DocumentItemCheckInNotification @ID, 'UNDO'
	END

	UPDATE
		[DocumentItem]
	SET
		[DocumentItem].[State] = @ToState,
		[DocumentItem].[CheckedOutBy] = CASE @ToState WHEN 3 THEN @UserID ELSE NULL END,
		[DocumentItem].[Modified] = DEFAULT,
		[DocumentItem].[ModifiedBy] = DEFAULT
	WHERE
		[DocumentItem].[ID] = @ID
	AND
		[DocumentItem].[State] = @FromState
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF @ToState = 1
	BEGIN
		IF @FromState = 3
			EXEC pjm5DocumentItemCheckInNotification @ID, 'CHECKIN'

		IF @FolderPublication = 1
		BEGIN
			EXEC @rv = pjm5DocumentItemChangeStateInternal @ID, 2
			IF @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END

	IF @FolderID > 0
	BEGIN
		UPDATE
			[DocumentCard]
		SET
			[Modified] = DEFAULT,
			[ModifiedBy] = DEFAULT
		FROM
			[DocumentCard]
			INNER JOIN [DocumentItem]
				ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		WHERE
			[DocumentItem].[ID] = @ID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	COMMIT TRANSACTION
	RETURN 0
GO

GRANT EXECUTE ON pjm5DocumentItemChangeState TO PUBLIC
GO

