IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6DocumentNumberGet')
	BEGIN
		PRINT 'Dropping Procedure pjm6DocumentNumberGet'
		DROP  Procedure  pjm6DocumentNumberGet
	END
GO

PRINT 'Creating Procedure pjm6DocumentNumberGet'
GO
/******************************************************************************
**		File: DocumentNumberGet
**		Name: pjm6DocumentNumberGet
**		Desc: 
**              
**		Auth: SPV
**		Date: 04.07.11
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.07.11	SPV				first version
*******************************************************************************/
CREATE Procedure pjm6DocumentNumberGet
	@TemplateClass TClass,
	@CompanyID TClass, --   ,   
	@DocumentClass TClass,
	@DocumentID	TIdentifier
	
AS
	DECLARE
		@CompanyClass TClass,
		@ProjectClass TClass,
		@ApplyLevel tinyint,
		@Seed TCount,
		@Increment TCount,
		@TemplateName TName,
		@TemplateNumber TName,
		@DuePeriodType tinyint,
		@CurrentNumber TCount,
		@PrevNumber TCount,
		@IsNew TBool
		
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')

	-------------------------  ,     ------------------------------------
	IF @CompanyID IS NULL
	BEGIN
		--  @DocumentID   
		SELECT @CompanyID = [ID] FROM [Company] WHERE [ID] = @DocumentID AND [Class] = @DocumentCLass AND [Own] = 1
		--  @DocumentID -  
		IF @CompanyID IS NOT NULL
		BEGIN
			SET @DocumentClass = NULL
			SET @DocumentID = NULL
		END
		--  @DocumentID   ,    
		ELSE
		BEGIN
			--      
			IF @DocumentClass = @CompanyClass
			BEGIN
				SET @CompanyID = 
				(
					SELECT TOP(1) [SupplierCompanyID]
					FROM [Project]
					WHERE
						[CustomerCompanyID] = @DocumentID AND
						[SupplierCompanyID] IN
						(
							SELECT [CompanyID]
							FROM [NumberTemplate]
							WHERE [TemplateClass] = @TemplateClass AND [ApplyLevel] = 1
						)
				)
			END
			--     
			ELSE IF @DocumentClass = @ProjectClass
			BEGIN
				SELECT @CompanyID = [SupplierCompanyID]
				FROM [Project]
				WHERE
					[ID] = @DocumentID AND
					[SupplierCompanyID] IN
					(
						SELECT [CompanyID]
						FROM [NumberTemplate]
						WHERE [TemplateClass] = @TemplateClass AND [ApplyLevel] = 2
					)
			END
		END
	END
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#numbertemplatenotfound', 18, -1)
		RETURN 1
	END
	---------------------------------------- ----------------------------------------------------------
	SELECT
		@Seed = [Seed],
		@Increment = [Increment],
		@TemplateName = [NameTemplate],
		@TemplateNumber = [NumberTemplate],
		@ApplyLevel = [ApplyLevel]
	FROM
		[NumberTemplate]
	WHERE
		[CompanyID] = @CompanyID AND
		[TemplateClass] = @TemplateClass

	--         ,   
	IF @ApplyLevel IS NULL
	BEGIN
		INSERT INTO [NumberTemplate] ([CompanyID], [TemplateClass], [ApplyLevel], [DuePeriodType], [CurrentNumber], [PrevNumber])
		VALUES (@CompanyID, @TemplateClass, 0, dbo.fnPjm6NumberGetDefaultPeriodType(@TemplateClass, 0), 1, 1)

		SELECT
			@Seed = [Seed],
			@Increment = [Increment],
			@TemplateName = [NameTemplate],
			@TemplateNumber = [NumberTemplate],
			@ApplyLevel = [ApplyLevel]
		FROM
			[NumberTemplate]
		WHERE
			[CompanyID] = @CompanyID AND
			[TemplateClass] = @TemplateClass
	END

	-------------------------------------- ------------------------------------------------------------

	-------------    
	IF @DocumentClass IS NOT NULL AND @DocumentID IS NOT NULL
	BEGIN
		SELECT
			@DuePeriodType = [DuePeriodType],
			@CurrentNumber = [CurrentNumber],
			@PrevNumber = [PrevNumber]
		FROM
			[NumberAssignment]
		WHERE
			[TemplateClass] = @TemplateClass AND
			[DocumentClass] = @DocumentClass AND 
			[DocumentID] = @DocumentID
		
		--    , 
		IF @DuePeriodType IS NULL
		BEGIN
			SET @IsNew = 1

			INSERT INTO [NumberAssignment] ([TemplateClass], [DocumentClass], [DocumentID], [DuePeriodType], [CurrentNumber], [PrevNumber])
			VALUES (@TemplateClass, @DocumentClass, @DocumentID, dbo.fnPjm6NumberGetDefaultPeriodType(@TemplateClass, @ApplyLevel), @Seed, @Seed)

			SELECT
				@DuePeriodType = [DuePeriodType],
				@CurrentNumber = [CurrentNumber],
				@PrevNumber = [PrevNumber]
			FROM
				[NumberAssignment]
			WHERE
				[TemplateClass] = @TemplateClass AND
				[DocumentClass] = @DocumentClass AND 
				[DocumentID] = @DocumentID
		END
	END
	-------------  
	ELSE
	BEGIN
		SELECT
			@DuePeriodType =  CASE WHEN [ApplyLevel] = 0 THEN [DuePeriodType] ELSE 0 END,
			@CurrentNumber = [CurrentNumber],
			@PrevNumber = [PrevNumber]
		FROM
			[NumberTemplate]
		WHERE
			[TemplateClass] = @TemplateClass AND
			[CompanyID] = @CompanyID
	END

	SELECT
		@CompanyID as [CompanyID],
		@DocumentClass as [DocumentClass],
		@DocumentID as [DocumentID],
		@DuePeriodType as [DuePeriodType],
		@CurrentNumber as [CurrentNumber],
		@PrevNumber as [PrevNumber],
		@Seed as [Seed],
		@Increment as [Increment],
		@TemplateName as [NameTemplate],
		@TemplateNumber as [NumberTemplate],
		@ApplyLevel as [ApplyLevel]
GO

GRANT EXEC ON pjm6DocumentNumberGet TO PUBLIC
GO
