IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6DocumentNumberUpdate')
	BEGIN
		PRINT 'Dropping Procedure pjm6DocumentNumberUpdate'
		DROP  Procedure  pjm6DocumentNumberUpdate
	END

GO

PRINT 'Creating Procedure pjm6DocumentNumberUpdate'
GO
/******************************************************************************
**		File:	DocumentNumberUpdate
**		Name:	pjm6DocumentNumberUpdate
**		Desc:	         
**				 
**              
**		Auth:	SPV
**		Date:	04.07.11
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.07.11	SPV				first version
*******************************************************************************/
CREATE Procedure pjm6DocumentNumberUpdate
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@TemplateClass TClass,
	@CompanyID TIdentifier,

	@ApplyLevel tinyint,
	@TemplateNumber TName,
	@TemplateName TName,
	@Seed TCount,
	@Increment TCount,
	
	@CurrentNumber TCount,
	@PrevNumber TCount,
	@DuePeriodType tinyint
AS

	SET @Seed = ISNULL(@Seed, 1)
	SET @Increment = ISNULL(@Increment, 1)
	SET @CurrentNumber = ISNULL(@CurrentNumber, 0)
	SET @PrevNumber = ISNULL(@PrevNumber, 0)

	IF @ApplyLevel = 0
	BEGIN
		UPDATE
			[NumberTemplate]
		SET
			[ApplyLevel] = @ApplyLevel,
			[NumberTemplate] = @TemplateNumber,
			[NameTemplate] = @TemplateName,
			[Seed] = @Seed,
			[Increment] = @Increment,

			[CurrentNumber] = @CurrentNumber,
			[PrevNumber] = @PrevNumber,
			[DuePeriodType] = @DuePeriodType
		WHERE
			[NumberTemplate].[CompanyID] = @CompanyID AND
			[NumberTemplate].[TemplateClass] = @TemplateClass
	END
	ELSE 
	BEGIN
		UPDATE
			[NumberTemplate]
		SET
			[ApplyLevel] = @ApplyLevel,
			[NumberTemplate] = @TemplateNumber,
			[NameTemplate] = @TemplateName,
			[Seed] = @Seed,
			[Increment] = @Increment
		WHERE
			[NumberTemplate].[CompanyID] = @CompanyID AND
			[NumberTemplate].[TemplateClass] = @TemplateClass
	
		UPDATE [NumberAssignment]
		SET
			[CurrentNumber] = @CurrentNumber,
			[PrevNumber] = @PrevNumber,
			[DuePeriodType] = @DuePeriodType
		WHERE
			[DocumentClass] = @DocumentClass AND
			[DocumentID] = @DocumentID AND
			[TemplateClass] = @TemplateClass
	END

	RETURN 1
GO

GRANT EXEC ON pjm6DocumentNumberUpdate TO PUBLIC
GO
