IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ExpenseChangeState]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ExpenseChangeState'
		DROP PROCEDURE [dbo].[pjm5ExpenseChangeState]
	END
GO

PRINT 'Creating procedure pjm5ExpenseChangeState'
GO

/******************************************************************************
**		File: pjm5ExpenseChangeState.sql
**		Name: pjm5ExpenseChangeState
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		14.05.10	SYV				  pjm6DismissEventsOnObjec  
**									pjm7AllDocumentReminderDismiss    
**		24.08.10	SYV				  pjm6DismissEventsOnObject .. 
**									   
**		01.10.10	SYV				Approver     
**		07.11.11	PAM				   ,   
**									    
**		01.04.13	SOV				. -     
*******************************************************************************/
CREATE PROCEDURE pjm5ExpenseChangeState
	@ID TIdentifier,
	@ToState TState
AS
	DECLARE @FromState TState,
			@TransitionTemplateID TIdentifier,
			@RightID TIdentifier,
			@Class TClass,
			@ProjectID TIdentifier,
			@EmployeeID TIdentifier,
			@DivisionID TIdentifier,
			@rv int
	
	SET NOCOUNT ON
	
	SELECT
		@Class = [Expense].[Class],
		@FromState = [Expense].[State],
		@ProjectID = [Expense].[ProjectID],
		@EmployeeID = [Expense].[EmployeeID],
		@DivisionID = [Employee].[DivisionID]
	FROM
		[Expense]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Expense].[EmployeeID]
	WHERE
		[Expense].[ID] = @ID
		
	IF @FromState = @ToState
	BEGIN
		RAISERROR('#invalidargument', 18, -1)
		RETURN 1
	END
	
	SELECT
		@TransitionTemplateID = [ID],
		@RightID = [RightID]
	FROM
		[TransitionTemplate]
	WHERE
		[TransitionTemplate].[FromState] = @FromState AND [TransitionTemplate].[ToState] = @ToState
	AND
		[TransitionTemplate].[Class] = @Class
		
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#invalidoperation', 18, -1)
		RETURN 1
	END
	
	SET @TransitionTemplateID = dbo.adfCheckTransitionRights(@TransitionTemplateID, @RightID, dbo.adfGetCurrentUserID())
	
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE 
		@CurrentEmployeeID TIdentifier,
		@projectManager TBool,
		@assistant TBool,
		@ExpenseSecretary TBool,
		@ExpenseApprover	TBool,
		@approver TBool,
		@IsManagerAssistant TBool

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @projectManager = dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID)
	SET @assistant = dbo.fnPjm5IsAssistant()
	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')
	SET @ExpenseApprover = dbo.adfHasAccessRightByName('ApproveExpenseWithoutAssignment')
	SET @approver = dbo.fnPjm5IsProjectApprover(@ProjectID, @CurrentEmployeeID)	
	SET @IsManagerAssistant  = dbo.fnPjm7IsManagerAssistant(@ProjectID, @CurrentEmployeeID)

	IF (
			(@FromState = 2 AND @ToState = 3) OR
			(@FromState = 2 AND @ToState = 5) OR
			(@FromState = 3 AND @ToState = 5)
		) AND
		@projectManager = 0 AND
		@assistant = 0 AND
		@approver = 0 AND
		@ExpenseApprover = 0 AND
		@IsManagerAssistant = 0
		BEGIN
				RAISERROR('#ExpenseChangeStateFailed', 18, -1)
				RETURN 1
		END		
	ELSE IF (
			--(@FromState = 2 AND @ToState = 3) OR 
			(@FromState = 2 AND @ToState = 4) OR 
			--(@FromState = 2 AND @ToState = 5) OR 
			(@FromState = 3 AND @ToState = 4) OR
			--(@FromState = 3 AND @ToState = 5) OR 
			(@FromState = 4 AND @ToState = 5) 
		) AND
		@projectManager = 0 AND
		@assistant = 0 AND
		@approver = 0 AND
		@IsManagerAssistant = 0
	BEGIN
		RAISERROR('#ExpenseChangeStateFailed', 18, -1)
		RETURN 1
	END 
	ELSE 	
	BEGIN
		IF ( 
				(@FromState = 1 AND @ToState = 2) OR 
				(@FromState = 2 AND @ToState = 1)
			) AND
			@CurrentEmployeeID != @EmployeeID AND
			@projectManager = 0 AND
			@assistant = 0 AND
			dbo.fnPjm5IsProjectAdministrator(@ProjectID, @CurrentEmployeeID) = 0  AND
			@ExpenseSecretary = 0 AND
			@approver = 0 AND
			@IsManagerAssistant = 0
		BEGIN
			RAISERROR('#ExpenseChangeStateFailed', 18, -1)
			RETURN 1
		END
		ELSE IF NOT (
				(@FromState = 2 AND @ToState = 3) OR 
				(@FromState = 3 AND @ToState = 5)
			) AND
			NOT (
				(@FromState = 1 AND @ToState = 2) OR 
				(@FromState = 2 AND @ToState = 1)
			) AND
			@CurrentEmployeeID != @EmployeeID AND 
			@projectManager = 0 AND
			@assistant = 0 AND
			@approver = 0 AND
			@ExpenseSecretary = 0 AND
			@IsManagerAssistant = 0
		BEGIN
			RAISERROR('#ExpenseChangeStateFailed', 18, -1)
			RETURN 1
		END
	END


	UPDATE
		[Expense]
	SET
		[Expense].[DivisionID] = CASE 
			WHEN @FromState = 2 AND @ToState = 3
				THEN @DivisionID
			ELSE [Expense].[DivisionID]
		END,
		[Expense].[State] = @ToState,
		[Expense].[Modified] = GETDATE(),
		[Expense].[ModifiedBy] = dbo.adfGetCurrentUserID()
	WHERE
		[Expense].[ID] = @ID
	AND
		[Expense].[State] = @FromState

	IF @@ERROR != 0
		RETURN 1
			
	IF (@ToState = 3 OR @ToState = 4 OR @ToState = 6)
	BEGIN
		EXEC @rv = pjm7AllDocumentReminderDismiss @Class, @ID
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN @rv
		END
	END		
		
	RETURN 0
GO

GRANT EXECUTE ON pjm5ExpenseChangeState TO PUBLIC
GO
 