IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5InvoiceBrowseByProject]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5InvoiceBrowseByProject'
		DROP PROCEDURE [dbo].[pjm5InvoiceBrowseByProject]
	END
GO

PRINT 'Creating procedure pjm5InvoiceBrowseByProject'
GO

/******************************************************************************
**		File: InvoiceBrowseByProject.sql
**		Name: pjm5InvoiceBrowseByProject
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5InvoiceBrowseByProject]
	@ProjectID TIdentifier,
	@StateSelector INT,
	@DateSelector INT,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	DECLARE
		@EmployeeID TIdentifier,
		@ViewAllProjects TBool,
		@BaseCurrencyCode TCode3,
		@value TVariant

	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	SELECT 
		@ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')),
		@EmployeeID = dbo.adfGetCurrentEmployeeID()

	IF @DateSelector != 0
		EXEC BillingFilterPeriodGet @DateSelector, @PeriodStart OUTPUT, @PeriodEnd OUTPUT
	;
	WITH [AdvanceInvoices] ([InvoiceID], [AdvanceValue]) AS
	(
		SELECT
			[AdvanceInvoice].[InvoiceID],
			SUM([Invoice].[TotalWithVAT])
		FROM
			[AdvanceInvoice]
			INNER JOIN [Invoice]
				ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		GROUP BY
			[AdvanceInvoice].[InvoiceID]
	)	
	SELECT
		[Invoice].[Class],
		[Invoice].[ID],
		[Invoice].[State],
		[Invoice].[Flag],
		[WarningFlag].[WarningType],
		[Invoice].[Date],
		[Invoice].[Number],
		[Invoice].[FileAs],
		[Invoice].[ProjectID],
		[Project].[ProjectManagerEmployeeID],
		[Invoice].[CurrencyCode],
		[Invoice].[CurrencyRate],
		[Invoice].[BaseCurrencyRate],
		[Invoice].[SupplierCompanyID],
		[Invoice].[SupplierBankAccountID],
		[Invoice].[CustomerCompanyID],
		[Invoice].[Advance],
		[Invoice].[Total],
		[Invoice].[VAT],
		[Invoice].[TotalWithVAT],
		[Invoice].[TotalWithVATPC] AS [ProjectTotal],
		[Project].[CurrencyCode] AS [ProjectCurrencyCode],
		[Invoice].[TotalWithVATBC] AS [BaseTotal],
		@BaseCurrencyCode AS [BaseCurrencyCode],
		ISNULL([pjm5vwInvoicePayment].[PaymentValue], 0) AS [PaymentValue],
		[Invoice].[TotalWithVAT] - 
			ISNULL([pjm5vwInvoicePayment].[PaymentValue], 0) -
			ISNULL([AdvanceInvoices].[AdvanceValue], 0) AS [RemainValue],
		[Invoice].[Comments],
		[Invoice].[Created],
		[Invoice].[CreatedBy],
		[Invoice].[Modified],
		[Invoice].[ModifiedBy],
		[Invoice].[Timestamp],
		[Project].[CostCenterID],
		[Company].[ManagerEmployeeID],
		[Invoice].[ExchangeBanned]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
		LEFT OUTER JOIN [Company]
			ON [Project].[CustomerCompanyID] = [Company].[ID]
		LEFT OUTER JOIN [pjm5vwInvoicePayment]
			ON [pjm5vwInvoicePayment].[InvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [AdvanceInvoices]
			ON [AdvanceInvoices].[InvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [WarningFlag]
			ON ([Invoice].[WarningFlagID] = [WarningFlag].[ID])
	WHERE
		[Project].[ID] = @ProjectID AND
		(@DateSelector = 0 OR [Invoice].[Date] BETWEEN @PeriodStart AND @PeriodEnd) AND
		(
			@StateSelector = 0 OR 
			@StateSelector = 7 AND [Invoice].[State] != 3 OR
			@StateSelector = 1 AND [Invoice].[State] = 1 OR
			@StateSelector = 2 AND [Invoice].[State] = 2 OR
			@StateSelector = 3 AND [Invoice].[State] = 5 OR
			@StateSelector = 4 AND [Invoice].[State] = 3 OR
			@StateSelector = 5 AND [Invoice].[State] = 7 OR
			@StateSelector = 6 AND [Invoice].[State] = 6
		) AND
		(@ViewAllProjects = 1 OR dbo.fnPjm5HasFinansDataAccess([Project].[ID], @EmployeeID, NULL, NULL) = 1)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5InvoiceBrowseByProject] TO PUBLIC
GO
   