IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7DocumentSupervisorReminderCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7DocumentSupervisorReminderCreate'
		DROP PROCEDURE [dbo].[pjm7DocumentSupervisorReminderCreate]
	END
GO

PRINT 'Creating procedure pjm7DocumentSupervisorReminderCreate'
GO

/******************************************************************************
**		File: pjm7DocumentSupervisorReminderCreate.sql
**		Name: pjm7DocumentSupervisorReminderCreate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 28.04.2012 15:23:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		09.04.13	SOV				         
*******************************************************************************/
CREATE PROCEDURE [pjm7DocumentSupervisorReminderCreate]
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@ReminderSubtype TCode2,
	@ReminderDescription TName,
	@ReminderEventTime TDateTime
AS
	SET NOCOUNT ON
	
	IF @DocumentClass IS NULL OR @DocumentID IS NULL
	BEGIN
		RETURN 1
	END
	
	DECLARE
		@DatabaseView				TSysname,
		@ReminderID					TIdentifier,
		@ReminderInitialState		TState,
		@ReminderInitialInterval	TTimeSpan,
		@rv							int,
		@SupervisorEmployeeID		TIdentifier,
		@UserID						TIdentifier

		SELECT
			@UserID = [Employee].[UserID]
		FROM
			[Taskrequest]
		INNER JOIN [Employee] ON
			[TaskRequest].[SupervisorEmployeeID] = [Employee].[ID]
		WHERE
			[Taskrequest].[Class] = @DocumentClass AND [Taskrequest].[ID] = @DocumentID
	
	IF (@UserID IS NOT NULL)--(@SupervisorEmployeeID IS NOT NULL)
	BEGIN
		EXEC @rv = pjm7ReminderForUserCreateInternal	@ReminderID OUTPUT,
														@DocumentClass, 
														@DocumentID, 
														@ReminderSubtype, 
														@ReminderEventTime
		IF @rv != 0 OR @ReminderID IS NULL
		BEGIN
			RETURN 1
		END

		IF NOT EXISTS (
			SELECT * FROM [UserReminder]
			WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
		)
		BEGIN
			IF @ReminderEventTime IS NOT NULL
			BEGIN
				SELECT 
					@ReminderInitialState = ISNULL(dbo.fnPjm5GetUserInitialReminderState(@DocumentClass, @ReminderSubtype, @UserID), 0),
					@ReminderInitialInterval = ISNULL(dbo.fnPjm5GetReminderInterval(@DocumentClass, @ReminderSubtype, @UserID), 15)
					
				INSERT INTO [UserReminder] ([ReminderID], [UserID], [State],
					[OriginalInterval], [NextInterval], [Description])
				VALUES (@ReminderID, @UserID, @ReminderInitialState,
					@ReminderInitialInterval, @ReminderInitialInterval, LTRIM(RTRIM(@ReminderDescription)))
			END
		END
		ELSE
		BEGIN
			UPDATE [UserReminder] 
			SET
				[State] =	CASE
								WHEN @ReminderEventTime IS NOT NULL THEN [State]
								ELSE 0
							END,
				[Modified] = DEFAULT
			WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
		END
		IF @@ERROR != 0
		BEGIN
			RETURN 1
		END

		RETURN 0
	END

	RETURN 0
GO

GRANT EXECUTE ON [pjm7DocumentSupervisorReminderCreate] TO PUBLIC
GO