IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7TimeEntryReminderCopy]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7TimeEntryReminderCopy'
		DROP PROCEDURE [dbo].[pjm7TimeEntryReminderCopy]
	END
GO

PRINT 'Creating procedure pjm7TimeEntryReminderCopy'
GO

/******************************************************************************
**		File: pjm7TimeEntryReminderCopy.sql
**		Name: pjm7TimeEntryReminderCopy
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: anton.paramonov
**		Date: 28.01.2010 13:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		14.05.10	SYV				  @ReminderEventTime
**		21.12.10	SYV				   pjm7TimeEntryReminderCopyInternal
*******************************************************************************/
CREATE PROCEDURE [pjm7TimeEntryReminderCopy]
	@DocumentClass TIdentifier,
	@DocumentID	TIdentifier,
	@NewDocumentID TIdentifier,
	@EmployeeID	TIdentifier,
	@NewEmployeeID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@NewReminderEventTime TDateTime,
		@ReminderEventTime TDateTime,
		@CreatorUserID TIdentifier,
		@CreatorEmployeeID TIdentifier,
		@NewUserID TIdentifier,
		@IsDefaultReminder TBool
		
	IF @DocumentClass IS NULL OR @DocumentID IS NULL OR @NewDocumentID IS NULL
	BEGIN
		RETURN 1
	END
	
	SET @ReminderEventTime = (SELECT [StartTime] FROM [TimeEntry] WHERE [ID] = @DocumentID)
	SET @NewReminderEventTime = (SELECT [StartTime] FROM [TimeEntry] WHERE [ID] = @NewDocumentID)
	SET @CreatorUserID = dbo.adfGetCurrentUserID()
	SET @NewUserID = (SELECT [UserID] FROM [Employee] WHERE [ID] = @NewEmployeeID)
	SET @CreatorEmployeeID = dbo.adfGetCurrentEmployeeID()
	
	--   
	IF @CreatorEmployeeID != @NewEmployeeID -- 
	BEGIN
		--   
		IF @EmployeeID = @CreatorEmployeeID
		BEGIN
			SET @IsDefaultReminder = CASE WHEN @NewReminderEventTime > GETDATE() 
											AND @ReminderEventTime > GETDATE()
										THEN 0 ELSE 1 END

			EXEC pjm7TimeEntryReminderCopyInternal @DocumentClass, @DocumentID, @NewDocumentID, 
				@CreatorUserID, @NewReminderEventTime, @IsDefaultReminder
		END
		
		EXEC pjm7TimeEntryReminderCopyInternal @DocumentClass, @DocumentID, @NewDocumentID, 
			@NewUserID, @NewReminderEventTime, 1
	END
	ELSE
	--  
	BEGIN
		SET @IsDefaultReminder = CASE WHEN @EmployeeID = @CreatorEmployeeID THEN 
												CASE WHEN @NewReminderEventTime > GETDATE() 
														AND @ReminderEventTime > GETDATE()
												THEN 0 ELSE 1 END
									ELSE 1 END
		
		EXEC pjm7TimeEntryReminderCopyInternal @DocumentClass, @DocumentID, @NewDocumentID, 
			@CreatorUserID, @NewReminderEventTime, @IsDefaultReminder
	END

	RETURN 0
GO

GRANT EXECUTE ON [pjm7TimeEntryReminderCopy] TO PUBLIC
GO