﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfPaymentNotFullAssignedBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfPaymentNotFullAssignedBrowse'
		DROP PROCEDURE [dbo].[adfPaymentNotFullAssignedBrowse]
	END
GO

PRINT 'Creating procedure adfPaymentNotFullAssignedBrowse'
GO

/******************************************************************************
**		File: PaymentNotFullAssignedBrowse.sql
**		Name: adfPaymentNotFullAssignedBrowse
**		Desc: Процедура возвращает список платежей, которые имеют
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: anton.paramonov
**		Date: 27.02.2012 15:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/
CREATE PROCEDURE [adfPaymentNotFullAssignedBrowse]
AS
	SET NOCOUNT ON

	IF dbo.adfHasAccessRightByName('ViewAllFinance') = 1
	BEGIN
		DECLARE
			@BaseCurrencyCode TCode3,
			@value TVariant

		EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
		SET @BaseCurrencyCode = CAST(@value as varchar(3))
				
		SELECT
			[Payment].[Class],
			[Payment].[ID],
			[Payment].[State],
			[Payment].[Flag],
			[Payment].[FileAs],
			[Payment].[Date],
			[Payment].[Number],
			[Payment].[PaymentTypeID],
			[Payment].[CurrencyCode],
			[Payment].[PayeeCompanyID],
			[Payment].[PayeeBankAccountID],
			[Payment].[PayerCompanyID],
			[Company].[ManagerEmployeeID] AS [ManagerEmployeeID],
			[Payment].[Value],
			[Payment].[VAT],
			[Payment].[Value]-[Payment].[VAT] AS [TotalBC],
			[Payment].[TotalWithVATBC] AS [BaseTotal],
			@BaseCurrencyCode AS [BaseCurrencyCode],
			[Payment].[Comments],
			[Payment].[Created],
			[Payment].[CreatedBy],
			[Payment].[Modified],
			[Payment].[ModifiedBy],
			[Payment].[Timestamp],
			([Payment].[Value] - ISNULL((SELECT SUM([PaymentValue]) FROM [PaymentDetail] WHERE [PaymentID] = [Payment].[ID]), 0)) AS [TotalNotAssigned]
		FROM
			[Payment]
			LEFT OUTER JOIN [Company]
				ON [Company].[ID] = [Payment].[PayerCompanyID]
		WHERE
			[Payment].[State] = 2
			AND
			([Payment].[Value] - ISNULL((SELECT SUM([PaymentValue]) FROM [PaymentDetail] WHERE [PaymentID] = [Payment].[ID]), 0)) > 0
	END
	
	RETURN 0
GO

GRANT EXECUTE ON [adfPaymentNotFullAssignedBrowse] TO PUBLIC
GO
 


