IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ChangeFinanceManager]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ChangeFinanceManager'
		DROP PROCEDURE [dbo].[pjm7ChangeFinanceManager]
	END
GO

PRINT 'Creating procedure pjm7ChangeFinanceManager'
GO

/******************************************************************************
**		File: ChangeFinanceManager.sql
**		Name: pjm7ChangeFinanceManager
**		Desc:
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth:
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		07.06.13	SOV				    ViewAllFinance
**		14.06.13	SOV				     AssignProjectManager
*******************************************************************************/
CREATE PROCEDURE pjm7ChangeFinanceManager
	@ProjectID TIdentifier,
	@EmployeeID TIdentifier
AS	
	SET NOCOUNT ON;

	IF dbo.fnPjm5IsProjectManager(@ProjectID, dbo.adfGetCurrentEmployeeID()) = 0 AND
		dbo.adfHasAccessRight(dbo.adfGetRightID('AssignProjectManager')) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF (@ProjectID IS NULL)
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE @AssignmentID TIdentifier

	IF (@EmployeeID IS NOT NULL)
	BEGIN
		DECLARE @ViewFinanceID INT,
				@UserID TIdentifier

		SET @ViewFinanceID = dbo.adfGetRightID('ViewFinance')
		SELECT @UserID = [UserID] FROM [Employee] WHERE [ID] = @EmployeeID
			
		IF NOT EXISTS(
			SELECT 
				*
			FROM
				[AccessRight] a INNER JOIN
				(SELECT 
					[UserRole].[RoleID]
				FROM
					[UserRole]
				WHERE
					[UserRole].[UserID] = @UserID) p 
				ON (a.[RightID] = @ViewFinanceID AND a.[TrusteeID] = [p].[RoleID] 
					AND [a].[Allow] = 1))
		BEGIN
			IF NOT EXISTS(
				SELECT 
					*
				FROM
					[AccessRight] a
				WHERE
					a.[RightID] = @ViewFinanceID 
						AND [a].[TrusteeID]=@UserID AND [a].[Allow] = 1)
			BEGIN
				RAISERROR('#NotEnoughPermissionsForAssigningOfFinanceManager', 18, -1)
				RETURN 1
			END
		END
				
		SET @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @EmployeeID)
		
		IF (@AssignmentID IS NOT NULL)
			UPDATE [Assignment] 
			SET
				[FinanceManagement] = 1	
			WHERE
				[ID] = @AssignmentID
	END
	ELSE
	BEGIN
		DECLARE @CurrentFinanceManagerID TIdentifier
		SELECT @CurrentFinanceManagerID = [FinanceManagerEmployeeID]
		FROM
			[Project]
		WHERE
			[ID] = @ProjectID

		SET @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @CurrentFinanceManagerID)
		
		IF (@AssignmentID IS NOT NULL)
			UPDATE [Assignment] 
			SET
				[FinanceManagement] = 0
			WHERE
				[ID] = @AssignmentID
	END
	
    UPDATE [Project]
    SET 
		[FinanceManagerEmployeeID] = @EmployeeID,
		[ModifiedBy] = dbo.adfGetCurrentUserID()
    WHERE
		[Project].ID=@ProjectID

	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END

	RETURN 0
GO

GRANT EXECUTE ON [pjm7ChangeFinanceManager] TO PUBLIC
GO
