IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectBrowseSelectorDialog]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectBrowseSelectorDialog'
		DROP PROCEDURE [dbo].[pjm5ProjectBrowseSelectorDialog]
	END
GO

PRINT 'Creating procedure pjm5ProjectBrowseSelectorDialog'
GO

/******************************************************************************
**		File: ProjectBrowseSelectorDialog.sql
**		Name: pjm5ProjectBrowseSelectorDialog
**		Desc:       , 
**		             
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      	----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------
**    	24.03.09	ENB			    
**								 
**
**		01.07.10	KOV			   
**		25.07.13	SAP			    
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectBrowseSelectorDialog]
	@EmployeeID TIdentifier,
	@OnlyActive bit,
	@ContractOnly bit,
	@OnlyProjectMember bit,
	@ProjectState int = 2,
	@ProjectSelector bit = 0,
	@SupportsRequestManagement bit
AS
	SET NOCOUNT ON

DECLARE @ProjectClass TClass
SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')
	
IF(@ProjectState < 10)
SELECT DISTINCT
		[Project].[ID],
		[Project].[Class],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		CASE @ContractOnly
			WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
			ELSE [Project].[FileAs]
		END AS [FileAs],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Employee].[FileAs] AS [Manager],
		[Supplier].[FileAs] AS [Supplier],
		[Customer].[FileAs] AS [Customer]
	FROM
		[Project]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Company] AS [Supplier]
			ON [Supplier].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Company] AS [Customer]
			ON [Customer].[ID] = [Project].[CustomerCompanyID]
		INNER JOIN 
		dbo.fnPjm6GetAvailableProjectsForProjectSelectorDialog (
			@EmployeeID,
			@OnlyActive,
			@ContractOnly,
			@OnlyProjectMember,
			@ProjectState,
			@ProjectSelector,
			@SupportsRequestManagement) AS [AvialableProject]
		ON [Project].[ID] = [AvialableProject].[ID]

ELSE
BEGIN
	IF(@ProjectState = 11)	
		SELECT DISTINCT
				[Project].[ID],
				[Project].[Class],
				[Project].[State],
				[Project].[Flag],
				[Project].[Date],
				[Project].[Number],
				CASE @ContractOnly
					WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
					ELSE [Project].[FileAs]
				END AS [FileAs],
				[Project].[SupplierCompanyID],
				[Project].[ProjectManagerEmployeeID],
				[Project].[CustomerCompanyID],
				[Project].[CustomerFinanceManagerID],
				[Project].[ResponsiblePersonEmployeeID],
				[Project].[Created],
				[Project].[CreatedBy],
				[Project].[Modified],
				[Project].[ModifiedBy],
				[Project].[Timestamp],
				[Employee].[FileAs] AS [Manager],
				[Supplier].[FileAs] AS [Supplier],
				[Customer].[FileAs] AS [Customer],
				[LastDocument].[TimeStamp] 
			FROM
				[Project]
				INNER JOIN [LastDocument] 
					ON [LastDocument].[EmployeeID] = @EmployeeID AND 
					[LastDocument].[DocumentClass] = @ProjectClass AND
					[Project].[ID] = [LastDocument].[DocumentID]
				LEFT OUTER JOIN [Employee]
					ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
				LEFT OUTER JOIN [Company] AS [Supplier]
					ON [Supplier].[ID] = [Project].[SupplierCompanyID]
				LEFT OUTER JOIN [Company] AS [Customer]
					ON [Customer].[ID] = [Project].[CustomerCompanyID]
			WHERE [Project].[SupportsRequestManagement] = 1
			ORDER BY [LastDocument].[TimeStamp] 

	ELSE
		SELECT DISTINCT
			[Project].[ID],
			[Project].[Class],
			[Project].[State],
			[Project].[Flag],
			[Project].[Date],
			[Project].[Number],
			CASE @ContractOnly
				WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
				ELSE [Project].[FileAs]
			END AS [FileAs],
			[Project].[SupplierCompanyID],
			[Project].[ProjectManagerEmployeeID],
			[Project].[CustomerCompanyID],
			[Project].[CustomerFinanceManagerID],
			[Project].[ResponsiblePersonEmployeeID],
			[Project].[Created],
			[Project].[CreatedBy],
			[Project].[Modified],
			[Project].[ModifiedBy],
			[Project].[Timestamp],
			[Employee].[FileAs] AS [Manager],
			[Supplier].[FileAs] AS [Supplier],
			[Customer].[FileAs] AS [Customer],
			[LastDocument].[TimeStamp] 
		FROM
			[Project]
			INNER JOIN [LastDocument] 
				ON [LastDocument].[EmployeeID] = @EmployeeID AND 
				[LastDocument].[DocumentClass] = @ProjectClass AND
				[Project].[ID] = [LastDocument].[DocumentID]
				AND
				[Project].[State] <> 4
			LEFT OUTER JOIN [Employee]
				ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
			LEFT OUTER JOIN [Company] AS [Supplier]
				ON [Supplier].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Company] AS [Customer]
				ON [Customer].[ID] = [Project].[CustomerCompanyID]
		ORDER BY [LastDocument].[TimeStamp] 
END	 
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5ProjectBrowseSelectorDialog] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ContractBrowseSelectorDialog]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ContractBrowseSelectorDialog'
		DROP PROCEDURE [dbo].[pjm5ContractBrowseSelectorDialog]
	END
GO

PRINT 'Creating procedure pjm5ContractBrowseSelectorDialog'
GO

/******************************************************************************
**		File: ProjectBrowseSelectorDialog.sql
**		Name: pjm5ContractBrowseSelectorDialog
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5ContractBrowseSelectorDialog]
	@ContractNumber varchar(256),
	@Number varchar(256),
	@Manager varchar(256),
	@Customer varchar(256)
AS
	SET NOCOUNT ON

	DECLARE
		@ViewAllProjects bit,
		@EmployeeID TIdentifier
		
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
		
	SELECT DISTINCT
		[Project].[ID],
		[Project].[Class],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Employee].[FileAs] AS [Manager],
		[Supplier].[FileAs] AS [Supplier],
		[Customer].[FileAs] AS [Customer]
	FROM
		[Project]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Company] AS [Supplier]
			ON [Supplier].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Company] AS [Customer]
			ON [Customer].[ID] = [Project].[CustomerCompanyID]
		
	WHERE
		[Project].[State] IN (1, 2) AND
		[Project].[ProjectTypeID] = 1 AND
		(
			@ViewAllProjects = 1 OR [Project].[ProjectManagerEmployeeID] = @EmployeeID
		) AND
		(
			@ContractNumber IS NULL OR [Project].[ContractNumber] LIKE @ContractNumber
		) AND
		(
			@Number IS NULL OR [Project].[Number] LIKE @Number
		) AND
		(
			@Manager IS NULL OR ISNULL([Employee].[FileAs], '') LIKE @Manager
		) AND
		(
			@Customer IS NULL OR ISNULL([Customer].[FileAs], '') LIKE @Customer
		)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5ContractBrowseSelectorDialog] TO PUBLIC
GO



IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectRequestBrowseSelectorDialog]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectRequestBrowseSelectorDialog'
		DROP PROCEDURE [dbo].[pjm5ProjectRequestBrowseSelectorDialog]
	END
GO

