﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6SubProjectBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6SubProjectBrowse'
		DROP PROCEDURE [dbo].[pjm6SubProjectBrowse]
	END
GO

PRINT 'Creating procedure pjm6SubProjectBrowse'
GO

/******************************************************************************
**		File: SubProjectBrowse.sql
**		Name: pjm6SubProjectBrowse
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**		----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 22.06.2011 11:33:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------
**		13.03.13	SOV			Добавлен необязательный параметр для учета возможности 
**								внесения линий в калькуляцию в подпроекте
**		22.04.13	SOV			При выборе подпроектов для калькуляций учитываются признаки
**								применения НДС и валюта основного проекта
**		07.05.13	SOV			Добавлена выборка ID фин. мен-ра и пом. рук-ля проекта
*******************************************************************************/
CREATE PROCEDURE [pjm6SubProjectBrowse]
	@ParentProjectID	TIdentifier,
	@StateSelector		INT,
	@CanCreateCalculation TBool = 0
AS
	
	DECLARE @ApplyVAT TBool,
			@RatesWithVAT TBool,
			@CurrencyCode TCode3

	-- Для учета применения НДС и валюты в основном проекте для калькуляций
	IF @CanCreateCalculation = 1 
	BEGIN
		SELECT
			@ApplyVAT = [ApplyVAT],
			@RatesWithVAT = [RatesWithVAT],
			@CurrencyCode = [CurrencyCode]
		FROM
			[Project]
		WHERE
			[ID] = @ParentProjectID
	END
			
	;WITH SubProjects ([ProjectID], [ParentProjectID], [FileAs], [Level]) AS
	(
	SELECT [ID], NULL, [FileAs], 1
	FROM
		[Project]
	WHERE
		[ID] = @ParentProjectID
	UNION ALL
	SELECT [Task].[SubProjectID], [Task].[ProjectID], [Task].[FileAs], [Level] + 1
	FROM [Task]
		INNER JOIN SubProjects
			ON [Task].[ProjectID] = SubProjects.[ProjectID]
	WHERE
		[Task].[SubProjectID] IS NOT NULL
	)
	
	
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[ProjectDetail].[PlannedManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1
			THEN [ProjectDetail].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[ExchangeSystemName],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		(CASE WHEN [SubProjects].[Level] = 2 THEN NULL ELSE [SubProjects].[ParentProjectID] END) AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN fnPjm6GetAvailableProjectsForSubProjectBrowse(0, NULL, NULL, @CanCreateCalculation) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]
		INNER JOIN SubProjects AS [SubProjects]
			ON [SubProjects].[ProjectID] = [Project].[ID] AND  [ParentProjectID] IS NOT NULL
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
	WHERE
		(@CanCreateCalculation = 0 OR 
			(
				[Project].[ApplyVAT] = @ApplyVAT AND [Project].[RatesWithVAT] = @RatesWithVAT AND
					[Project].[CurrencyCode] = @CurrencyCode
			)
		) AND		
		((@StateSelector  = 0 AND [Project].[State] NOT IN (5, 6)) OR 
		(@StateSelector != 0 AND [Project].[State] = @StateSelector))
		
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm6SubProjectBrowse] TO PUBLIC
GO
