﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[ReportExcelCompensation]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure ReportExcelCompensation'
		DROP PROCEDURE [dbo].[ReportExcelCompensation]
	END
GO

PRINT 'Creating procedure ReportExcelCompensation'
GO

/******************************************************************************
**		File: ReportExcelCompensation.sql
**		Name: ReportExcelCompensation
**		Desc: Excel Report
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey.Averkiev
**		Date: 15.02.2012 11:11:11
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		СНЛ - скидка, наценка, лимит
**		01.10.12	SOV				Существование 2-х и более актов в одном месяце
**									по одному счету теперь не вызывает ошибку
**		11.09.13	SAP				Исправлена дата окончания при построении отчета
**									за период
*******************************************************************************/
CREATE PROCEDURE ReportExcelCompensation
	@DateSelector INT,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS

	IF dbo.adfHasAccessRightByName('ViewCompensations') = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE
		@language TCode,
		@timeClass TClass,
		@expenseClass TClass,
		@phoneClass TClass,
		@requestClass TClass,
		@calculationClass TClass,
		@paymentClass TClass,
		@employeeClass TClass,
		@StatementID TIdentifier, 
		@PaymentID TIdentifier,
		@PaymentDate TDate,
		@PaymentDetailTotalBC TMoney, 
		@StatementExpenses TMoney,
		@statementClass TClass,
		@paidBefore TMoney,
		@CurrencyCode TCode3,
		@Date TDate,
		@ErrorMessage varchar(max),
		@InvoiceID TIdentifier,
		@val TVariant,
		@CalcID TIdentifier

	SET @language = dbo.adfGetLanguage()
	SET @CurrencyCode = dbo.fnPjm5GetBaseCurrency()
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@expenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	SET	@phoneClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET	@calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET @requestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET @statementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET @paymentClass = dbo.adfGetClassByName('Adf.Payment')
	SET @employeeClass = dbo.adfGetClassByName('Adf.Employee')
	
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	IF @DateSelector = 0				--previous month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodStart = DATEADD(month, -1, @PeriodStart),
		@PeriodEnd = DATEADD(month, 1, @PeriodStart),
		@PeriodEnd = DATEADD(day, -1, @PeriodEnd)
	ELSE IF @DateSelector = 1			--current month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodEnd = DATEADD(month, 1, @PeriodStart),
		@PeriodEnd = DATEADD(day, -1, @PeriodEnd)
	ELSE
	SELECT
		@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
		@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime)

	--Суммы платежей
	DECLARE @PaymentPart TABLE
	(
		[StatementID] TIdentifier, 
		[InvoiceID] TIdentifier,
		[PaymentID] TIdentifier,
		[StatementDate] TDate,
		[StatementNumber] TCode,
		[StatementFileAs] TName,
		[StatementProjectID] TIdentifier,
		[StatementPeriodStart] TDate,
		[StatementPeriodEnd] TDate,
		[StatementSupplierCompanyID] TIdentifier,
		[StatementCustomerCompanyID] TIdentifier,
		[StatementTotalBC] TMoney,
		[InvoiceDate] TDate,
		[InvoiceNumber] TCode,
		[InvoiceFileAs] TName,
		[InvoiceAdvance] TBool,
		[InvoiceTotalBC] TMoney,
		[PaymentDetailTotalBC] TMoney,
		[PaymentDate] TDate,
		[StatementPaidBefore] TMoney,
		[StatementExpenses] TMoney,
		[ID] TIdentifier,	--ID платежа
		[State]	TState,		--State платежа
		[CalculataionTimeTotal] TMoney,
		[FileAs] TName
	)

	--Акты, связанные со счетами на постоплату
	DECLARE @temp TABLE
	(
		[StatementID] TIdentifier
	)

	DECLARE @temp2 TABLE --Связь Акт -> Счет
	(
		[StatementID] TIdentifier,
		[InvoiceID] TIdentifier
	)

	DECLARE @temp3 TABLE
	(
		[InvoiceID] TIdentifier
	)

	DECLARE @temp4 TABLE --Связь Счет -> Акт
	(
		[StatementID] TIdentifier,
		[InvoiceID] TIdentifier
	)
	
	DECLARE @temp5 TABLE --Временная таблица для просмотра ошибочной ситуации дублирования счетов
	(
		[InvoiceID] TIdentifier,
		[PaymentID] TIdentifier
	)

	DECLARE @TStatementID TABLE
	(
		[StatementID] TIdentifier
	)
	--Связь актов с калькуляциями
	DECLARE @TCalculationID TABLE
	(
		[StatementID] TIdentifier,
		[CalculationID] TIdentifier,
		[CalculationDocumentClass] TClass,
		[CalculationCurrencyCode] TCode3,
		[CalculationTotal] TMoney,
		[CalculationTotalWithoutDiscount] TMoney,
		[CalculationDiscountType] TIdentifier,
		[CalculationDiscountPercent] TPercent,
		[CalculationDiscount] TMoney,
		[StatementDate] TDate,
		[StatementBaseCurrencyRate] TMoney,
		[ProjectCurrencyCode] TCode
	)

	DECLARE @CalculationTotal TABLE
	(
		[StatementID] TIdentifier, 
		[InvoiceID] TIdentifier,
		[PaymentID] TIdentifier,
		[Initials] TCode,
		[Total] TMoney,
		[IsSenior] TPropertyValue
	)

	DECLARE @tempTotal TABLE
	(
		[StatementID] TIdentifier, 
		[EmployeeID] TIdentifier,
		[Total] TMoney
	)

	DECLARE @TPeriod TABLE
	(
		[PeriodStart] TDate,
		[PeriodEND] TDate,
		[CurrencyCode] TCode
	)

	DECLARE @TEmployee TABLE
	(
		[Initials] TCode,
		[IsSenior] TPropertyValue,
		[EmployeeID] TIdentifier
	)

	DECLARE @ExeptionDoubleInvoice TABLE
	(
		[InvoiceID] TIdentifier
	)

	DECLARE @ExeptionFutureInvoice TABLE
	(
		[InvoiceID] TIdentifier
	)

	DECLARE @ExeptionNoLink TABLE
	(
		[InvoiceID] TIdentifier
	)

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrency TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @val OUTPUT
	SET @BaseCurrencyCode = CAST(@val as varchar(3))

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrency = CAST(@val AS varchar(8))

	INSERT INTO @TPeriod ([PeriodStart], [PeriodEnd], [CurrencyCode]) VALUES (@PeriodStart, @PeriodEnd, @CurrencyCode)
	
	--Все неавансовые счета на постоплату (связанные с актом)
	INSERT INTO @temp2	
	SELECT
		[Statement].[ID],
		[Invoice].[ID]
	FROM [Statement]
		INNER JOIN [Attachment] ON [Attachment].[DocumentClass] = [Statement].[Class] AND [Attachment].[DocumentID] = [Statement].[ID]
		INNER JOIN [Invoice] ON [Attachment].[LinkDocumentClass] = [Invoice].[Class] AND [Invoice].[ID] = [Attachment].[LinkDocumentID]
		INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		[Invoice].[Advance] = 0
	AND
		([Payment].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
	AND
		([Statement].[State] NOT IN (1,4)) AND ([Invoice].[State] NOT IN (1,3,6,7)) AND ([Payment].[State] NOT IN (1,4))

	INSERT INTO @temp4	
	SELECT
		[Statement].[ID],
		[Invoice].[ID]
	FROM [Invoice]
		INNER JOIN [Attachment] ON [Attachment].[DocumentClass] = [Invoice].[Class] AND [Attachment].[DocumentID] = [Invoice].[ID]
		INNER JOIN [Statement] ON [Attachment].[LinkDocumentClass] = [Statement].[Class] AND [Statement].[ID] = [Attachment].[LinkDocumentID]
		INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		[Invoice].[Advance] = 0
	AND
		([Payment].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
	AND
		([Statement].[State] NOT IN (1,4)) AND ([Invoice].[State] NOT IN (1,3,6,7)) AND ([Payment].[State] NOT IN (1,4))

	--Все неавансовые счета на постоплату (в том числе и без связки с актом)
	INSERT INTO @temp3	
	SELECT
		[Invoice].[ID]
	FROM 
		[Invoice]
		INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		[Invoice].[Advance] = 0
	AND
		([Payment].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
	AND
		([Invoice].[State] NOT IN (1,3,6,7)) AND ([Payment].[State] NOT IN (1,4))

	--Выбор всех актов, связанных со счетами на постоплату, чтобы получить по ним все суммы платежей.
	INSERT INTO @temp
	SELECT
		[StatementID]
	FROM
		@temp2
	GROUP BY 
		[StatementID]

	--Добавление всех сумм платежей, связанных со счетами на постоплату
	INSERT INTO @PaymentPart
	SELECT
		[Statement].[ID],
		[Invoice].[ID],
		[PaymentDetail].[ID],
		[Statement].[Date],
		[Statement].[Number],
		[Statement].[FileAs],
		[Statement].[ProjectID],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		[Statement].[SupplierCompanyID],
		[Statement].[CustomerCompanyID],
		[Statement].[TotalBC],
		[Invoice].[Date],
		[Invoice].[Number],
		[Invoice].[FileAs],
		[Invoice].[Advance],
		[Invoice].[TotalBC],
		CASE 
			WHEN [Payment].[CurrencyCode] = @NationalCurrency
			THEN ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) / [Payment].[BaseCurrencyRate]
			ELSE ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) * [Payment].[BaseCurrencyRate]
		END,
		[Payment].[Date],
		0,
		0,
		[Payment].[ID],
		[Payment].[State],
		0,
		[Payment].[FileAs]
	FROM [Statement]
	INNER JOIN [Attachment] ON [Attachment].[DocumentClass] = [Statement].[Class] AND [Attachment].[DocumentID] = [Statement].[ID]
	INNER JOIN [Invoice] ON [Attachment].[LinkDocumentClass] = [Invoice].[Class] AND [Invoice].[ID] = [Attachment].[LinkDocumentID]
	INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		[Invoice].[Advance] = 0
	AND
		(
			([Statement].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
			OR
			([Statement].[ID] IN (SELECT [StatementID] FROM @temp))
		)
	AND
		([Statement].[State] NOT IN (1,4)) AND ([Invoice].[State] NOT IN (1,3,6,7)) AND ([Payment].[State] NOT IN (1,4))
	UNION
		SELECT
		[Statement].[ID],
		[Invoice].[ID],
		[PaymentDetail].[ID],
		[Statement].[Date],
		[Statement].[Number],
		[Statement].[FileAs],
		[Statement].[ProjectID],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		[Statement].[SupplierCompanyID],
		[Statement].[CustomerCompanyID],
		[Statement].[TotalBC],
		[Invoice].[Date],
		[Invoice].[Number],
		[Invoice].[FileAs],
		[Invoice].[Advance],
		[Invoice].[TotalBC],
		CASE 
			WHEN [Payment].[CurrencyCode] = @NationalCurrency
			THEN ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) / [Payment].[BaseCurrencyRate]
			ELSE ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) * [Payment].[BaseCurrencyRate]
		END,
		[Payment].[Date],
		0,
		0,
		[Payment].[ID],
		[Payment].[State],
		0,
		[Payment].[FileAs]
	FROM [Statement]
	INNER JOIN [Attachment] ON [Attachment].[LinkDocumentClass] = [Statement].[Class] AND [Attachment].[LinkDocumentID] = [Statement].[ID]
	INNER JOIN [Invoice] ON [Attachment].[DocumentClass] = [Invoice].[Class] AND [Invoice].[ID] = [Attachment].[DocumentID]
	INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		[Invoice].[Advance] = 0
	AND
		(
			[Statement].[ID] NOT IN (SELECT [StatementID] FROM @temp)
		)
	AND
		(
			([Statement].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
			OR
			([Statement].[ID] IN (SELECT [StatementID] FROM @temp4))
		)
	AND
		([Statement].[State] NOT IN (1,4)) AND ([Invoice].[State] NOT IN (1,3,6,7)) AND ([Payment].[State] NOT IN (1,4))
	
	--Акты, вошедшие в отчетный период, либо связанные с платежами (по счетам на постоплату), вошедшими в отчетный период
	INSERT INTO @TStatementID
	SELECT 
		[StatementID]
	FROM @PaymentPart

	--Добавление всеx сумм, связанных с авансовыми счетами (в том числе для актов, не вошедших в отчетный период, но с которыми связаны платежи по счетам на постоплату)
	INSERT INTO @PaymentPart
	SELECT
		[Statement].[ID],
		[Invoice].[ID],
		[PaymentDetail].[ID],
		[Statement].[Date],
		[Statement].[Number],
		[Statement].[FileAs],
		[Statement].[ProjectID],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		[Statement].[SupplierCompanyID],
		[Statement].[CustomerCompanyID],
		[Statement].[TotalBC] TMoney,
		[Invoice].[Date],
		[Invoice].[Number],
		[Invoice].[FileAs],
		[Invoice].[Advance],
		[Invoice].[TotalBC] AS [InvoiceTotalBC],
		CASE 
			WHEN [Payment].[CurrencyCode] = @NationalCurrency	--[Invoice].[CurrencyCode] = @NationalCurrency
			THEN ([StatementAdvanceInvoice].[StatementPaymentValue] - [StatementAdvanceInvoice].[StatementPaymentVAT]) / [Payment].[BaseCurrencyRate]
			ELSE ([StatementAdvanceInvoice].[StatementPaymentValue] - [StatementAdvanceInvoice].[StatementPaymentVAT]) * [Payment].[BaseCurrencyRate]
		END,
		/*		
		CASE 
			WHEN [Payment].[CurrencyCode] = @NationalCurrency
			THEN ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) / [Payment].[BaseCurrencyRate]
			ELSE ([PaymentDetail].[PaymentValue] - [PaymentDetail].[PaymentVAT]) * [Payment].[BaseCurrencyRate]
		END,
		*/
		[Payment].[Date],
		0,
		0,
		[Payment].[ID],
		[Payment].[State],
		0,
		[Payment].[FileAs]
	FROM [Statement]
	INNER JOIN [StatementAdvanceInvoice] ON [StatementAdvanceInvoice].[StatementID] = [Statement].[ID] 
	INNER JOIN [Invoice] ON [Invoice].[ID] = [StatementAdvanceInvoice].[AdvanceInvoiceID]
	INNER JOIN [PaymentDetail] ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	INNER JOIN [Payment] ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE 
		(([Statement].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
	OR
		([Statement].[ID] IN (SELECT [StatementID] FROM @TStatementID)))
	AND
		[Statement].[State] NOT IN (1,4) AND [Invoice].[State] NOT IN (1,3,6,7) AND [Payment].[State] NOT IN (1,4)

	/*---Блок обработки некорректных ситуаций---*/

	INSERT INTO @ExeptionFutureInvoice
		SELECT [InvoiceID] FROM @PaymentPart WHERE [InvoiceAdvance] = 1 AND [PaymentDate] > [StatementDate]

	INSERT INTO @temp5 
		SELECT [InvoiceID], [PaymentID] FROM @PaymentPart WHERE [InvoiceAdvance] = 1 GROUP BY [InvoiceID], [PaymentID]

	INSERT INTO @ExeptionDoubleInvoice
		SELECT [InvoiceID] FROM @temp5 GROUP BY [InvoiceID] HAVING COUNT(*) > 1

	INSERT INTO @ExeptionNoLink
		SELECT [InvoiceID] 
	FROM
		@temp3
	WHERE
		[InvoiceID] NOT IN (SELECT [InvoiceID] FROM @temp2)
		AND [InvoiceID] NOT IN (SELECT [InvoiceID] FROM @temp4)

	IF EXISTS (SELECT * FROM @ExeptionFutureInvoice)
	BEGIN
		IF(@language = 'en')
			SET @ErrorMessage = 'There are some overdued payments related to following invoices: '
		ELSE
			SET @ErrorMessage = 'По следующим авансовым счетам производились платежи после закрытия работ актом: '	

		DECLARE invoiceCursor CURSOR FOR
		SELECT [InvoiceID] FROM @ExeptionFutureInvoice
		OPEN invoiceCursor
			FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			WHILE @@fetch_status = 0 
			BEGIN
				SET @ErrorMessage = 
					@ErrorMessage + CAST((SELECT [Number] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID) AS varchar(32)) + ' от ' + 
					CAST(CONVERT(varchar(20),(SELECT [Date] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID), 105) AS varchar(32)) + '; '
				FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			END
		CLOSE invoiceCursor
		DEALLOCATE invoiceCursor

		RAISERROR(@ErrorMessage, 18, -1)
		RETURN 1
	END

	IF EXISTS (SELECT * FROM @ExeptionDoubleInvoice)
	BEGIN
		IF(@language = 'en')
			SET @ErrorMessage = 'Folowing advance invoices have multiple payments: '
		ELSE
			SET @ErrorMessage = 'По следующим авансовым счетам было произведено несколько платежей: '

		DECLARE invoiceCursor CURSOR FOR
		SELECT [InvoiceID] FROM @ExeptionDoubleInvoice
		OPEN invoiceCursor
			FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			WHILE @@fetch_status = 0 
			BEGIN
				SET @ErrorMessage = 
					@ErrorMessage + CAST((SELECT [Number] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID) AS varchar(32)) + ' от ' + 
					CAST(CONVERT(varchar(20),(SELECT [Date] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID), 105) AS varchar(32)) + '; '
				FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			END
		CLOSE invoiceCursor
		DEALLOCATE invoiceCursor

		RAISERROR(@ErrorMessage, 18, -1)
		RETURN 1
	END

	IF EXISTS (SELECT * FROM @ExeptionNoLink)
	BEGIN
		IF(@language = 'en')
			SET @ErrorMessage = 'Folowing invoices does not linked to statement: '
		ELSE
			SET @ErrorMessage = 'У следующих счетов отсутствует ссылка на акт: '

		DECLARE invoiceCursor CURSOR FOR
		SELECT [InvoiceID] FROM @ExeptionNoLink
		OPEN invoiceCursor
			FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			WHILE @@fetch_status = 0 
			BEGIN
				SET @ErrorMessage = 
					@ErrorMessage + CAST((SELECT [Number] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID) AS varchar(32)) + ' от ' + 
					CAST(CONVERT(varchar(20),(SELECT [Date] FROM [Invoice] WHERE [Invoice].[ID] = @InvoiceID), 105) AS varchar(32)) + '; '
				FETCH NEXT FROM invoiceCursor INTO @InvoiceID
			END
		CLOSE invoiceCursor
		DEALLOCATE invoiceCursor

		RAISERROR(@ErrorMessage, 18, -1)
		RETURN 1
	END
	/*---конец---*/

	--Все участвующие в расчете акты
	INSERT INTO @TStatementID
	SELECT 
		[StatementID]
	FROM @PaymentPart

	--Связь калькуляций с актами
	INSERT INTO @TCalculationID
	SELECT 
		[Statement].[ID],
		[Calculation].[ID],
		[Calculation].[DocumentClass],
		[Calculation].[CurrencyCode],
		--В учетной валюте на дату Акта
		CASE 
			WHEN [Project].[CurrencyCode] = @BaseCurrencyCode
				THEN [Calculation].[TotalPC]
			WHEN [Project].[CurrencyCode] = @NationalCurrency
				THEN [Calculation].[TotalPC] / [Statement].[BaseCurrencyRate]
			ELSE [Calculation].[TotalPC] * [Statement].[BaseCurrencyRate]
		END,
		0,
		[Calculation].[DiscountType],
		[Calculation].[DiscountPercent],
		[Calculation].[Discount],
		[Statement].[Date],
		[Statement].[BaseCurrencyRate],
		[Project].[CurrencyCode]
	FROM [Statement]
	INNER JOIN [StatementLine] ON [Statement].[ID] = [StatementLine].[StatementID]
	INNER JOIN [Calculation] ON [StatementLine].[DocumentID] = [Calculation].[ID]
	INNER JOIN [Project] ON [Statement].[ProjectID] = [Project].[ID]
	WHERE 
		[Statement].[ID] IN (SELECT [StatementID] FROM @TStatementID)
		AND [StatementLine].[DocumentClass] = @calculationClass
		AND [Calculation].[State] NOT IN (1,4)

	--Вложенные калькуляции
	INSERT INTO @TCalculationID
	SELECT 
		[TCalculationID].[StatementID],
		[Calculation].[ID],
		[Calculation].[DocumentClass],
		[Calculation].[CurrencyCode],
		--В учетной валюте на дату Акта
		CASE 
			WHEN [Project].[CurrencyCode] = @BaseCurrencyCode
				THEN [Calculation].[TotalPC]
			WHEN [Project].[CurrencyCode] = @NationalCurrency
				THEN [Calculation].[TotalPC] / (SELECT [BaseCurrencyRate] FROM [Statement] WHERE [Statement].[ID] = [TCalculationID].[StatementID])
			ELSE [Calculation].[TotalPC] * (SELECT [BaseCurrencyRate] FROM [Statement] WHERE [Statement].[ID] = [TCalculationID].[StatementID])
		END,
		0,
		[Calculation].[DiscountType],
		[Calculation].[DiscountPercent],
		[Calculation].[Discount],
		[TCalculationID].[StatementDate],
		(SELECT [BaseCurrencyRate] FROM [Statement] WHERE [Statement].[ID] = [TCalculationID].[StatementID]) AS [StatementBaseCurrency],
		[Project].[ID]
	FROM @TCalculationID AS [TCalculationID]
	INNER JOIN [CalculationAdvance] ON [TCalculationID].[CalculationID] = [CalculationAdvance].[CalculationID]
	INNER JOIN [Calculation] ON [CalculationAdvance].[AdvanceCalculationID] = [Calculation].[ID]
	INNER JOIN [Statement] ON [TCalculationID].[StatementID] = [Statement].[ID]
	INNER JOIN [Project] ON [Statement].[ProjectID] = [Project].[ID]

	DECLARE calcCursor CURSOR FOR
	SELECT [CalculationID] FROM @TCalculationID
	OPEN calcCursor
		FETCH NEXT FROM calcCursor INTO @calcID
		WHILE @@fetch_status = 0 
		BEGIN
			UPDATE @TCalculationID SET [CalculationTotalWithoutDiscount] =
			(
				SELECT SUM([CalculationLine].[Amount] * [CalculationLine].[Price])
				FROM @TCalculationID AS [TCalculationID]
				INNER JOIN [CalculationLine] ON [TCalculationID].[CalculationID] = [CalculationLine].[CalculationID]
				WHERE [TCalculationID].[CalculationID] = @calcID
			)
			WHERE [CalculationID] = @calcID
			FETCH NEXT FROM calcCursor INTO @calcID
		END
	CLOSE calcCursor
	DEALLOCATE calcCursor
	
	/*SELECT * FROM @TCalculationID*/

	--Выработка по актам
	INSERT INTO @tempTotal
	SELECT 
		[TCalculationID].[StatementID],
		[TimeEntry].[EmployeeID],
		SUM(
			CASE 
				WHEN [TCalculationID].[ProjectCurrencyCode] = @BaseCurrencyCode
					THEN 1
				WHEN [TCalculationID].[CalculationCurrencyCode] = @NationalCurrency
					THEN 1.0 / [TCalculationID].[StatementBaseCurrencyRate] 
				ELSE 1 * [TCalculationID].[StatementBaseCurrencyRate]
			END
					* [CalculationLine].[Amount] * [CalculationLine].[Price] 
					* CASE [TCalculationID].[CalculationDiscountType]
						WHEN 1 THEN (1 - [TCalculationID].[CalculationDiscountPercent])
						WHEN 2 THEN (1 +  [TCalculationID].[CalculationDiscountPercent])
						WHEN 3 THEN 
							CASE 
							WHEN [TCalculationID].[CalculationTotalWithoutDiscount] 
									> [TCalculationID].[CalculationDiscount] THEN [TCalculationID].[CalculationDiscountPercent]
							ELSE 1
							END
						ELSE 1
						END) AS [Total]			--Выработка с учетом СНЛ
	FROM @TCalculationID AS [TCalculationID]
		INNER JOIN [CalculationLine] ON [TCalculationID].[CalculationID] = [CalculationLine].[CalculationID]
		INNER JOIN [TimeEntry] ON [CalculationLine].[DocumentID] = [TimeEntry].[ID]
		--INNER JOIN [Employee] ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	WHERE [TCalculationID].[CalculationDocumentClass] = @timeClass
	GROUP BY [TCalculationID].[StatementID], [TimeEntry].[EmployeeID]

	--Все участвующие сотрудники
	INSERT INTO @TEmployee
	SELECT 
		ISNULL([Employee].[Initials], [Employee].[FileAs]) AS [Initials],
		ISNULL([PropertyValue].[Value],'Нет') AS [IsSenior],
		[tempTotal].[EmployeeID] AS [EmployeeID]
	FROM @tempTotal AS [tempTotal]
		INNER JOIN [Employee] ON [tempTotal].[EmployeeID] = [Employee].[ID]
		INNER JOIN [Property] ON [Employee].[Class] = [Property].[Class]
		LEFT OUTER JOIN [PropertyValue] ON [Property].[ID] = [PropertyValue].[PropertyID] AND [PropertyValue].[DocumentID] = [Employee].[ID]
	GROUP BY [tempTotal].[EmployeeID], [Employee].[Initials], [Employee].[FileAs], [Property].[Name], [PropertyValue].[Value]
	HAVING [Property].[Name] like 'Старший партнер'

	IF NOT EXISTS(SELECT * FROM @TEmployee)
	BEGIN
		INSERT INTO @TEmployee
		SELECT 
			ISNULL([Employee].[Initials], [Employee].[FileAs]) AS [Initials], 
			'Нет' AS [IsSenior],
			[Employee].[ID] AS [EmplyeeID]
		FROM @tempTotal AS [tempTotal]
		INNER JOIN [Employee] ON [tempTotal].[EmployeeID] = [Employee].[ID]
		GROUP BY [Employee].[ID], [Employee].[Initials], [Employee].[FileAs]
	END

	--Формирование таблицы CalculationTotal
	INSERT INTO @CalculationTotal
	SELECT 
		[PaymentPart].[StatementID] TIdentifier, 
		[PaymentPart].[InvoiceID] TIdentifier,
		[PaymentPart].[PaymentID] TIdentifier,
		[TEmployee].[Initials],
		ISNULL([tempTotal].[Total], 0),
		[TEmployee].[IsSenior]
	FROM @PaymentPart AS [PaymentPart]
		CROSS JOIN @TEmployee AS [TEmployee]
		LEFT OUTER JOIN @tempTotal AS [tempTotal] 
			ON [PaymentPart].[StatementID] = [tempTotal].[StatementID] AND [TEmployee].[EmployeeID] = [tempTotal].[EmployeeID]

	--Расчет колонки Оплачено ранее
	DECLARE paymentCursor CURSOR FOR
		SELECT [StatementID], [PaymentID], [PaymentDate], [PaymentDetailTotalBC], [StatementExpenses] FROM @PaymentPart
	OPEN paymentCursor
	FETCH NEXT FROM paymentCursor INTO @StatementID, @PaymentID, @PaymentDate, @PaymentDetailTotalBC, @StatementExpenses
	WHILE @@fetch_status = 0 
	BEGIN
		--Затраты по акту
		UPDATE @PaymentPart 
		SET [StatementExpenses] = 
		(ISNULL(
			(
				SELECT SUM([CalculationTotal]) --В учетной валюте на дату Акта
				FROM @TCalculationID
				WHERE [CalculationDocumentClass] IN (@expenseClass, @phoneClass)
				GROUP BY [StatementID]
				HAVING [StatementID] = @StatementID 
			)
			,0)
		)
		WHERE [StatementID] = @StatementID 

		--Оплачено до текущего платежа
		SET @paidBefore = 
		(
			SELECT SUM([PaymentDetailTotalBC])
			FROM @PaymentPart
			WHERE	[StatementID] = @StatementID AND 
					([PaymentDate] < @PaymentDate OR ([PaymentDate] = @PaymentDate AND [PaymentID] < @PaymentID))
		)
		
		IF (@paidBefore IS NULL) SET @paidBefore = 0

		UPDATE @PaymentPart 
		SET [StatementPaidBefore] = 
		(
			@paidBefore
		)
		WHERE
			[PaymentID] = @PaymentID
		FETCH NEXT FROM paymentCursor INTO @StatementID, @PaymentID, @PaymentDate, @PaymentDetailTotalBC, @StatementExpenses
	END
	CLOSE paymentCursor
	DEALLOCATE paymentCursor

	--Итоговая выборка линий
	SELECT 
		[PaymentID],	
		[Company].[FileAs] AS [CustomerFileAs],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectCode],
		[PaymentDate],
		[PaymentDetailTotalBC],
		[InvoiceID],
		[InvoiceNumber],
		[InvoiceDate],
		[InvoiceTotalBC],
		[InvoiceAdvance],
		[StatementID],
		[StatementNumber],
		[StatementDate],
		[StatementTotalBC],
		[StatementPeriodStart],
		[StatementPeriodEnd],
		[StatementPaidBefore], 
		[StatementExpenses],
		ISNULL((SELECT SUM([Total]) FROM @tempTotal GROUP BY [StatementID] HAVING [StatementID] = [PaymentPart].[StatementID]),0) AS [CalculationTimeTotal],
		[PaymentPart].[ID],
		[PaymentPart].[State],
		@paymentClass AS [Class],
		[PaymentPart].[FileAs] AS [FileAs]
	FROM 
		@PaymentPart AS [PaymentPart]
		INNER JOIN [Project] ON [PaymentPart].[StatementProjectID] = [Project].[ID]
		INNER JOIN [Company] ON [PaymentPart].[StatementCustomerCompanyID] = [Company].[ID]
	WHERE 
			(([InvoiceAdvance] = 1 AND [PaymentDate] <= [StatementDate] AND ([StatementDate] BETWEEN @PeriodStart AND @PeriodEnd))
		OR
			([InvoiceAdvance] = 0 AND ([PaymentDate] BETWEEN @PeriodStart AND @PeriodEnd)))
	ORDER BY 
		[Company].[FileAs],[Project].[Number], [PaymentDate], [InvoiceNumber], [PaymentID]

	SELECT
		[PeriodStart],
		[PeriodEnd],
		[CurrencyCode]
	FROM @TPeriod

	SELECT 
		[Initials],
		[IsSenior]
	FROM @TEmployee AS [TEmployee]
	ORDER BY [TEmployee].[IsSenior], [TEmployee].[Initials]

	SELECT 
		[PaymentID],
		[InvoiceID],
		[StatementID],
		[Initials],
		[Total]
	FROM @CalculationTotal AS [CalculationTotal]
	ORDER BY [CalculationTotal].[IsSenior], [CalculationTotal].[Initials]

	RETURN 0
GO

GRANT EXECUTE ON ReportExcelCompensation TO PUBLIC
GO