IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportBillOfProjectHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportBillOfProjectHeader'
		DROP  Procedure  ReportBillOfProjectHeader
	END

GO

PRINT 'Creating Procedure ReportBillOfProjectHeader'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportBillOfProjectHeader
	@ProjectID		TIdentifier,
	@Date			TDatetime
AS
	SET NOCOUNT ON
	DECLARE
		@UserID				TIdentifier,
		@UserName			TName,
		@Approved			decimal(18,2),
		@Rate				decimal(18,2),
		@TimeEntryHours		decimal(18,2),
		@TimeEntrySum		decimal(18,2),
		@NotApprovedHours	decimal(18,2),
		@NotApprovedSum		decimal(18,2),
		@value			TVariant,
		@WorkTime		decimal(18,2)
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
				
	SET @UserID = dbo.adfGetCurrentUserID()
		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	SELECT
		@TimeEntryHours = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0)), 0) - ISNULL(SUM(ISNULL([BillableDuration] / 60.00,0) * ISNULL([Billable], 0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date AND
		[State] IN (2, 3, 6) --3: 6:  	
		
	SELECT
		@TimeEntrySum = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0) * ISNULL([Rate],0)), 0) - ISNULL(SUM(ISNULL([BillableDuration] / 60.00,0) * ISNULL([Billable], 0) * ISNULL([Rate],0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date AND
		[State] IN (2, 3, 6) --3: 6:  	
		
	SELECT
		@NotApprovedHours = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date AND
		[State] = 2 --2:  	
		
	SELECT
		@NotApprovedSum = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0) * ISNULL([Rate],0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date AND
		[State] = 2  --2:  		
		
	SELECT
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[SupplierCompany].[FileAs] AS [SupplierCompanyName],
		[CostCenter].[FileAs] AS [CostCenter],
		[Employee].[FileAs] AS [ManagerName],
		[CustomerCompany].[FileAs] AS [CustomerCompanyName],
		[Project].[Date] AS [StartDate],
		ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) AS [EndDate],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(GETDATE(), ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]))
			ELSE NULL
		END AS [Remains],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(ISNULL(DATEADD(day, 1, [Project].[EndDate]), DATEADD(day, 1, [ProjectDetail].[DueDate])), GETDATE())
			ELSE NULL
		END AS [Exceed],
		[Project].[State] AS [State],
		[Project].[Budget],
		[ProjectDetail].[PlannedBudget] AS [PlanBudget],
		(SELECT 
			ISNULL(SUM([BusyEntry].[Planned] * [Assignment].[StandardRate]), 0) / 60.0
		FROM 
			[BusyEntry] 
			INNER JOIN [Assignment]
				ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
		WHERE [BusyEntry].[ProjectID] = [Project].[ID] AND [BusyEntry].[Date] <= GETDATE()) AS [EstimatedBudget],
		@Date AS [Date],	
		@UserName AS [UserName],
		@TimeEntryHours AS [TimeEntryHours],
		@TimeEntrySum AS [TimeEntrySum],
		@NotApprovedHours AS [NotApprovedHours],
		@NotApprovedSum	AS [NotApprovedSum],
		[Project].[CurrencyCode] AS [CurrencyCode]	
	FROM 
		[Project]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]	
		LEFT OUTER JOIN [Employee]
			ON [Project].[ProjectManagerEmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [CostCenter]
			ON [Project].[CostCenterID] = [CostCenter].[ID]	
	WHERE
		[Project].[ID] = @ProjectID

RETURN 0
GO

GRANT EXEC ON ReportBillOfProjectHeader TO PUBLIC

GO
