IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeEfficiency')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeEfficiency'
		DROP  Procedure  ReportEmployeeEfficiency
	END
GO

PRINT 'Creating Procedure ReportEmployeeEfficiency'
GO
/******************************************************************************
**		File: ReportEmployeeEfficiency.sql
**		Name: ReportEmployeeEfficiency
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		Auth: Sergey Pelevin			Date: 18.04.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		22.04.14	SAP				  
**		25.04.14	SAP				  
**		06.05.14	SAP				 1      
**		08.05.14	SAP				  
**		15.05.14	SAP				       
**		15.05.14	SAP				   " "
**		20.05.14	SAP				   ""
**		22.05.14	SAP				      
**									//
**		23.05.14	SAP				  " 12 "
**		29.05.14	SAP				    
**		29.05.14	SAP				 ' '    		 
**		09.06.14	SAP				    
**		16.06.14	GNV				 
**		16.06.14	SAP				        
**		17.06.14	GNV				     
**		17.06.14	SAP				   
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportEmployeeEfficiency]
	@EmployeeTypeSelector int,			--   
    @WorkingEmployeeID TIdentifier,		-- ID 
    @DismissedEmployeeID TIdentifier,	-- ID 
	@CurrencySelector int,				--  (0 - , 1 - )
	@PeriodSelector int,				--  (0 -  12 , 1 -  , 2 -  , 3 -  )
	@PeriodStart date,					--   
	@PeriodEnd date,					--   
	@IncludeApproval bit,				--     (0 -  , 1 - )
	@TimeRoundingSelector int,			--   (0 -  , 1 -  )
	@ScaleSelector int,					--   (0 - , 1 - , 2 - , 3 - )
	@StateOfFinanceDocuments int		--  .  (0 -  , 1 -  , 2 -  )

AS

SET NOCOUNT ON

	--  	
	IF  dbo.adfHasAccessRightByName('ViewEmployeeEfficiencyReport') = 0 
	BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	--   , %
	DECLARE
		@CompanyAverageEfficiency int,
		@Value TVariant

	EXEC adfParameterGet 'StandardEfficiency', 'Pjm7', @Value OUTPUT
	SET @CompanyAverageEfficiency = CAST(@Value as decimal(18,2)) * 100	

	DECLARE 
		@PeriodName TName,
		@WorkingDays int,
		@CalculationClass TClass,
		@InvoiceClass TClass,
		@StatementClass TClass,
		@BaseCurrency TCode3,
        @NationalCurrency TCode3,
		@EmployeeSelector int



--////////////////////////////// 

	IF (@EmployeeTypeSelector = 0)
	BEGIN
		IF (@WorkingEmployeeID IS NULL) 
		BEGIN
			RAISERROR('#EmployeeIsNotSelected', 16, -1)
			RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeSelector = @WorkingEmployeeID
		END
	END
	ELSE
	BEGIN
		IF (@DismissedEmployeeID IS NULL) 
		BEGIN
			RAISERROR('#EmployeeIsNotSelected', 16, -1)
			RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeSelector = @DismissedEmployeeID
		END
	END


--////////////////////////////// / 
	
	
	SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')

	  
	SET @BaseCurrency = [dbo].[fnPjm5GetBaseCurrency]()	 
	SET @NationalCurrency = [dbo].[fnPjm5GetNationalCurrency]()
	
	IF @PeriodSelector <> 0
	BEGIN
		DECLARE 
			@TmpDateSelector int
		SELECT
			@TmpDateSelector = 
				CASE @PeriodSelector --      
					WHEN 1 THEN 4
					WHEN 2 THEN 5									
					WHEN 3 THEN 6									
				END					
		EXEC ReportGetPeriod 
			@TmpDateSelector,		--   
			1, --      
			@PeriodStart OUTPUT,	--  
			@PeriodEnd	 OUTPUT,	--  
			@PeriodName  OUTPUT--  
		END
	ELSE
	BEGIN
		DECLARE 
			@CurDate datetime = GETDATE()	
				
		SELECT
			--  - 1-  ,   ,  
			@PeriodStart = DATEADD(year,-1,DATEADD(month,1,DATEADD(day,-DATEPART(day,@CurDate) + 1,@CurDate))),
			--  -   + 1 
			@PeriodEnd = DATEADD(DAY,1,@CurDate),
			@PeriodName = dbo.fnReportGetPeriodName(@PeriodStart, @PeriodEnd,'ru',1,1)--' 12 '				
	END

	

	SELECT
		@WorkingDays = dbo.fnPjm5GetWorkingDays(@PeriodStart,DATEADD(DAY,-1,@PeriodEnd))


--//////////////////////////////     
	
	DECLARE	@PeriodNames TABLE
	(
		PeriodStartDate date,
		PeriodEndDate date,
		PeriodName TName,
		WorkingDays int
	)

	INSERT INTO @PeriodNames
	SELECT 
		[M].[PeriodStartDate],
		[M].[PeriodEndDate],
		[M].[PeriodName],
		dbo.fnPjm5GetWorkingDays([M].[PeriodStartDate],[M].[PeriodEndDate])
	FROM
		[dbo].[fnReportSplitPeriodOnMonths](@PeriodStart,DATEADD(DAY,-1,@PeriodEnd),'ru',0,1) as [M]
	

	--SELECT * FROM @PeriodNames



--////////////////////////////// 
	--  ,    
	DECLARE @TimeEntriesInFinance 
	TABLE
	(
		[TimeEntryID]			TIdentifier,
		[FinanceDocumentClass]	TClass, 
		[FinanceDocumentID]		TIdentifier, 
		[FinanceDocumentState]	TState, 		
		[TimeEntryIsThroughCalculation]	TFlag
	)

	INSERT INTO @TimeEntriesInFinance ([TimeEntryID], [FinanceDocumentClass], [FinanceDocumentID], [FinanceDocumentState], [TimeEntryIsThroughCalculation])
	SELECT
		[F].[DocumentID],
		[F].[LinkClass],
		[F].[LinkDocumentID],
		[F].[State],
		[F].[ThroughCalculation]
	FROM fnReportGetTimeEntriesInFinance(@PeriodStart, @PeriodEnd, @EmployeeSelector) AS [F]

	--SELECT * FROM @TimeEntriesInFinance


	DECLARE @TimeEntriesRealization TABLE
	(
		[MonthName] TName,
		[ID] int,
		[Date] date,
		[Duration] decimal(18,4),
		[PositiveDurationDeviation] decimal(18,4),
		[NegativeDurationDeviation] decimal(18,4),		
		[Cost] decimal(18,2),
		[PositiveCostDeviation] decimal(18,2),
		[NegativeCostDeviation] decimal(18,2)
	)

	-- ,    . -  
	IF @StateOfFinanceDocuments <> 0
	BEGIN 
		INSERT INTO @TimeEntriesRealization
		SELECT
			[PeriodNames].[PeriodName],	
			[TimeEntry].[ID],
			[TimeEntry].[StartTime],
			[EntryAmount].[Amount],
			CASE  
				WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 > 0 
				THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0
				ELSE 0
			END AS [PositiveDurationDeviation],
			CASE 
				WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 < 0 
				THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)
				ELSE 0
			END AS [NegativeDurationDeviation],						
			[EntryAmount].[Amount]
			*	
			[EntryAmount].[Price]
			*   
			(
				1 -	CASE [Project].[RatesWithVAT]
						WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
						ELSE 0 
					END
			)
			*
			CASE @CurrencySelector
			   WHEN 0 THEN
					CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
					END
				ELSE
					CASE [Project].[CurrencyCode]
						WHEN @NationalCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
					END
			END AS [Cost],
			CASE 
				WHEN [EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] > 0 
				THEN
				ROUND((
					[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
					- 
					[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
				)	
				*
				(
					1 -	CASE [Project].[RatesWithVAT]
							WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
							ELSE 0 
						END
				)
				*			
				CASE @CurrencySelector
				   WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
				ELSE 0
			END AS [PositiveCostDeviation],
			CASE 
				WHEN [EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] < 0 
				THEN
				ROUND(ABS(
					[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
					- 
					[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
				)	
				*
				(
					1 -	CASE [Project].[RatesWithVAT]
							WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
							ELSE 0 
						END
				)
				*			
				CASE @CurrencySelector
				   WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
				ELSE 0
			END AS [NegativeCostDeviation]
		FROM
			[TimeEntry]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [TimeEntry].[EmployeeID]
			INNER JOIN [EntryAmount]
				ON [EntryAmount].[ID] = [TimeEntry].[ID]
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
			INNER JOIN	@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
				ON [TimeEntriesInFinance].[TimeEntryID] = [TimeEntry].[ID]	
			LEFT JOIN @PeriodNames as [PeriodNames]
				ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
				AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]
		WHERE
			--    "  . "		
			(	-- ... "  "?
				(@IncludeApproval = 0 AND [TimeEntry].[State] = 6) 	
				OR 	
				(@IncludeApproval = 1 AND [TimeEntry].[State] IN (2,6))
			)
			AND --      . 
			(
				@StateOfFinanceDocuments = 2 
				OR 
				(
					[TimeEntriesInFinance].[FinanceDocumentState] = 2 
					OR 
					(
						@InvoiceClass = [TimeEntriesInFinance].[FinanceDocumentClass] AND [TimeEntriesInFinance].[FinanceDocumentState] = 5
					) 
					OR
					(
						@InvoiceClass != [TimeEntriesInFinance].[FinanceDocumentClass] AND [TimeEntriesInFinance].[FinanceDocumentState] = 3
					)
				)
			)
			AND 
			--.   
			[TimeEntriesInFinance].[FinanceDocumentClass] <> @CalculationClass
	END
	--SELECT * FROM @TimeEntriesRealization

	-- ,   
	INSERT INTO @TimeEntriesRealization
	SELECT
		[PeriodNames].[PeriodName],	
		[TimeEntry].[ID],
		[TimeEntry].[StartTime],
		[EntryAmount].[Amount],
		CASE 
			WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 > 0 
			THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0
			ELSE 0
		END AS [PositiveDeviation],
		CASE 
			WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 < 0 
			THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)
			ELSE 0
		END AS [NegativeDeviation],		
		ROUND(						
				[EntryAmount].[Amount]
				*	
				[EntryAmount].[Price]
				*
				CASE [Calculation].[DiscountType]
					WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
					WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
					WHEN 3 THEN --
						CASE 
							WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
							ELSE 1
						END
					WHEN 4 THEN [Calculation].[DiscountPercent]-- 
					ELSE 1
				END
				*   
				(1 - CASE [Project].[RatesWithVAT] 
						WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
						ELSE 0 
					END
				)
				*	
				CASE @CurrencySelector
				   WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END
		,2) AS [Cost],
		CASE 
			WHEN ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0 
			THEN
				ROUND(([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate])
				*
				(1 - CASE [Project].[RatesWithVAT] 
						WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
						ELSE 0 
					END
				)
				*	
				CASE @CurrencySelector
				   WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
			ELSE 0
		END AS [PositiveCostDeviation],
		CASE 
			WHEN ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0 
			THEN
				ROUND(ABS([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate])
				*
				(1 - CASE [Project].[RatesWithVAT] 
						WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
						ELSE 0 
					END
				)
				*	
				CASE @CurrencySelector
				   WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
			ELSE 0
		END AS [NegativeCostDeviation]
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [EntryAmount]
			ON [EntryAmount].[ID] = [TimeEntry].[ID]
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
		INNER JOIN	@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
			ON [TimeEntriesInFinance].[TimeEntryID] = [TimeEntry].[ID]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [TimeEntriesInFinance].[FinanceDocumentID]
		LEFT JOIN @PeriodNames as [PeriodNames]
			ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
			AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]
	WHERE
		--    "  . "
		(	-- ... "  "?
			(@IncludeApproval = 0 AND [TimeEntry].[State] = 6) 	
			OR 	
			(@IncludeApproval = 1 AND [TimeEntry].[State] IN (2,6))
		)
		AND --   (3),   (2) .     (1)
		(
			(@StateOfFinanceDocuments = 0 AND [TimeEntriesInFinance].[FinanceDocumentState] = 3) 	
			OR 
			(@StateOfFinanceDocuments = 1 AND [TimeEntriesInFinance].[FinanceDocumentState] IN (2,3)) 
			OR
			(@StateOfFinanceDocuments = 2 AND [TimeEntriesInFinance].[FinanceDocumentState] IN (1,2,3)) 
		)
		AND --.  - 
		[TimeEntriesInFinance].[FinanceDocumentClass] = @CalculationClass
	
	--SELECT * FROM @TimeEntriesRealization

	
--////////////////////////////// 
	
	DECLARE @TimeEntriesUtilization TABLE
	(
		[MonthName] TName,
		[ID] int,
		[Date] date,
		[Duration] decimal(18,4)
	)
	
	INSERT INTO @TimeEntriesUtilization
	SELECT
		[PeriodNames].[PeriodName],		
		[TimeEntry].[ID],
		[TimeEntry].[StartTime],
		ROUND(CASE WHEN @TimeRoundingSelector = 0 
			THEN [TimeEntry].[RoundedDuration]
			ELSE [TimeEntry].[Duration]
		END/60.0,4)		
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]		
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
		LEFT JOIN @PeriodNames as [PeriodNames]
			ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
			AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]
	WHERE
		-- 
		[Project].[ProjectTypeID] = 1
		AND --    ""  "  . "	
		(	-- ... "  "?
			(@IncludeApproval = 0 AND [TimeEntry].[State] IN (3,6)) 	
			OR 	
			(@IncludeApproval = 1 AND [TimeEntry].[State] IN (2,3,6))
		)	
		AND 
		(
			[TimeEntry].[StartTime] >= @PeriodStart 
			AND 
			[TimeEntry].[StartTime] <= @PeriodEnd
		)
		AND
		[Employee].[ID] = @EmployeeSelector
		
	--SELECT * FROM @TimeEntriesUtilization
	
		

--//////////////////////////////  

	DECLARE @Main TABLE
	(
		[Flag] int,
		[MonthName] TName,
		[Utilization] decimal(18,2),
		[Realization] decimal(18,2),
		[Efficiency] decimal(18,2),
		[EfficiencyDeviation] decimal(18,2),
		[Cost] decimal(18,2),
		[AverageRate] decimal(18,2)
	)
	

	INSERT INTO @Main
	SELECT
		0,
		[PeriodName],
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL
	FROM
		@PeriodNames

	--   
	
	UPDATE @Main
	SET 
		[Utilization] = [UtilizationAggregateTable].[Sum]		
	FROM
	@Main AS [Main]
	INNER JOIN
	(
		SELECT
			[TimeEntriesUtilization].[MonthName],
			SUM([TimeEntriesUtilization].[Duration]) AS [Sum]
		FROM
			@TimeEntriesUtilization AS [TimeEntriesUtilization]
		GROUP BY
			[TimeEntriesUtilization].[MonthName]
	) AS [UtilizationAggregateTable]
		ON [Main].[MonthName] = [UtilizationAggregateTable].[MonthName]

	UPDATE @Main
	SET 		
		[Realization] = [RealizationAggregateTable].[SumTime],		
		[Cost] = [RealizationAggregateTable].[SumCost]
	FROM
	@Main AS [Main]
	INNER JOIN
	(
		SELECT
			[TimeEntriesRealization].[MonthName],
			SUM([TimeEntriesRealization].[Duration]) AS [SumTime],
			SUM([TimeEntriesRealization].[Cost]) AS [SumCost]
		FROM
			@TimeEntriesRealization AS [TimeEntriesRealization]
		GROUP BY
			[TimeEntriesRealization].[MonthName]
	) AS [RealizationAggregateTable]
		ON [Main].[MonthName] = [RealizationAggregateTable].[MonthName]

	UPDATE @Main
	SET
		[Efficiency] = CASE 
							WHEN [Utilization] IS NOT NULL THEN 
								CASE
									WHEN [Utilization] <> 0 THEN (([Realization] - [RealizationAggregateTable].[PositiveDurationDeviation])/[Utilization])*100
									ELSE 0
								END 
							ELSE NULL 
						END,
		[EfficiencyDeviation] = CASE
									WHEN [Utilization] IS NOT NULL AND [Realization] IS NOT NULL THEN
										CASE 
											WHEN ROUND([Utilization],2) <> 0 AND ROUND([Realization] - [RealizationAggregateTable].[PositiveDurationDeviation],2) <> 0 
											THEN (([Realization] - [RealizationAggregateTable].[PositiveDurationDeviation])/[Utilization])*100 - @CompanyAverageEfficiency
											ELSE 0
										END
									ELSE NULL									 
								END,
		[AverageRate] = CASE
							WHEN [Utilization] IS NOT NULL AND [Cost] IS NOT NULL THEN
								CASE
									WHEN [Utilization] <> 0 THEN [Cost]/[Utilization]
									ELSE 0 
								END
							ELSE NULL
						END
	FROM
	@Main AS [Main]
	INNER JOIN
	(
		SELECT
			[TimeEntriesRealization].[MonthName],
			SUM([TimeEntriesRealization].[PositiveDurationDeviation]) AS [PositiveDurationDeviation]
		FROM
			@TimeEntriesRealization AS [TimeEntriesRealization]
		GROUP BY
			[TimeEntriesRealization].[MonthName]
	) AS [RealizationAggregateTable]
		ON [Main].[MonthName] = [RealizationAggregateTable].[MonthName]
			
--//////////////////////////////  ,   

	--
	INSERT INTO @Main
	SELECT
		1,
		N':',
		SUM([Utilization])/(SELECT COUNT([Utilization]) FROM @Main WHERE [Utilization] IS NOT NULL),
		SUM([Realization])/(SELECT COUNT([Realization]) FROM @Main WHERE [Realization] IS NOT NULL),
		SUM(ROUND([Efficiency],0))/(SELECT COUNT([Efficiency]) FROM @Main WHERE [Efficiency] IS NOT NULL),
		CASE 
			WHEN ROUND(SUM(ROUND([Efficiency],0))/(SELECT COUNT([Efficiency]) FROM @Main WHERE [Efficiency] IS NOT NULL),0) <> 0 
			THEN SUM([Efficiency])/(SELECT COUNT([Efficiency]) FROM @Main WHERE [Efficiency] IS NOT NULL) - @CompanyAverageEfficiency
			ELSE 0 
		END,
		SUM([Cost])/(SELECT COUNT([Cost]) FROM @Main WHERE [Cost] IS NOT NULL),
		SUM([AverageRate])/(SELECT COUNT([AverageRate]) FROM @Main WHERE [AverageRate] IS NOT NULL)
	FROM
		@Main AS [Main]
	WHERE
		[Flag] = 0

	-- 
	INSERT INTO @Main
	SELECT
		2,
		N' :',
		SUM([Utilization])
		/
		(
			SELECT 
				SUM([PN].[WorkingDays]) 
			FROM 
				@Main AS [Main] 
				INNER JOIN @PeriodNames AS [PN]
					ON [PN].[PeriodName] = [Main].[MonthName] 
			WHERE 
				[Main].[Utilization] IS NOT NULL
		),
		SUM([Realization])
		/
		(
			SELECT 
				SUM([PN].[WorkingDays]) 
			FROM 
				@Main AS [Main] 
				INNER JOIN @PeriodNames AS [PN]
					ON [PN].[PeriodName] = [Main].[MonthName] 
			WHERE 
				[Main].[Realization] IS NOT NULL
		),
		NULL,
		NULL,
		SUM([Cost])
		/
		(
			SELECT 
				SUM([PN].[WorkingDays]) 
			FROM 
				@Main AS [Main] 
				INNER JOIN @PeriodNames AS [PN]
					ON [PN].[PeriodName] = [Main].[MonthName] 
			WHERE 
				[Main].[Cost] IS NOT NULL
		),
		NULL
	FROM
		@Main AS [Main]		
	WHERE
		[Flag] = 0

	--
	INSERT INTO @Main
	SELECT
		3,
		N':',
		SUM([Utilization]),
		SUM([Realization]),
		NULL,
		NULL,
		SUM([Cost]),
		NULL
	FROM
		@Main AS [Main]
	WHERE
		[Flag] = 0

	-- 
	INSERT INTO @Main
	SELECT
		4,
		N' :',
		NULL,
		SUM([PositiveDurationDeviation]),
		NULL,
		NULL,
		SUM([PositiveCostDeviation]),
		NULL
	FROM
		@TimeEntriesRealization AS [TimeEntriesRealization]

	-- 
	INSERT INTO @Main
	SELECT
		5,
		N' :',
		NULL,
		SUM([NegativeDurationDeviation]),
		NULL,
		NULL,
		SUM([NegativeCostDeviation]),
		NULL
	FROM
		@TimeEntriesRealization AS [TimeEntriesRealization]
	


--////////////////////////////// 

	UPDATE @Main
	SET 
		[Utilization] = ROUND([Utilization],2),
		[Realization] = ROUND([Realization],2),
		[Efficiency] = ROUND([Efficiency],0),
		[EfficiencyDeviation] = ROUND([EfficiencyDeviation],0),
		[AverageRate] = ROUND([AverageRate],2)



--////////////////////////////// SmartValue
	DECLARE 
		@Scale int,
		@MaxValue decimal(18,2)

	SELECT
		@MaxValue = MAX([Cost])
	FROM
		@Main

	SELECT
		@Scale = [dbo].[fnReportCalculateSmartValue](@ScaleSelector,@MaxValue)

	UPDATE @Main
	SET [Cost] = [Cost]/@Scale


--//////////////////////////////  
	DECLARE 
		@AverageCost decimal(18,2)

	SELECT	
		@AverageCost = [Cost]
	FROM 
		@Main
	WHERE
		[Flag] = 1

	
--//////////////////////////////  

	EXEC [dbo].[ReportEmployeeEfficiencyHeader] @EmployeeSelector,@PeriodName,@CurrencySelector,@ScaleSelector,@Scale,@WorkingDays,@CompanyAverageEfficiency,@AverageCost

	SELECT * FROM @Main	

GO

GRANT EXEC ON ReportEmployeeEfficiency TO PUBLIC

GO

