IF EXISTS (SELECT * FROM sysobjects WHERE TYPE = 'P' AND name = 'ReportEmployeeEfficiencyHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeEfficiencyHeader'
		DROP  PROCEDURE  ReportEmployeeEfficiencyHeader
	END
GO
PRINT 'Creating Procedure ReportEmployeeEfficiencyHeader'
GO
/******************************************************************************
**		File: ReportEmployeeEfficiencyHeader.sql
**		Name: ReportEmployeeEfficiencyHeader
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 18.04.2014 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-----------------------------------------------
**		09.06.14	SAP			      	
**		16.06.14	GNV			     
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportEmployeeEfficiencyHeader]		    
    @EmployeeID TIdentifier,		-- ID     
    @PeriodName TName,				--  
    @CurrencySelector int,			--  (0 - , 1 - )
	@ScaleSelector int,				--   (0 - , 1 - , 2 - , 3 - )
	@Scale int,						--  
	@WorkingDays TName,				--  /
	@CompanyAverageEfficiency int,	--    , %.
	@AverageCost decimal(18,2)		--    
AS
SET NOCOUNT ON

DECLARE
	@OwnCompanyName TName,
	@DivisionName TName,
	@PositionName TName,
	@EmployeeName TName,
	@Rate decimal(18,2),
	@Qualification TName,
	@CurrencyCode TCode3,	
	@CurrencyWithPrefix TName,
	@UserName TName,
	@UserID TIdentifier

	--  	
	SELECT 
		@OwnCompanyName = [Company].[FileAs]		
	FROM
		[Employee]
		INNER JOIN [Company]
			ON [Company].[ID] = [Employee].[CompanyID]
	WHERE 
		[Employee].[ID] = @EmployeeID
	
			
	--   
	SELECT
		@CurrencyCode = 
			CASE @CurrencySelector
				WHEN 0 THEN [dbo].[fnPjm5GetBaseCurrency]()
				WHEN 1 THEN [dbo].[fnPjm5GetNationalCurrency]()
			END
			
	SELECT
		@CurrencyWithPrefix =
			CASE @ScaleSelector
				WHEN 0 THEN @CurrencyCode
				WHEN 1 THEN '. ' + @CurrencyCode
				WHEN 2 THEN '. ' + @CurrencyCode
				WHEN 3 THEN
					CASE @Scale
						WHEN 1 THEN @CurrencyCode
						WHEN 1000 THEN '. ' + @CurrencyCode
						WHEN 1000000 THEN '. ' + @CurrencyCode
						WHEN 1000000000 THEN '. ' + @CurrencyCode
					END 
			END

	--, ,   
	SELECT
		@EmployeeName = [Employee].[FileAs],
		@DivisionName = [Division].[FileAs],
		@PositionName = [Position].[FileAs],
		@Qualification = [Qualification].[FileAs],
		@Rate = [QualificationRate].[Standard]
	FROM
		[Employee] 
		LEFT JOIN [Division]
			ON [Division].[ID] = [Employee].[DivisionID]
		LEFT JOIN [Position]
			ON [Position].[ID] = [Employee].[PositionID]
		LEFT JOIN [Qualification]
			ON [Qualification].[ID] = [Employee].[QualificationID]
		LEFT JOIN [QualificationRate]
			ON [Employee].[QualificationID] = [QualificationRate].[QualificationID]
			AND [QualificationRate].[CurrencyCode] = @CurrencyCode
	WHERE 
		[Employee].[ID] = @EmployeeID
	
	-- 
	SET @UserID = dbo.adfGetCurrentUserID()		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM 
		[Trustee]
	WHERE 
		[Trustee].[ID] = @UserID
	
	
	
	--    
	SELECT
		@OwnCompanyName AS [OwnCompanyName],
		@DivisionName AS [DivisionName],
		@PositionName as [PositionName],
		@Qualification AS [QualificationName],
		@Rate AS [Rate],
		@EmployeeName AS [EmployeeName],
		@CurrencyWithPrefix AS [Currency],
		@PeriodName AS [PeriodName],
		@WorkingDays AS [WorkingDays],
		@WorkingDays*8 as [WorkingHours],
		@UserName AS [UserName],
		@CompanyAverageEfficiency AS [CompanyAverageEfficiency],
		@AverageCost AS [AverageCost]
RETURN 0
GO
GRANT EXEC ON ReportEmployeeEfficiencyHeader TO PUBLIC
GO