IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeesTimeAllocationByPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeesTimeAllocationByPeriod'
		DROP  Procedure  ReportEmployeesTimeAllocationByPeriod
	END
GO

PRINT 'Creating Procedure ReportEmployeesTimeAllocationByProject'
GO

/******************************************************************************
**		File: ReportEmployeesTimeAllocationByProject.sql
**		Name: ReportEmployeesTimeAllocationByProject
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 22/11/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		22.11.2010	MAN				First Version
**		15.01.2013	BAO				   
**									,    -
*******************************************************************************/

CREATE PROCEDURE [dbo].[ReportEmployeesTimeAllocationByPeriod]
	@CompanyID		TIdentifier,	-- ID 
    @DivisionID		TIdentifier,	-- ID 
    @DivisionSelector TIdentifier,
	@DateSelector	TIdentifier,	--    (SelectedIndex  )
    @PeriodStart	TDateTime,		--   
    @PeriodEnd		TDateTime,		--   
    @EmployeeID		TIdentifier,	-- ID 
    @DeviationType	TIdentifier,
	@IncludingDrafts int			--       -?	
AS

SET NOCOUNT ON

--  
IF  dbo.adfHasAccessRightByName('ViewEmployeesTimeAllocationByPeriodReport') = 0 
BEGIN
      RAISERROR('#NotEnoughPermissions', 18, -1)
      RETURN 1
END

DECLARE
	@PeriodName TName, --  
	@Number TIdentifier,
	@InvoiceClass TClass



-- 
EXEC ReportGetPeriod 
	@DateSelector, --   
	0,			
	@PeriodStart OUTPUT,	--  
	@PeriodEnd	 OUTPUT,	--  
	@PeriodName  OUTPUT		--  
	

IF (@DivisionSelector = 0 )
	SET @DivisionID = NULL



SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')

--   ,    
DECLARE @TimeEntriesInFinance TABLE(DocumentID TIdentifier,LinkClass TClass, LinkDocumentID TIdentifier, State	TState, Date TDateTime, ThroughCalculation TFlag)
INSERT INTO @TimeEntriesInFinance(DocumentID, LinkClass, LinkDocumentID, State, ThroughCalculation)
SELECT 
[F].[DocumentID], [F].[LinkClass], [F].[LinkDocumentID], [F].[State], [F].[ThroughCalculation]
FROM
fnReportGetTimeEntriesInFinance(@PeriodStart, @PeriodEnd, @EmployeeID) AS [F]



DECLARE @Result TABLE
(
	[FileAs] TName,
	[TimeTotal] TAmount,
	[TimeBillable] TAmount,
	[TimeSold]		TAmount,
	[ProjectType2] TAmount,
	[ProjectType3] TAmount,
	[ProjectType4] TAmount,
	[ProjectType5] TAmount,
	[ProjectType6] TAmount
)
INSERT INTO @Result
(
	[FileAs],
	[TimeTotal],
	[TimeBillable],
	[TimeSold],
	[ProjectType2],
	[ProjectType3],
	[ProjectType4],
	[ProjectType5],
	[ProjectType6]
)
SELECT
	[Employee].[FileAs],
	SUM
	(
		CASE
			WHEN 
				[vwTimeEntry].[State] IN ( 3, 6 ) --   
				AND
				[Project].[ProjectTypeID] = 1 --   
				THEN
					[vwTimeEntry].[RoundedDuration] / 60.00
		END 
	) AS [TimeTotal],
	SUM
	(
		CASE
			WHEN 
				[vwTimeEntry].[Billable] = 1
				AND
				[vwTimeEntry].[State] IN ( 3, 6 ) --   
				AND
				[Project].[ProjectTypeID] = 1 --   
				THEN
					[vwTimeEntry].[RoundedDuration] / 60.00
		END
	) AS [TimeBillable],
	SUM
	(
		CASE
			WHEN 
				[vwTimeEntry].[State] IN ( 6 )
				AND
				[Project].[ProjectTypeID] = 1 --   
				AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --     
				THEN
					[vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [TimeSold],
	SUM
	(
		CASE
			WHEN [Project].[ProjectTypeID] = 2 --  
				THEN [vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [ProjectType2],
	SUM
	(
		CASE
			WHEN [Project].[ProjectTypeID] = 3 --  
				THEN [vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [ProjectType3],
	SUM
	(
		CASE
			WHEN [Project].[ProjectTypeID] = 4 -- 
				THEN [vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [ProjectType4],
	SUM
	(
		CASE
			WHEN [Project].[ProjectTypeID] = 5 -- 
				THEN [vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [ProjectType5],
	SUM
	(
		CASE
			WHEN [Project].[ProjectTypeID] = 6 --  
				THEN [vwTimeEntry].[BillableDuration] / 60.00
		END
	) AS [ProjectType6]					
FROM
	[vwTimeEntry]
	INNER JOIN [Employee]
		ON [vwTimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [vwTimeEntry].[ProjectID] = [Project].[ID]
	LEFT OUTER JOIN										--    ,   
		@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
			ON [TimeEntriesInFinance].[DocumentID] = [vwTimeEntry].[ID]
WHERE
	[vwTimeEntry].[State] IN (3,6)
	AND
	[vwTimeEntry].[StartTime] >= @PeriodStart
	AND
	[vwTimeEntry].[StartTime] < @PeriodEnd
	AND
	(
		@EmployeeID IS NULL
		OR
		[vwTimeEntry].[EmployeeID] = @EmployeeID
	)
	AND
	(
		(
			@CompanyID IS NULL
			AND
			EXISTS
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
				    [Company].[ID] = [Employee].[CompanyID]
				    AND
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
GROUP BY
	[Employee].[FileAs]

SELECT
	[FileAs],
	[TimeTotal],
	[TimeBillable],
	[TimeSold],
	[ProjectType2],
	[ProjectType3],
	[ProjectType4],
	[ProjectType5],
	[ProjectType6],
	CASE @DeviationType
		WHEN 0 THEN ISNULL([TimeTotal],0) 
		WHEN 1 THEN ISNULL([TimeBillable],0)
	END AS [Deviation]
FROM
	@Result
	
--  
EXEC ReportEmployeesTimeAllocationByPeriodHeader
	    @CompanyID,
        @DivisionID ,
        @PeriodName,
        @PeriodStart,
        @PeriodEnd,
        @DeviationType
RETURN 0
GO

GRANT EXEC ON ReportEmployeesTimeAllocationByPeriod TO PUBLIC
GO

