	IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[ReportFuturePeriodsRealization]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure ReportFuturePeriodsRealization'
		DROP PROCEDURE [dbo].[ReportFuturePeriodsRealization]
	END
	GO

	PRINT 'Creating procedure ReportFuturePeriodsRealization'
	GO

	/******************************************************************************
	**		File: ReportFuturePeriodsRealization.sql
	**		Name: ReportFuturePeriodsRealization
	**		Desc: 
	**
	**              
	**		Return values:
	** 
	**		Called by:   
	**              
	**		Parameters:
	**		Input							Output
	**      ----------						-----------
	**
	**		Auth: Sergey Pelevin
	**		Date: 04.12.13
	*******************************************************************************
	**		Change History
	*******************************************************************************
	**		Date:		Author:			Description:
	**		--------	--------		-------------------------------------------
	**		22.12.13	SAP				 	 
	*******************************************************************************/
	CREATE PROCEDURE [ReportFuturePeriodsRealization]			
		@OwnCompanyID TIdentifier,-- ID   (NULL - )
		@CurrencySelector int,--  : 0 - , 1 - 
		@CompanyManagerSelector int, --   : 0 - , 1 -  
		@ManagerID TIdentifier, -- ID   (NULL - ,    )
		@CostCenterSelector int, --  : 0 -  , 1 -  
		@CostCenterID TIdentifier,-- ID   (NULL -  )
		@ReportDate TDate,-- ,    
		@TypeSelector int, -- : 0 - , 1 - 
		@SortSelector int, -- : 0 -   , 1 -  
		@ScaleSelector	int,  -- : 0 - , 1 -   2 - 
		@CountSelector int, --    : 0 - , 1 -  5, 2 -  10, 3 - 
		@Count int --  

	AS

	SET NOCOUNT ON

	DECLARE
		@PeriodEnd TDate, 
        @date datetime,
        @CurrentEmployeeID TIdentifier,
        @Class TClass,
            
        @TimeEntryClass TClass,
        @ExpenseClass TClass,
        @PhoneCallClass TClass,
        @ServiceRequestClass TClass,

		@BaseCurrency TCode3,
		@NationalCurrency TCode3,

		@MaxValue int,
		@Scale int,

		@tmpManagerID TIdentifier,
		@tmpCompanyID TIdentifier,

		@ReportCurrency varchar(50),
		@RowCount int


	--  
	IF  dbo.adfHasAccessRightByName('ViewFuturePeriodsRealizationReport') = 0 
	BEGIN
		  RAISERROR('#NotEnoughPermissions', 18, -1)
		  RETURN 1
	END
            
    SET @PeriodEnd = @ReportDate
	SET @date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)--DATEADD(day, 1, CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime))

	
	SET @Class = dbo.adfGetClassByName('Pjm5.Calculation')      
    SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
    SET @ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')


	IF @CountSelector = 1
		SET @Count = 5
	IF @CountSelector = 2
		SET @Count = 10	

	-- 
	SELECT
		@BaseCurrency = [dbo].[fnPjm5GetBaseCurrency](),
		@NationalCurrency = [dbo].[fnPjm5GetNationalCurrency]()


	--   
	DECLARE @Chart TABLE
	(
		[Company] TName,
		[Total] TAmount
	)

	--   
	DECLARE @Rates TABLE
	(
		[FromCurrencyCode] TCode3,
		[ToCurrencyCode] TCode3,
		[Rate] TAmount
	)

	
	--********************************************************
	--     .
	;
	WITH [TimeCurrencyCodes]([CurrencyCode])
	AS
	(
		SELECT DISTINCT				
			[TimeEntry].[CurrencyCode]		
		FROM
			[TimeEntry]
			INNER JOIN [EntryAmount]
				ON [EntryAmount].[ID] = [TimeEntry].[ID]
				AND [EntryAmount].[Price] > 0
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
			INNER JOIN [Company]
				ON [Company].[ID] = [Project].[CustomerCompanyID]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [Company].[ManagerEmployeeID]
		WHERE
			[Project].[State] NOT IN (4,5,6)
			AND
			[TimeEntry].[State] = 3
			AND
			[TimeEntry].[Billable] = 1 
			AND
			(
				@OwnCompanyID IS NULL
				OR
				[Project].[SupplierCompanyID] = @OwnCompanyID
			)
			AND
			(
				@CompanyManagerSelector = 0
				OR
				[Company].[ManagerEmployeeID] = @ManagerID
			)
			AND
			(
				@CostCenterSelector = 0
				OR
				[Project].[CostCenterID] = @CostCenterID 
			)
			AND
			(
				[TimeEntry].[StartTime] <= @PeriodEnd					
			)
			AND
			(
				[StartTime] >= ISNULL(
										(
											SELECT 
												MAX([PeriodEnd]) + 1 
											FROM 
												[Calculation]
												LEFT OUTER JOIN [PaymentPeriod]
													ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
											WHERE 
												[Calculation].[ProjectID] = [TimeEntry].[ProjectID] 
												AND 
												[Calculation].[State] != 4
												AND
												[Calculation].[DocumentClass] = @TimeEntryClass
												AND
												(
													[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
													OR
													[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
												)
										), 
									0)
			)			
		)
	INSERT INTO @Rates
	SELECT
		[CurrencyCode] AS [FromCurrencyCode],
		@NationalCurrency AS [ToCurrencyCode],
		[dbo].[pjm6fnCurrencyGetRate]([CurrencyCode], @date, @NationalCurrency) AS [Rate]
	FROM
		[TimeCurrencyCodes]
	UNION
	SELECT
		[CurrencyCode] AS [FromCurrencyCode],
		@BaseCurrency AS [ToCurrencyCode],
		[dbo].[pjm6fnCurrencyGetRate]([CurrencyCode], @date, @BaseCurrency) AS [Rate]
	FROM
		[TimeCurrencyCodes]

	;
	WITH [ExpenseCurrencyCodes]([CurrencyCode])
	AS
	(
		SELECT DISTINCT
			[Expense].[ToCurrencyCode]
		FROM
			[Expense]				
			INNER JOIN [Project]
				ON [Project].[ID] = [Expense].[ProjectID]
			INNER JOIN [Company]
				ON [Company].[ID] = [Project].[CustomerCompanyID]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [Company].[ManagerEmployeeID]
		WHERE
			[Project].[State] NOT IN (4,5,6)
			AND
			[Expense].[State] = 3
			AND
			[Expense].[Billable] = 1 
			AND
			(
				@OwnCompanyID IS NULL
				OR
				[Project].[SupplierCompanyID] = @OwnCompanyID
			)
			AND
			(
				@CompanyManagerSelector = 0
				OR
				[Company].[ManagerEmployeeID] = @ManagerID
			)
			AND
			(
				@CostCenterSelector = 0
				OR
				[Project].[CostCenterID] = @CostCenterID 
			)
			AND
			(
				[Expense].[Date] <= @PeriodEnd					
			)
			AND
			(
				[Expense].[Date] >= ISNULL(
										(
											SELECT 
												MAX([PeriodEnd]) + 1 
											FROM 
												[Calculation]
												LEFT OUTER JOIN [PaymentPeriod]
													ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
											WHERE 
												[Calculation].[ProjectID] = [Expense].[ProjectID] 
												AND 
												[Calculation].[State] != 4
												AND
												[Calculation].[DocumentClass] = @TimeEntryClass
												AND
												(
													[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
													OR
													[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
												)
										), 
									0)
			)		
	)
	INSERT INTO @Rates
	SELECT
		[CurrencyCode] AS [FromCurrencyCode],
		@NationalCurrency AS [ToCurrencyCode],
		[dbo].[pjm6fnCurrencyGetRate]([CurrencyCode], @date, @NationalCurrency) AS [Rate]
	FROM
		[ExpenseCurrencyCodes]
	UNION
	SELECT
		[CurrencyCode] AS [FromCurrencyCode],
		@BaseCurrency AS [ToCurrencyCode],
		[dbo].[pjm6fnCurrencyGetRate]([CurrencyCode], @date, @BaseCurrency) AS [Rate]
	FROM
		[ExpenseCurrencyCodes]
	EXCEPT
	SELECT * FROM @Rates


	--SELECT * FROM @Rates



	IF @TypeSelector = 0
	BEGIN
		DECLARE @common TABLE
		(
			[Order] int,
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[Time] TAmount,
			[TimeMoney] TAmount,
			[ExpenseMoney] TAmount,
			[Total] TAmount
		)

		--********************************************************
		--
		DECLARE @time TABLE
		(
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[Time] TAmount,
			[TimeMoney] TAmount			
		)
		
		;
		WITH [Time]([ManagerID],[CompanyID],[StartDate],[EndDate],[Time],[TimeMoney])
		AS
		(
			SELECT				
				[Employee].[ID] AS [ManagerID],
				[Company].[ID] AS [CompanyID],
				MIN([TimeEntry].[StartTime]),
				MAX([TimeEntry].[StartTime]),						
				SUM(ISNULL([EntryAmount].[Amount], 0)) AS [Time],
				SUM(ISNULL([EntryAmount].[Amount] * [EntryAmount].[Price] * [@Rates].[Rate], 0)) AS [TimeMoney]					
			FROM
				[TimeEntry]
				INNER JOIN [EntryAmount]
					ON [EntryAmount].[ID] = [TimeEntry].[ID]
					AND [EntryAmount].[Price] > 0
				INNER JOIN [Project]
					ON [Project].[ID] = [TimeEntry].[ProjectID]
				INNER JOIN [Company]
					ON [Company].[ID] = [Project].[CustomerCompanyID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [Company].[ManagerEmployeeID]
				INNER JOIN @Rates
					ON [@Rates].[FromCurrencyCode] = [TimeEntry].[CurrencyCode]
			WHERE
				(
					@CurrencySelector = 0 AND [@Rates].[ToCurrencyCode] = @NationalCurrency
					OR
					@CurrencySelector = 1 AND [@Rates].[ToCurrencyCode] = @BaseCurrency
				)
				AND			
				[Project].[State] NOT IN (4,5,6)
				AND
				[TimeEntry].[State] = 3
				AND
				[TimeEntry].[Billable] = 1 
				AND
				(
					@OwnCompanyID IS NULL
					OR
					[Project].[SupplierCompanyID] = @OwnCompanyID
				)
				AND
				(
					@CompanyManagerSelector = 0
					OR
					[Company].[ManagerEmployeeID] = @ManagerID
				)
				AND
				(
					@CostCenterSelector = 0
					OR
					[Project].[CostCenterID] = @CostCenterID 
				)
				AND
				(
					[TimeEntry].[StartTime] <= @PeriodEnd					
				)
				AND
				(
					[StartTime] >= ISNULL(
											(
												SELECT 
													MAX([PeriodEnd]) + 1 
												FROM 
													[Calculation]
													LEFT OUTER JOIN [PaymentPeriod]
														ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
												WHERE 
													[Calculation].[ProjectID] = [TimeEntry].[ProjectID] 
													AND 
													[Calculation].[State] != 4
													AND
													[Calculation].[DocumentClass] = @TimeEntryClass
													AND
													(
														[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
														OR
														[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
													)
											), 
										0)
				)
			GROUP BY
				[Employee].[ID],
				[Company].[ID]
		)
		
		INSERT INTO @time
		SELECT * FROM [Time]

		--SELECT * FROM @time ORDER BY [ManagerID],[CompanyID]

		--********************************************************
		--
		DECLARE @expense TABLE
		(
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[ExpenseMoney] TAmount			
		)


		;
		WITH [Expenses]([ManagerID],[CompanyID],[PeriodStart],[PeriodEnd],[ExpenseMoney])
		AS
		(
			SELECT
				[Employee].[ID] AS [ManagerID],
				[Company].[ID] AS [CompanyID],
				MIN([Expense].[Date]),
				MAX([Expense].[Date]),							
				SUM(ISNULL([Expense].[TotalWithVATPC] * [@Rates].[Rate], 0)) AS [ExpenseMoney]
			FROM
				[Expense]				
				INNER JOIN [Project]
					ON [Project].[ID] = [Expense].[ProjectID]
				INNER JOIN [Company]
					ON [Company].[ID] = [Project].[CustomerCompanyID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [Company].[ManagerEmployeeID]
				INNER JOIN @Rates
					ON [@Rates].[FromCurrencyCode] = [Expense].[ToCurrencyCode]
			WHERE
				(
					@CurrencySelector = 0 AND [@Rates].[ToCurrencyCode] = @NationalCurrency
					OR
					@CurrencySelector = 1 AND [@Rates].[ToCurrencyCode] = @BaseCurrency
				)
				AND			
				[Project].[State] NOT IN (4,5,6)
				AND
				[Expense].[State] = 3
				AND
				[Expense].[Billable] = 1 
				AND
				(
					@OwnCompanyID IS NULL
					OR
					[Project].[SupplierCompanyID] = @OwnCompanyID
				)
				AND
				(
					@CompanyManagerSelector = 0
					OR
					[Company].[ManagerEmployeeID] = @ManagerID
				)
				AND
				(
					@CostCenterSelector = 0
					OR
					[Project].[CostCenterID] = @CostCenterID 
				)
				AND
				(
					[Expense].[Date] <= @PeriodEnd					
				)
				AND
				(
					[Expense].[Date] >= ISNULL(
											(
												SELECT 
													MAX([PeriodEnd]) + 1 
												FROM 
													[Calculation]
													LEFT OUTER JOIN [PaymentPeriod]
														ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
												WHERE 
													[Calculation].[ProjectID] = [Expense].[ProjectID] 
													AND 
													[Calculation].[State] != 4
													AND
													[Calculation].[DocumentClass] = @TimeEntryClass
													AND
													(
														[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
														OR
														[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
													)
											), 
										0)
				)
			GROUP BY				
				[Employee].[ID],
				[Company].[ID]
		)


		INSERT INTO @expense
		SELECT	* FROM	[Expenses]

		--SELECT * FROM @expense ORDER BY [Company]




		--********************************************************
		--    time  expense    
		
		INSERT INTO @common
		SELECT
			0,
			[@time].[ManagerID],
			[@time].[CompanyID],
			CASE WHEN ISNULL([@time].[PeriodStart],@date) < ISNULL([@expense].[PeriodStart],@date)
				THEN ISNULL([@time].[PeriodStart],@date)
				ELSE ISNULL([@expense].[PeriodStart],@date)
			END,
			CASE WHEN ISNULL([@time].[PeriodEnd],0) > ISNULL([@expense].[PeriodEnd],0)
				THEN ISNULL([@time].[PeriodEnd],0)
				ELSE ISNULL([@expense].[PeriodEnd],0)
			END,
			[@time].[Time],
			[@time].[TimeMoney],
			[@expense].[ExpenseMoney],
			ISNULL([@time].[TimeMoney],0) + ISNULL([@expense].[ExpenseMoney],0)
		FROM
			@time
			LEFT JOIN @expense
				ON [@expense].[ManagerID] = [@time].[ManagerID]
					AND
					[@expense].[CompanyID] = [@time].[CompanyID]
		
		--SELECT * FROM @Common
		--********************************************************
		--       
		--    [Order]     :
		--0 -  
		--1000 -    
		--1001 -   

		DECLARE managerSubtotalCursor CURSOR LOCAL FAST_FORWARD FOR
			SELECT DISTINCT [ManagerID] FROM @common

		OPEN managerSubtotalCursor
		FETCH NEXT FROM managerSubtotalCursor INTO @tmpManagerID

		WHILE @@FETCH_STATUS = 0
		BEGIN
			INSERT INTO @common
			SELECT
				1000,
				@tmpManagerID,
				NULL,
				NULL,
				NULL,
				SUM([@common].[Time]),
				SUM([@common].[TimeMoney]),
				SUM([@common].[ExpenseMoney]),
				SUM([@common].[Total])
			FROM
				@common
			WHERE
				[@common].[ManagerID] = @tmpManagerID


			FETCH NEXT FROM managerSubtotalCursor INTO @tmpManagerID
		END

		CLOSE managerSubtotalCursor
		DEALLOCATE managerSubtotalCursor


		SELECT
			@RowCount = COUNT(*)
		FROM
			@common

		IF @RowCount > 0
		BEGIN
			INSERT INTO @common
			SELECT
				1001,
				NULL,
				NULL,
				NULL,
				NULL,
				SUM([@common].[Time]),
				SUM([@common].[TimeMoney]),
				SUM([@common].[ExpenseMoney]),
				SUM([@common].[Total])
			FROM
				@common
			WHERE 
				[Order] = 0
		END



		--********************************************************
		--   (SmartValue)
		
		SELECT
			@MaxValue = [Total]
		FROM
			@common
		WHERE
			[Order] = 1001
			
		IF @ScaleSelector = 3
		SET @Scale = 
			CASE  
				WHEN @MaxValue < 10000 THEN 1
				WHEN @MaxValue >= 10000 AND @MaxValue < 10000000 THEN 1000
				WHEN @MaxValue >= 10000000 AND @MaxValue < 10000000000 THEN 1000000
				WHEN @MaxValue >= 10000000000 THEN 1000000000
			END
		ELSE
		SET	@Scale = 
			CASE @ScaleSelector
				WHEN 0 THEN 1
				WHEN 1 THEN 1000
				WHEN 2 THEN 1000000
		END


		-- 		
		UPDATE @common
		SET
			[TimeMoney] = [TimeMoney] / @Scale,
			[ExpenseMoney] = [ExpenseMoney] / @Scale,
			[Total] = [Total] / @Scale





		--********************************************************
		-- .
		IF @CountSelector = 0
		BEGIN
			IF @SortSelector = 1
			BEGIN
				DECLARE @sortedOut TABLE
				(
					[Order] int,
					[ManagerID] TName,
					[CompanyID] TName,
					[PeriodStart] TDate,
					[PeriodEnd] TDate,
					[Time] TAmount,
					[TimeMoney] TAmount,
					[ExpenseMoney] TAmount,
					[Total] TAmount
				)
							
				WHILE EXISTS(SELECT * FROM @common WHERE [@common].[ManagerID] NOT IN (SELECT DISTINCT [ManagerID] FROM @sortedOut))
				BEGIN
					SELECT TOP 1
						@tmpManagerID = [ManagerID]
					FROM
						@common
					WHERE
						[ManagerID] NOT IN (SELECT DISTINCT [ManagerID] FROM @sortedOut)
						AND 
						[Order] = 1000
					ORDER BY
						[Total] DESC


					INSERT INTO @sortedOut
					SELECT
						*
					FROM
						@common
					WHERE
						[ManagerID] = @tmpManagerID
						AND
						[Order] = 0
					ORDER BY 
						[Total] DESC

					INSERT INTO @sortedOut
					SELECT
						*
					FROM
						@common
					WHERE
						[ManagerID] = @tmpManagerID
						AND
						[Order] = 1000				
				END
			
				INSERT INTO @sortedOut
				SELECT
					*
				FROM
					@common
				WHERE				
					[Order] = 1001
				
				--SELECT * FROM @sortedOut		
				SELECT
					[Order],
					[Employee].[FileAs] AS [Manager],
					[Company].[FileAs] AS [Company],
					[PeriodStart],
					[PeriodEnd],
					[Time],
					[TimeMoney],
					[ExpenseMoney],
					[Total],
					@SortSelector AS [SortSelector]
				FROM
					@sortedOut 
					LEFT JOIN [Employee]
						ON [Employee].[ID] = [@sortedOut].[ManagerID]
					LEFT JOIN [Company]
						ON [Company].[ID] = [@sortedOut].[CompanyID]
			END
			ELSE
			BEGIN
				SELECT 
					[Order],
					[Employee].[FileAs] AS [Manager],
					[Company].[FileAs] AS [Company],
					[PeriodStart],
					[PeriodEnd],
					[Time],
					[TimeMoney],
					[ExpenseMoney],
					[Total],
					@SortSelector AS [SortSelector]
				FROM
					@common 
					LEFT JOIN [Employee]
						ON [Employee].[ID] = [@common].[ManagerID]
					LEFT JOIN [Company]
						ON [Company].[ID] = [@common].[CompanyID]
			END				

		END			
		ELSE
		BEGIN
			DECLARE @commonTopX TABLE
			(
				[Order] int,
				[ManagerID] TIdentifier,
				[CompanyID] TIdentifier,
				[PeriodStart] TDate,
				[PeriodEnd] TDate,
				[Time] TAmount,
				[TimeMoney] TAmount,
				[ExpenseMoney] TAmount,
				[Total] TAmount
			)

			--  @Count 
			INSERT INTO @commonTopX
			SELECT TOP (@Count)
				*
			FROM
				@common
			WHERE
				[Order] = 0
			ORDER BY
				[Total] DESC
			
			--    
			INSERT INTO @commonTopX
			SELECT
				1000,
				NULL,
				-1,
				NULL,
				NULL,
				SUM([Time]),
				SUM([TimeMoney]),
				SUM([ExpenseMoney]),
				SUM([Total])			
			FROM
				@common
			WHERE
				[CompanyID] NOT IN (SELECT [CompanyID] FROM @commonTopX)
				AND
				[Order] = 0

			--      @common
			INSERT INTO @commonTopX
			SELECT
				*
			FROM
				@common
			WHERE
				[Order] = 1001



			SELECT 
				[Order],
				[Employee].[FileAs] AS [Manager],
				CASE WHEN [Order] = 1000
					THEN ''
					ELSE [Company].[FileAs] 
				END AS [Company],
				[PeriodStart],
				[PeriodEnd],
				[Time],
				[TimeMoney],
				[ExpenseMoney],
				[Total],
				@SortSelector AS [SortSelector]
			FROM
				@commonTopX 
				LEFT JOIN [Employee]
					ON [Employee].[ID] = [@commonTopX].[ManagerID]
				LEFT JOIN [Company]
					ON [Company].[ID] = [@commonTopX].[CompanyID]
			ORDER BY 
				[Employee].[FileAs], 
				[Order]
				
			
			-- ,       10 
			IF @Count < 11
			BEGIN
				INSERT INTO @Chart
				SELECT
					CASE WHEN [Order] = 1000
						THEN ''
						ELSE [Company].[FileAs] 
					END AS [Company],
					[Total]
				FROM
					@commonTopX
					LEFT JOIN [Company]
						ON [Company].[ID] = [@commonTopX].[CompanyID]
				WHERE
					[Order] IN (0,1000)
			END		
		END	 

	END
	ELSE
	BEGIN
		DECLARE @commonP TABLE
		(
			[Order] int,
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[ProjectID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[Time] TAmount,
			[TimeMoney] TAmount,
			[ExpenseMoney] TAmount,
			[Total] TAmount
		)


		--********************************************************
		--
		DECLARE @timeP TABLE
		(
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[ProjectID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[Time] TAmount,
			[TimeMoney] TAmount			
		)


		;
		WITH [TimeP]([ManagerID],[CompanyID],[ProjectID],[StartDate],[EndDate],[Time],[TimeMoney])
		AS
		(
			SELECT				
				[Employee].[ID] AS [ManagerID],
				[Company].[ID] AS [CompanyID],
				[TimeEntry].[ProjectID],
				MIN([TimeEntry].[StartTime]),
				MAX([TimeEntry].[StartTime]),						
				SUM(ISNULL([EntryAmount].[Amount], 0)) AS [Time],
				SUM(ISNULL([EntryAmount].[Amount] * [EntryAmount].[Price] * [@Rates].[Rate], 0)) AS [TimeMoney]			
			FROM
				[TimeEntry]
				INNER JOIN [EntryAmount]
					ON [EntryAmount].[ID] = [TimeEntry].[ID]
					AND [EntryAmount].[Price] > 0
				INNER JOIN [Project]
					ON [Project].[ID] = [TimeEntry].[ProjectID]
				INNER JOIN [Company]
					ON [Company].[ID] = [Project].[CustomerCompanyID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [Company].[ManagerEmployeeID]
				INNER JOIN @Rates
					ON [@Rates].[FromCurrencyCode] = [TimeEntry].[CurrencyCode]
			WHERE
				(
					@CurrencySelector = 0 AND [@Rates].[ToCurrencyCode] = @NationalCurrency
					OR
					@CurrencySelector = 1 AND [@Rates].[ToCurrencyCode] = @BaseCurrency
				)
				AND			
				[Project].[State] NOT IN (4,5,6)
				AND
				[TimeEntry].[State] = 3
				AND
				[TimeEntry].[Billable] = 1 
				AND
				(
					@OwnCompanyID IS NULL
					OR
					[Project].[SupplierCompanyID] = @OwnCompanyID
				)
				AND
				(
					@CompanyManagerSelector = 0
					OR
					[Company].[ManagerEmployeeID] = @ManagerID
				)
				AND
				(
					@CostCenterSelector = 0
					OR
					[Project].[CostCenterID] = @CostCenterID 
				)
				AND
				(
					[TimeEntry].[StartTime] <= @PeriodEnd					
				)
				AND
				(
					[StartTime] >= ISNULL(
											(
												SELECT 
													MAX([PeriodEnd]) + 1 
												FROM 
													[Calculation]
													LEFT OUTER JOIN [PaymentPeriod]
														ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
												WHERE 
													[Calculation].[ProjectID] = [TimeEntry].[ProjectID] 
													AND 
													[Calculation].[State] != 4
													AND
													[Calculation].[DocumentClass] = @TimeEntryClass
													AND
													(
														[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
														OR
														[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
													)
											), 
										0)
				)
			GROUP BY
				[Employee].[ID],
				[Company].[ID],
				[TimeEntry].[ProjectID]
		)
		
		INSERT INTO @timeP
		SELECT * FROM [TimeP]

		--SELECT * FROM @timeP ORDER BY [ManagerID],[CompanyID],[ProjectID]


		--********************************************************
		--
		DECLARE @expenseP TABLE
		(
			[ManagerID] TIdentifier,
			[CompanyID] TIdentifier,
			[ProjectID] TIdentifier,
			[PeriodStart] TDate,
			[PeriodEnd] TDate,
			[ExpenseMoney] TAmount			
		)


		;
		WITH [ExpensesP]([ManagerID],[CompanyID],[ProjectID],[PeriodStart],[PeriodEnd],[ExpenseMoney])
		AS
		(
			SELECT
				[Employee].[ID] AS [ManagerID],
				[Company].[ID] AS [CompanyID],
				[Expense].[ProjectID],
				MIN([Expense].[Date]),
				MAX([Expense].[Date]),							
				SUM(ISNULL([Expense].[TotalWithVATPC] * [@Rates].[Rate], 0)) AS [ExpenseMoney]		
			FROM
				[Expense]				
				INNER JOIN [Project]
					ON [Project].[ID] = [Expense].[ProjectID]
				INNER JOIN [Company]
					ON [Company].[ID] = [Project].[CustomerCompanyID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [Company].[ManagerEmployeeID]
				INNER JOIN @Rates
					ON [@Rates].[FromCurrencyCode] = [Expense].[ToCurrencyCode]
			WHERE
				(
					@CurrencySelector = 0 AND [@Rates].[ToCurrencyCode] = @NationalCurrency
					OR
					@CurrencySelector = 1 AND [@Rates].[ToCurrencyCode] = @BaseCurrency
				)
				AND			
				[Project].[State] NOT IN (4,5,6)
				AND
				[Expense].[State] = 3
				AND
				[Expense].[Billable] = 1 
				AND
				(
					@OwnCompanyID IS NULL
					OR
					[Project].[SupplierCompanyID] = @OwnCompanyID
				)
				AND
				(
					@CompanyManagerSelector = 0
					OR
					[Company].[ManagerEmployeeID] = @ManagerID
				)
				AND
				(
					@CostCenterSelector = 0
					OR
					[Project].[CostCenterID] = @CostCenterID 
				)
				AND
				(
					[Expense].[Date] <= @PeriodEnd					
				)
				AND
				(
					[Expense].[Date] >= ISNULL(
											(
												SELECT 
													MAX([PeriodEnd]) + 1 
												FROM 
													[Calculation]
													LEFT OUTER JOIN [PaymentPeriod]
														ON [PaymentPeriod].[ProjectID] = [Calculation].[ProjectID]
												WHERE 
													[Calculation].[ProjectID] = [Expense].[ProjectID] 
													AND 
													[Calculation].[State] != 4
													AND
													[Calculation].[DocumentClass] = @TimeEntryClass
													AND
													(
														[Calculation].[PeriodEnd] < [PaymentPeriod].[CalculationNextPaymentDate]
														OR
														[PaymentPeriod].[CalculationNextPaymentDate] IS NULL
													)
											), 
										0)
				)
			GROUP BY				
				[Employee].[ID],
				[Company].[ID],
				[Expense].[ProjectID]
		)


		INSERT INTO @expenseP
		SELECT	* FROM	[ExpensesP]

		--SELECT * FROM @expenseP ORDER BY [ManagerID],[CompanyID],[ProjectID]



		--********************************************************
		--    time  expense    
		
		INSERT INTO @commonP
		SELECT
			0,
			[@timeP].[ManagerID],
			[@timeP].[CompanyID],
			[@timeP].[ProjectID],
			CASE WHEN ISNULL([@timeP].[PeriodStart],@date) < ISNULL([@expenseP].[PeriodStart],@date)
				THEN ISNULL([@timeP].[PeriodStart],@date)
				ELSE ISNULL([@expenseP].[PeriodStart],@date)
			END,
			CASE WHEN ISNULL([@timeP].[PeriodEnd],0) > ISNULL([@expenseP].[PeriodEnd],0)
				THEN ISNULL([@timeP].[PeriodEnd],0)
				ELSE ISNULL([@expenseP].[PeriodEnd],0)
			END,
			[@timeP].[Time],
			[@timeP].[TimeMoney],
			[@expenseP].[ExpenseMoney],
			ISNULL([@timeP].[TimeMoney],0) + ISNULL([@expenseP].[ExpenseMoney],0)
		FROM
			@timeP
			LEFT JOIN @expenseP
				ON [@expenseP].[ManagerID] = [@timeP].[ManagerID]
					AND
					[@expenseP].[CompanyID] = [@timeP].[CompanyID]
					AND
					[@expenseP].[ProjectID] = [@timeP].[ProjectID]


		--********************************************************
		--    ,    
		--    [Order]     :
		-- -1 -    
		--0 -  
		--1000 -    
		--1001 -   


		--  
		DECLARE companySubtotalCursor CURSOR LOCAL FAST_FORWARD FOR
			SELECT DISTINCT [ManagerID], [CompanyID] FROM @commonP

		OPEN companySubtotalCursor
		FETCH NEXT FROM companySubtotalCursor INTO @tmpManagerID, @tmpCompanyID

		WHILE @@FETCH_STATUS = 0
		BEGIN
			INSERT INTO @commonP
			SELECT
				-1,
				@tmpManagerID,
				@tmpCompanyID,
				NULL,
				MIN([@commonP].[PeriodStart]),
				MAX([@commonP].[PeriodEnd]),
				SUM([@commonP].[Time]),
				SUM([@commonP].[TimeMoney]),
				SUM([@commonP].[ExpenseMoney]),
				SUM([@commonP].[Total])
			FROM
				@commonP
			WHERE
				[@commonP].[ManagerID] = @tmpManagerID
				AND
				[@commonP].[CompanyID] = @tmpCompanyID


			FETCH NEXT FROM companySubtotalCursor INTO @tmpManagerID, @tmpCompanyID
		END

		CLOSE companySubtotalCursor
		DEALLOCATE companySubtotalCursor


		--  
		DECLARE managerSubtotalCursor CURSOR LOCAL FAST_FORWARD FOR
			SELECT DISTINCT [ManagerID] FROM @commonP

		OPEN managerSubtotalCursor
		FETCH NEXT FROM managerSubtotalCursor INTO @tmpManagerID

		WHILE @@FETCH_STATUS = 0
		BEGIN
			INSERT INTO @commonP
			SELECT
				1000,
				@tmpManagerID,
				NULL,
				NULL,
				NULL,
				NULL,
				SUM([@commonP].[Time]),
				SUM([@commonP].[TimeMoney]),
				SUM([@commonP].[ExpenseMoney]),
				SUM([@commonP].[Total])
			FROM
				@commonP
			WHERE
				[@commonP].[ManagerID] = @tmpManagerID
				AND
				[@commonP].[Order] = 0


			FETCH NEXT FROM managerSubtotalCursor INTO @tmpManagerID
		END

		CLOSE managerSubtotalCursor
		DEALLOCATE managerSubtotalCursor


		SELECT
			@RowCount = COUNT(*)
		FROM
			@commonP

		-- 
		IF @RowCount > 0
		BEGIN		
			INSERT INTO @commonP
			SELECT
				1001,
				NULL,
				NULL,
				NULL,
				NULL,
				NULL,
				SUM([@commonP].[Time]),
				SUM([@commonP].[TimeMoney]),
				SUM([@commonP].[ExpenseMoney]),
				SUM([@commonP].[Total])
			FROM
				@commonP
			WHERE 
				[Order] = 0
		END



		--********************************************************
		--   (SmartValue)
		
		SELECT
			@MaxValue = [Total]
		FROM
			@commonP
		WHERE
			[Order] = 1001
			
		IF @ScaleSelector = 3
		SET @Scale = 
			CASE  
				WHEN @MaxValue < 10000 THEN 1
				WHEN @MaxValue >= 10000 AND @MaxValue < 10000000 THEN 1000
				WHEN @MaxValue >= 10000000 AND @MaxValue < 10000000000 THEN 1000000
				WHEN @MaxValue >= 10000000000 THEN 1000000000
			END
		ELSE
		SET	@Scale = 
			CASE @ScaleSelector
				WHEN 0 THEN 1
				WHEN 1 THEN 1000
				WHEN 2 THEN 1000000
		END


		-- 		
		UPDATE @commonP
		SET
			[TimeMoney] = [TimeMoney] / @Scale,
			[ExpenseMoney] = [ExpenseMoney] / @Scale,
			[Total] = [Total] / @Scale



		--********************************************************
		-- .
		IF @CountSelector = 0
			SELECT
				[Order],
				[Employee].[FileAs] AS [Manager],
				[Company].[FileAs] AS [Company],
				[Project].[Number] AS [ProjectNumber],
				[PeriodStart],
				[PeriodEnd],
				[Time],
				[TimeMoney],
				[ExpenseMoney],
				[Total],
				@SortSelector AS [SortSelector]
			FROM
				@commonP 
				LEFT JOIN [Employee]
					ON [Employee].[ID] = [@commonP].[ManagerID]
				LEFT JOIN [Company]
					ON [Company].[ID] = [@commonP].[CompanyID]
				LEFT JOIN [Project]
					ON [Project].[ID] = [@commonP].[ProjectID]
			ORDER BY 
				[Employee].[FileAs],
				[Company],
				[Order]
		ELSE
		BEGIN
			DECLARE @commonPTopX TABLE
			(
				[Order] int,
				[ManagerID] TIdentifier,
				[CompanyID] TIdentifier,
				[ProjectID] TIdentifier,
				[PeriodStart] TDate,
				[PeriodEnd] TDate,
				[Time] TAmount,
				[TimeMoney] TAmount,
				[ExpenseMoney] TAmount,
				[Total] TAmount
			)

			--  @Count 
			INSERT INTO @commonPTopX
			SELECT TOP (@Count)
				*
			FROM
				@commonP
			WHERE
				[Order] = -1
			ORDER BY
				[Total] DESC

			--      
			INSERT INTO @commonPTopX
			SELECT 
				*
			FROM
				@commonP
			WHERE
				[Order] = 0
				AND
				[CompanyID] IN (SELECT [CompanyID] FROM @commonPTopX)
			
			
			--    
			INSERT INTO @commonPTopX
			SELECT
				1000,
				NULL,
				-1,
				NULL,
				NULL,
				NULL,
				SUM([Time]),
				SUM([TimeMoney]),
				SUM([ExpenseMoney]),
				SUM([Total])			
			FROM
				@commonP
			WHERE
				[CompanyID] NOT IN (SELECT DISTINCT [CompanyID] FROM @commonPTopX)
				AND
				[Order] = -1

			--      @common
			INSERT INTO @commonPTopX
			SELECT
				*
			FROM
				@commonP
			WHERE
				[Order] = 1001



			SELECT 
				[Order],
				[Employee].[FileAs] AS [Manager],
				CASE WHEN [Order] = 1000
					THEN ''
					ELSE [Company].[FileAs] 
				END AS [Company],
				[Project].[Number] AS [ProjectNumber],
				[PeriodStart],
				[PeriodEnd],
				[Time],
				[TimeMoney],
				[ExpenseMoney],
				[Total],
				@SortSelector AS [SortSelector]
			FROM
				@commonPTopX 
				LEFT JOIN [Employee]
					ON [Employee].[ID] = [@commonPTopX].[ManagerID]
				LEFT JOIN [Company]
					ON [Company].[ID] = [@commonPTopX].[CompanyID]
				LEFT JOIN [Project]
					ON [Project].[ID] = [@commonPTopX].[ProjectID]
			ORDER BY 
				[Employee].[FileAs],
				[Company], 
				[Order]
				
				
			-- ,       10 
			IF @Count < 11
			BEGIN
				INSERT INTO @Chart
				SELECT
					CASE WHEN [Order] = 1000
						THEN ''
						ELSE [Company].[FileAs] 
					END AS [Company],
					[Total]
				FROM
					@commonPTopX
					LEFT JOIN [Company]
						ON [Company].[ID] = [@commonPTopX].[CompanyID]
				WHERE
					[Order] IN (-1,1000)
			END				
		END		
	END


	--********************************************************
	--    	
	SELECT
		@ReportCurrency =
			CASE @CurrencySelector
				WHEN 0 THEN 
					CASE @ScaleSelector
						WHEN 0 THEN ' ' + @NationalCurrency
						WHEN 1 THEN ' . ' + @NationalCurrency
						WHEN 2 THEN ' . ' + @NationalCurrency
						WHEN 3 THEN
							CASE @Scale
								WHEN 1 THEN ' ' + @NationalCurrency
								WHEN 1000 THEN ' . ' + @NationalCurrency
								WHEN 1000000 THEN ' . ' + @NationalCurrency
								WHEN 1000000000 THEN ' . ' + @NationalCurrency
							END 
					END
				WHEN 1 THEN 
					CASE @ScaleSelector
						WHEN 0 THEN ' ' + @BaseCurrency
						WHEN 1 THEN ' . ' + @BaseCurrency
						WHEN 2 THEN ' . ' + @BaseCurrency
						WHEN 3 THEN
							CASE @Scale
								WHEN 1 THEN ' ' + @BaseCurrency
								WHEN 1000 THEN ' . ' + @BaseCurrency
								WHEN 1000000 THEN ' . ' + @BaseCurrency
								WHEN 1000000000 THEN ' . ' + @BaseCurrency
							END 
					END				
			END

	
	--********************************************************
	--  
	SELECT * FROM @Chart



	--********************************************************
	--  
	EXEC ReportFuturePeriodsRealizationHeader @OwnCompanyID, @ReportCurrency, @CompanyManagerSelector, @ManagerID, @CostCenterSelector, @CostCenterID,
		@ReportDate, @CountSelector, @Count, @SortSelector, @TypeSelector

	RETURN 0

GO
GRANT EXEC ON ReportFuturePeriodsRealization TO PUBLIC
GO