IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportGetPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportGetPeriod'
		DROP  Procedure  ReportGetPeriod
	END

GO

PRINT 'Creating Procedure ReportGetPeriod'
GO
/******************************************************************************
**		File:	ReportGetPeriod.sql
**		Name: 	ReportGetPeriod
**		Desc:	
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	16.04.09	MAN			first version
**		23.04.13	SAP			     
*******************************************************************************/

CREATE Procedure ReportGetPeriod
	@DateTypeSelector TIdentifier,
	@CapsFirstLetters bit = 0,
	@PeriodStart TDateTime OUTPUT,
	@PeriodEnd TDateTime OUTPUT,
	@PeriodName TName OUTPUT
AS
DECLARE
	@Date	TDate,
	@PeriodNameEnd TDateTime--     
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)

IF @DateTypeSelector = 0 -- current month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodEnd = DATEADD(day, 1, @Date),
		@PeriodNameEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))
ELSE IF @DateTypeSelector = 1 -- prev month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodStart = DATEADD(month, -1, @PeriodStart),
		@PeriodEnd = DATEADD(month, 1, @PeriodStart)
ELSE IF @DateTypeSelector = 2 -- quart
	Select
	@PeriodStart= DATEADD(q, DATEDIFF(q, 0, @Date), 0), 
	@PeriodEnd =   DATEADD(d,1,@Date),
	@PeriodNameEnd = DATEADD(day,-1, DATEADD(q, DATEDIFF(q, 0, @Date) + 1, 0))
ELSE IF @DateTypeSelector = 3 -- prev quart
	SELECT
	@PeriodStart= DATEADD(q, DATEDIFF(q, 0, DATEADD(q,-1, @Date)), 0), 
	@PeriodEnd =  DATEADD(q, DATEDIFF(q, 0, DATEADD(q,-1, @Date)) + 1, 0)
ELSE IF @DateTypeSelector = 4 -- curr year
	SELECT
		@PeriodStart = CAST(Year(@Date) as varchar(4)),
		@PeriodEnd = DATEADD(day, 1, @Date),
		@PeriodNameEnd =  DATEADD(day, -1, DATEADD(YEAR, 1, @PeriodStart))
ELSE IF @DateTypeSelector = 5 -- prev year
	SELECT
		@PeriodEnd = CAST(Year(@Date) as varchar(4)),
		@PeriodStart = CAST(Year(@Date)-1 as varchar(4))
ELSE IF @DateTypeSelector = 7 -- curr year FULL
	SELECT
		@PeriodStart = CAST(Year(@Date) as varchar(4)),
		@PeriodEnd = (DATEADD(DAY,-1,DATEADD(YEAR,1,@PeriodStart))),
		@PeriodNameEnd =  DATEADD(day, -1, DATEADD(YEAR, 1, @PeriodStart))
ELSE
	SELECT
		@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
		@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))

SELECT @PeriodNameEnd = ISNULL(@PeriodNameEnd, DATEADD(DAY,-1,@PeriodEnd))

EXEC Pjm6GetTimeIntervalFormatted @PeriodStart,   @PeriodNameEnd, 'ru', @CapsFirstLetters, @PeriodName  OUTPUT

RETURN 0
GO

GRANT EXEC ON ReportGetPeriod TO PUBLIC
GO