IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportStatisticsByIssues')
	BEGIN
		PRINT 'Dropping Procedure ReportStatisticsByIssues'
		DROP  Procedure  ReportStatisticsByIssues
	END

GO

PRINT 'Creating Procedure ReportStatisticsByIssues'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportStatisticsByIssues
	@DateSelector		int,
	@PeriodStart		Tdatetime,
	@PeriodEnd			Tdatetime,
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier
AS
	SET NOCOUNT ON	
	SET DATEFIRST 1
	
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE 
		@ProjectID TIdentifier
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END
			
	DECLARE 
		@Date			datetime
		
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)	

	IF @DateSelector = 0 -- week
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(weekday, @Date), @Date),
			@PeriodEnd = DATEADD(day, 1, @Date)

	IF @DateSelector = 1 -- prev week
		SELECT
			@PeriodStart = DATEADD(day, 1-7-DATEPART(weekday, @Date), @Date),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 2 -- month
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, 1, @Date)

	IF @DateSelector = 3 -- prev month
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodStart = DATEADD(month, -1, @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)

	IF @DateSelector = 4 -- quart
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodStart = DATEADD(month,1-CAST(DATEPART(month, @PeriodStart)/DATEPART(quarter, @PeriodStart) AS int), @PeriodStart),
			@PeriodEnd = DATEADD(day, 1, @Date)

	IF @DateSelector = 5 -- prev quart
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodStart = DATEADD(month,1-CAST(DATEPART(month, @PeriodStart)/DATEPART(quarter, @PeriodStart) AS int), @PeriodStart),
			@PeriodStart = DATEADD(quarter, -1, @PeriodStart),
			@PeriodEnd = DATEADD(quarter, 1, @PeriodStart)

	IF @DateSelector = 6 
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))
			
	IF @PeriodStart >= @PeriodEnd
	BEGIN
		RAISERROR('#InvalidPeriod', 16, -1)
		RETURN 1
	END

	EXECUTE ReportStatisticsByIssuesHeader @PeriodStart, @PeriodEnd
	
	SELECT
	[Issue].[Created],
	[Issue].[State],
	SUM(CASE WHEN [Issue].[State] IN (2,3,4) AND [Issue].[SeverityID] = 4
			THEN 1
		ELSE 0
	END) AS [ActiveCritical],
	SUM(CASE WHEN [Issue].[State] IN (2,3,4)
			THEN 1
		ELSE 0
	END) AS [ActiveAll],
	SUM(CASE WHEN [Issue].[State] = 6
			THEN 1
		ELSE 0
	END) AS [Deferred],
	SUM(CASE WHEN [Issue].[State] = 5
			THEN 1
		ELSE 0
	END) AS [Closed]
	FROM 
		[Issue]
	WHERE
		[Issue].[ProjectID] = @ProjectID
	GROUP BY	
		[Issue].[Created],
		[Issue].[State]
	


RETURN 0
GO

GRANT EXEC ON ReportStatisticsByIssues TO PUBLIC

GO
