IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaWordInvoice')
	BEGIN
		PRINT 'Dropping Procedure VistaWordInvoice'
		DROP  Procedure  VistaWordInvoice
	END

GO

PRINT 'Creating Procedure VistaWordInvoice'
GO

CREATE Procedure VistaWordInvoice
	@ID int,
	@Language Tname = NULL	
AS
	SET NOCOUNT ON
	DECLARE
		@Total money,
		@TotalWithVAT money,
		@VAT money	,
		@TotalCount int,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@Currency TName,
		@AdvanceValue TMoney,
		@AdvanceValueWithoutVAT TMoney,
		@AdvanceVAT TMoney,
		@PaymentValue TMoney,
		@PaymentVAT TMoney,
		@RemainValue TMoney,
		@RemainVAT TMoney,
		@Class TClass,
		@Code TName,
		@CompanyClass TClass,
		@EmployeeClass TClass,
		@ProjectID TIdentifier,
		@ContactID TIdentifier,
		@SupplierID TIdentifier,
		@CustomerID TIdentifier,
		@CurrencyCode TCode,
		@OfferRu nvarchar(2000),
		@OfferEn nvarchar(2000),
		@CustomerAddressPresent BIT
		
		
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @Code = CASE WHEN @Language = 'en' THEN 'Invoice; ' ELSE '; ' END	
	
	SELECT
		@ProjectID = [Project].[ID],
		@ContactID = [Project].[ResponsiblePersonEmployeeID],
		@Currency = CASE [Project].[InvoiceCurrency] WHEN 0 THEN 'Project' ELSE 'Payment' END,
		@CurrencyCode = CASE [Project].[InvoiceCurrency] WHEN 0 THEN [Project].[CurrencyCode] ELSE [Invoice].[CurrencyCode] END,
		@Class = [Invoice].[Class],
		@Total = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalPC]
			ELSE [Invoice].[Total]
		END,
		@VAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[VATPC]
			ELSE [Invoice].[VAT]
		END,
		@TotalWithVAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalWithVATPC]
			ELSE [Invoice].[TotalWithVAT]
		END,
		@SupplierID = [Invoice].[SupplierCompanyID],
		@CustomerID = [Invoice].[CustomerCompanyID],
		@OfferEn= dbo.adfPropertyValueGetText([Project].[Class], [Project].[ID], '00000002-0000-0000-0000-000000000000'),
		@OfferRu= dbo.adfPropertyValueGetText([Project].[Class], [Project].[ID], '00000001-0000-0000-0000-000000000000')
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE
		[Invoice].[ID] = @ID	
		
	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0)),
		@AdvanceVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[VAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[VATPC]
			END, 0.0)),
		@AdvanceValueWithoutVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[Total]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalPC]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	
		
	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [PaymentDetail].[PaymentValue]
				WHEN @Currency = 'Project'
					THEN [PaymentDetail].[Value]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
		INNER JOIN [PaymentDetail]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	
	SET @PaymentValue = ISNULL(@PaymentValue, 0)
	
	SET @RemainValue =
		CASE 
			WHEN @TotalWithVAT > ISNULL(@AdvanceValue, 0.0) THEN @TotalWithVAT - ISNULL(@AdvanceValue, 0.0) 
			ELSE 0.0
		END
	SET @RemainVAT =
		CASE
			WHEN @VAT > ISNULL(@AdvanceVAT, 0.0) THEN @VAT - ISNULL(@AdvanceVAT, 0.0) 
			ELSE 0.0
		END

	DECLARE @t TABLE(
		[ID] TIdentifier,
		[Class] TClass,
		[Description] TNotes,
		[Amount] TAmount,
		[Price] Tmoney,
		[Total] Tmoney,
		[VATRate] TMoney,
		[VAT] Tmoney,
		[PriceWithVAT] Tmoney,
		[TotalWithVAT] Tmoney,
		[UOMID] TIdentifier,
		[ServiceTypeID] TIdentifier,
		[ServiceTypeFileAs] TName,
		[CalculationNumber] TCode,
		[CalculationDate] Tdate	,
		[ServiceName] TNotes,
		[ServiceNameOtherLang] TNotes	
	)
		
	IF @Currency = 'Payment'
	BEGIN
	INSERT INTO @t
			([ID],
			[Class],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],
			[CalculationNumber], [CalculationDate],
			[ServiceName],
			[ServiceNameOtherLang])
		
		SELECT
			[InvoiceLine].[ID],
			CASE [Calculation].[DocumentClass]
				WHEN dbo.adfGetClassByName('Pjm5.ServiceRequest') THEN 1
				WHEN dbo.adfGetClassByName('Pjm5.TimeEntry') THEN 2
				WHEN dbo.adfGetClassByName('Pjm5.Expense') THEN 3
				WHEN dbo.adfGetClassByName('Pjm5.PhoneCall') THEN 4
				ELSE 5
			END,
			[InvoiceLine].[Description],
			[InvoiceLine].[Amount],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[Price] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[Price] 
				END,
			[InvoiceLine].[VATRate],
			[InvoiceLine].[VAT],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[Price] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[Price] 
				END,
			[InvoiceLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[Calculation].[Number],
			[Calculation].[Date],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]),
			COALESCE(
				dbo.adfPropertyValueGetText([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID],
					'00000001-0000-0000-0000-000000000000'),
				 dbo.adfPropertyValueGetText([Service].[Class],[Service].[ID],
					'00000001-0000-0000-0000-000000000000'),[Service].[FileAs])	
		FROM
			[InvoiceLine]
			LEFT OUTER JOIN [ServiceType]
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT OUTER JOIN [Calculation]
				ON [InvoiceLine].[DocumentClass] = [Calculation].[Class] AND
					[InvoiceLine].[DocumentID] = [Calculation].[ID]	
			LEFT OUTER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [InvoiceLine].[DocumentID] AND
					[ServiceAssignment].[Class] = [InvoiceLine].[DocumentClass]	
			LEFT OUTER JOIN [Service]
				ON [ServiceAssignment].[ServiceID] = [Service].[ID]		
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END
	ELSE
	BEGIN
		INSERT INTO @t
			([ID],
			[Class],
			[Description],
			[Amount],[Price],[Total],
			[VATRate],[VAT],
			[PriceWithVAT],[TotalWithVAT],
			[UOMID],[ServiceTypeID],[ServiceTypeFileAs],
			[CalculationNumber], [CalculationDate],
			[ServiceName],
			[ServiceNameOtherLang])
		
		SELECT
			[InvoiceLine].[ID],
			CASE [Calculation].[DocumentClass]
				WHEN dbo.adfGetClassByName('Pjm5.ServiceRequest') THEN 1
				WHEN dbo.adfGetClassByName('Pjm5.TimeEntry') THEN 2
				WHEN dbo.adfGetClassByName('Pjm5.Expense') THEN 3
				WHEN dbo.adfGetClassByName('Pjm5.PhoneCall') THEN 4
				ELSE 5
			END,
			[InvoiceLine].[Description],
			[InvoiceLine].[Amount],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[PricePC] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[PricePC] 
				END,
			[InvoiceLine].[VATRate],
			[InvoiceLine].[VATPC],
			CASE 
				WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
					THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] + [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
				ELSE [InvoiceLine].[PricePC] 	 
			END,
			[InvoiceLine].[Amount] * 	
				CASE 
					WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
						THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] + [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount]	
					ELSE [InvoiceLine].[PricePC] 
				END,
			[InvoiceLine].[UOMID],
			[ServiceType].[ID],
			[ServiceType].[FileAs],
			[Calculation].[Number],
			[Calculation].[Date],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]),
			COALESCE(
				dbo.adfPropertyValueGetText([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID],
					'00000001-0000-0000-0000-000000000000'),
				 dbo.adfPropertyValueGetText([Service].[Class],[Service].[ID],
					'00000001-0000-0000-0000-000000000000'),[Service].[FileAs])	
		FROM
			[InvoiceLine]
			LEFT OUTER JOIN [ServiceType]
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			LEFT OUTER JOIN [Calculation]
				ON [InvoiceLine].[DocumentClass] = [Calculation].[Class] AND
					[InvoiceLine].[DocumentID] = [Calculation].[ID]	
			LEFT OUTER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [InvoiceLine].[DocumentID] AND
					[ServiceAssignment].[Class] = [InvoiceLine].[DocumentClass]	
			LEFT OUTER JOIN [Service]
				ON [ServiceAssignment].[ServiceID] = [Service].[ID]		
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END
	
	/*DECLARE @AdvanceID int
	SELECT @AdvanceID = [ID] FROM @t WHERE [Class] IN (1, 2)
	UPDATE 
		@t
	SET 
		[Total] = [Total] - ISNULL(@AdvanceValue - @AdvanceVAT, 0),
		[Price] = [Price] - ISNULL(@AdvanceValue - @AdvanceVAT, 0),
		[TotalWithVAT] = [TotalWithVAT] - ISNULL(@AdvanceValue, 0),
		[PriceWithVAT] = [PriceWithVAT] - ISNULL(@AdvanceValue, 0),
		[VAT] = [VAT] - ISNULL(@AdvanceVAT, 0)
	WHERE
		[ID] = @AdvanceID*/
			
	SELECT
		@TotalCount = COUNT(*),
		@VATRate = MAX([VATRate]),
		@VATRateCount = COUNT(DISTINCT [VATRate])
	FROM
		@t

	SELECT
		[Invoice].[ID],
		[Invoice].[FileAs],
		[Invoice].[Number],
		[Invoice].[Date],
		[Invoice].[DueDate],
		(CASE WHEN [Invoice].[InvoiceExpirationPeriodType] = 1 THEN
			dbo.fnPjm5GetWorkingDays([Invoice].[Date], [Invoice].[DueDate]) 
		ELSE
			DATEDIFF(day, [Invoice].[Date], [Invoice].[DueDate]) + 1
		END) AS [ExpirationPeriod],
		[Invoice].[InvoiceExpirationPeriodType] as [ExpirationPeriodType],
		
		[Invoice].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Invoice].[SupplierCompanyID],
		[Invoice].[CustomerCompanyID],

		[BankAccount].[ID] AS [BankAccountID],
		[BankAccount].[BankName] AS [BankName],
		[BankAccount].[IntermediaryBank] AS [SBankName],
		[BankAccount].[City] AS [BankCity],
		[BankAccount].[BankCode] AS [BankCode],
		[BankAccount].[Account] AS [CAccount],
		[BankAccount].[IntermediaryAccount] AS [SAccount],
		[BankAccount].[IntermediarySWIFT] AS [IntermediarySWIFT],

		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],

		[SupplierCompany].[LegalCode] AS [SupplierCompanyLegalCode],
		[SupplierCompany].[KPP] AS [SupplierCompanyKPP],

		[CustomerCompany].[LegalCode] AS [CustomerCompanyLegalCode],
		[CustomerCompany].[KPP] AS [CustomerCompanyKPP],

		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerExecutive].[LastName] + 
			ISNULL(' ' + [CustomerExecutive].[FirstName], '') + 
				ISNULL(' ' + [CustomerExecutive].[MiddleName], '') AS [CustomerExecutiveName],
		[CustomerExecutive].[FileAs] AS [CustomerExecutiveFileAs],
		[CustomerExecutivePosition].[ID] AS [CustomerExecutivePositionID],
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePositionFileAs],

		[CustomerContact].[ID] AS [CustomerContactEmployeeID],
		[CustomerContact].[LastName] + 
			ISNULL(' ' + [CustomerContact].[FirstName], '') + 
				ISNULL(' ' + [CustomerContact].[MiddleName], '') AS [CustomerContactName],
		[CustomerContact].[FileAs] AS [CustomerContactFileAs],
		[CustomerContactPosition].[ID] AS [CustomerContactPositionID],
		[CustomerContactPosition].[FileAs] AS [CustomerContactPositionFileAs],

		[SupplierCompany].[ExecutiveEmployeeID] AS [SupplierExecutiveEmployeeID],
		[SupplierExecutive].[LastName] + 
			ISNULL(' ' + [SupplierExecutive].[FirstName], '') + 
				ISNULL(' ' + [SupplierExecutive].[MiddleName], '') AS [SupplierExecutiveName],
		[SupplierExecutive].[FileAs] AS [SupplierExecutiveFileAs],
		[SupplierExecutivePosition].[ID] AS [SupplierExecutivePositionID],
		[SupplierExecutivePosition].[FileAs] AS [SupplierExecutivePositionFileAs],

		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		[SupplierAccountant].[LastName] + 
			ISNULL(' ' + [SupplierAccountant].[FirstName], '') + 
				ISNULL(' ' + [SupplierAccountant].[MiddleName], '') AS [SupplierAccountantName],
		[SupplierAccountant].[FileAs] AS [SupplierAccountantFileAs],
		[SupplierAccountantPosition].[ID] AS [SupplierAccountantPositionID],
		[SupplierAccountantPosition].[FileAs] AS [SupplierAccountantPositionFileAs],

		@Total-ISNULL(@AdvanceValue - @AdvanceVAT, 0) AS [Total],
		@VAT - ISNULL(@AdvanceVAT, 0) AS [VAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @Total
			ELSE @Total + @VAT
		END - ISNULL(@AdvanceValue, 0) AS [TotalWithVAT],
		CASE
			WHEN @Total IS NULL THEN 0
			ELSE 1
		END	AS [TotalFlag],
		
		dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode) AS [TotalCurrencyCode],
		dbo.fnPjm5CurrencyToString(@VAT, @CurrencyCode) AS [VATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@Total + @VAT), @CurrencyCode)
		END AS [TotalWithVATCurrencyCode],

		@AdvanceValue AS [AdvanceValue],
		@AdvanceVAT AS [AdvanceVAT],
		@AdvanceValueWithoutVAT AS [AdvanceValueWithoutVAT],
		CASE
			WHEN ISNULL(@AdvanceValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		dbo.fnPjm5CurrencyToString(@AdvanceValue, @CurrencyCode) AS [AdvanceValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@AdvanceVAT, @CurrencyCode) AS [AdvanceVATCurrencyCode],

		@PaymentValue AS [PaymentValue],
		@PaymentVAT AS [PaymentVAT],
		CASE
			WHEN ISNULL(@PaymentValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [PaymentFlag],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode) AS [PaymentValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode) AS [PaymentVATCurrencyCode],

		@RemainValue AS [RemainValue],
		@RemainVAT AS [RemainVAT],
		CASE
			WHEN ISNULL(@RemainValue, 0.0) = 0 THEN 0
			ELSE 1
		END	AS [RemainFlag],
		dbo.fnPjm5CurrencyToString(@RemainValue, @CurrencyCode) AS [RemainValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@RemainVAT, @CurrencyCode) AS [RemainVATCurrencyCode],
		
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],
		@TotalCount AS [TotalCount],
		CASE @Currency WHEN 'Payment' THEN [Currency].[ID] ELSE [ProjectCurrency].[ID] END AS [CurrencyID],
		CASE @Currency WHEN 'Payment' THEN [Currency].[FileAs] ELSE [ProjectCurrency].[FileAs] END AS [CurrencyFileAs],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Code] ELSE [ProjectCurrency].[Code] END AS [CurrencyCode],
		CASE 
			WHEN @Currency = 'Payment' AND
				dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			WHEN @Currency != 'Payment' AND
				dbo.adfPropertyValueGetText([ProjectCurrency].[Class], [ProjectCurrency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		[Invoice].[CurrencyCode] AS [InvoiceCurrency],
		CASE 
			WHEN @OfferEn = CAST('Offer' AS nvarchar(2000)) OR
				@OfferRu = CAST('' AS nvarchar(2000)) OR
				@OfferEn = CAST('offer' AS nvarchar(2000)) OR
				@OfferRu = CAST('' AS nvarchar(2000))
			THEN 1 
			ELSE 0 
		END AS [OfferFlag]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Invoice].[CurrencyCode] = [Currency].[Code]
		INNER JOIN [Currency] AS [InvoiceCurrency]
			ON [Invoice].[CurrencyCode] = [InvoiceCurrency].[Code]
		INNER JOIN [Currency] AS [ProjectCurrency]
			ON [Project].[CurrencyCode] = [ProjectCurrency].[Code]
			
		INNER JOIN [Company] AS [SupplierCompany]	
			ON [Invoice].[SupplierCompanyID] = [SupplierCompany].[ID]
		INNER JOIN [Company] AS [CustomerCompany]	
			ON [Invoice].[CustomerCompanyID] = [CustomerCompany].[ID]
			
		LEFT OUTER JOIN [Employee] AS [SupplierExecutive]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutive].[PositionID] = [SupplierExecutivePosition].[ID]

		LEFT OUTER JOIN [Employee] AS [SupplierAccountant]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountant].[PositionID] = [SupplierAccountantPosition].[ID]

		LEFT OUTER JOIN [Employee] AS [CustomerExecutive]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutive].[PositionID] = [CustomerExecutivePosition].[ID]

		LEFT OUTER JOIN [Employee] AS [CustomerContact]
			ON [Project].[ResponsiblePersonEmployeeID] = [CustomerContact].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerContactPosition]
			ON [CustomerContact].[PositionID] = [CustomerContactPosition].[ID]

		LEFT OUTER JOIN [BankAccount]
			ON [Invoice].[SupplierBankAccountID] = [BankAccount].[ID]
	WHERE 
		[Invoice].[ID] = @ID		

	SELECT
		[ID],
		[Description],
		[Amount],
		[Price],
		CASE WHEN [Class]=1 THEN [Total]-ISNULL(@AdvanceValueWithoutVAT,0.0) ELSE [Total] END AS [Total],
		[VAT],
		[PriceWithVAT],
		CASE WHEN [Class]=1 THEN [TotalWithVAT]-ISNULL(@AdvanceValue,0.0) ELSE [Total] END AS [TotalWithVAT],
		[UOMID],
		[ServiceTypeID],
		[ServiceTypeFileAs],
		[CalculationNumber],
		[CalculationDate],
		[Class],
		[ServiceName],
		[ServiceNameOtherLang]
	FROM
		@t
	ORDER BY
		[ServiceTypeFileAs] ASC,
		[Description] ASC
	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString],
		@SupplierID AS [SupplierCompanyID]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @SupplierID AND 
		[Address].[BusinessCardClass] = @CompanyClass  

	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street],[Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString],
		@CustomerID AS [CustomerCompanyID]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @CustomerID AND 
		[Address].[BusinessCardClass] = @CompanyClass

		
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Invoice].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Invoice].[ID] = @ID

		
RETURN 0
GO

GRANT EXEC ON VistaWordInvoice TO PUBLIC

GO
