IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5GenerateStatementFromInvoice]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5GenerateStatementFromInvoice'
		DROP PROCEDURE [dbo].[pjm5GenerateStatementFromInvoice]
	END
GO

PRINT 'Creating procedure pjm5GenerateStatementFromInvoice'
GO

/******************************************************************************
**		File: pjm5GenerateStatementFromInvoice.sql
**		Name: pjm5GenerateStatementFromInvoice
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		19.04.10	SPV				     
									 
**		21.10.13	SOV				   ,   
**									     
**		18.11.13	SAP				     
**									   ,   
**		25.02.14	SAP				       
**		29.04.14	SAP				    [IsEditedInPaymentCurrency]    
*******************************************************************************/
CREATE PROCEDURE [pjm5GenerateStatementFromInvoice]
	@ID TIdentifier,
	@Number TCode,
	@Date TDate,
	@FileAs TName,
	@PeriodStart TDate,
	@PeriodEnd TDate,
	@CurrencyCode TCode3,
	@CurrencyRate TMoney
AS
	DECLARE @State TState,
			@StatementID TIdentifier,
			@Class TClass,
			@InvoiceClass TClass,
			@InvoiceState TClass,
			@InvoiceIsAdvance TBool,
			@Guid TGuid,
			@ProjectID TIdentifier,
			@ProjectCurrencyCode TCode3,
			@InvoiceCurrencyCode TCode3,
			@StatementCurrencyRate TMoney,
			@InvoiceBaseCurrencyRate TMoney,
			@StatementBaseCurrencyRate TMoney,
			@CalculationClass TClass,
			@ExpenseClass TClass,
			@ApplyVAT TBool,
			@value TVariant,
			@rv int,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount,
			@ServiceTypeID TIdentifier
	
	SET NOCOUNT ON
	
	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	SET @Class = dbo.adfGetClassByName('Pjm5.Statement')
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET @CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET @ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')

	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrencyCode TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value as varchar(3))
	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrencyCode = CAST(@value as varchar(3))
	SELECT
		@ProjectID = [Invoice].[ProjectID],
		@InvoiceCurrencyCode = [Invoice].[CurrencyCode],
		@InvoiceBaseCurrencyRate = [Invoice].[BaseCurrencyRate],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@ApplyVAT = [Project].[ApplyVAT],
		@InvoiceState = [Invoice].[State],
		@InvoiceIsAdvance = [Invoice].[Advance],
		@SupplierCompanyID = [Invoice].[SupplierCompanyID],
		@CustomerCompanyID = [Invoice].[CustomerCompanyID],
		@Scale = [Invoice].[Scale]
	FROM 
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE
		[Invoice].[ID] = @ID

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllStatements')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END	
		
	SET @StatementCurrencyRate = @CurrencyRate
	IF @ProjectCurrencyCode = @CurrencyCode
		SET @StatementCurrencyRate = 1.0

	IF @InvoiceCurrencyCode = @BaseCurrencyCode
		SET @StatementBaseCurrencyRate = @CurrencyRate
	ELSE IF @CurrencyCode = @BaseCurrencyCode 
		SET @StatementBaseCurrencyRate = @InvoiceBaseCurrencyRate
	ELSE IF @ProjectCurrencyCode = @BaseCurrencyCode
		SET @StatementBaseCurrencyRate = 1.0
		
	DECLARE @c1 TCode3, @c2 TCode3
	IF @StatementCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @CurrencyCode
		BEGIN
			SET @c1 = @ProjectCurrencyCode
			SET @c2 = @CurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @ProjectCurrencyCode
			SET @c1 = @CurrencyCode
		END

		SELECT
			@StatementCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	IF @StatementBaseCurrencyRate IS NULL
	BEGIN
		IF @NationalCurrencyCode = @ProjectCurrencyCode
		BEGIN
			SET @c1 = @BaseCurrencyCode
			SET @c2 = @ProjectCurrencyCode
		END
		ELSE
		BEGIN
			SET @c2 = @BaseCurrencyCode
			SET @c1 = @ProjectCurrencyCode
		END

		SELECT
			@StatementBaseCurrencyRate = [Rate]
		FROM
			[CurrencyRate]
		WHERE
			[FromCurrencyCode] = @c1 AND 
			[ToCurrencyCode] = @c2 AND
			@Date BETWEEN [ValidFrom] AND [ValidTo]
	END

	DECLARE @lines TABLE (
		ID                   int,
		DocumentClass        int,
		DocumentID           int,
		Description          nvarchar(max),
		Amount               decimal(18,4),
		VATRate              decimal(18,4),
		VATIsIncluded        bit,
		Price				 money null,
		VAT					 money null,
		PricePC              money,
		VATPC                money,
		UOMID				 int null,
		ServiceTypeID		 int null,
		BasePrice			 int,
		SortKey				 varchar(32)
		)	
	DECLARE
		@lineID int,
		@lineInvoiceID int, @lineDocumentClass int, @lineDocumentID int, @lineDescription nvarchar(max),
		@lineAmount decimal(18, 4), @lineVATRate decimal(18, 4),
		@lineVATIsIncluded bit,
		@linePrice money, @lineVAT money, @linePricePC money,
		@lineVATPC money, @lineUOMID int, @lineServiceTypeID int, @lineBasePrice int, 
		@lineSortKey varchar(32), @lineEditedInPaymentCurrency bit
	DECLARE lines CURSOR FAST_FORWARD READ_ONLY FOR
		SELECT
			[ID],
			[InvoiceID], [DocumentClass], [DocumentID], [Description],
			[Amount], [VATRate], [VATIsIncluded],
			[Price], [VAT], [PricePC], [VATPC], [UOMID], [ServiceTypeID], [BasePrice], [SortKey],
			[EditedInPaymentCurrency]
		FROM
			[InvoiceLine]
		WHERE
			[InvoiceID] = @ID
			
	OPEN lines
	FETCH NEXT FROM lines INTO
		@lineID,
		@lineInvoiceID, @lineDocumentClass, @lineDocumentID, @lineDescription,
		@lineAmount, @lineVATRate,
		@lineVATIsIncluded,
		@linePrice, @lineVAT, @linePricePC,
		@lineVATPC, @lineUOMID, @lineServiceTypeID, @lineBasePrice, @lineSortKey,
		@lineEditedInPaymentCurrency
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @ProjectCurrencyCode = @CurrencyCode
		BEGIN
			SET @linePrice = @linePricePC
			SET @lineVAT = @lineVATPC
		END
		ELSE
		BEGIN
			DECLARE @continue bit, @t1 money, @t2 money, @vi bit, @cc TCode3, @vt money
			SET @continue = 1
	
			IF @lineDocumentClass = @CalculationClass
			BEGIN
				SELECT 
					@t1 = [Total], @t2 = [TotalWithVAT], @vt = [VAT], @cc = [CurrencyCode]
				FROM
					[Calculation]
				WHERE	
					[ID] = @lineDocumentID
				IF @cc = @CurrencyCode
				BEGIN
					IF @lineVATIsIncluded = 0 OR @ApplyVAT = 0 SET @linePrice = @t1 ELSE SET @linePrice = @t2
					IF @ApplyVAT = 1 SET @lineVAT = @vt ELSE SET @lineVAT = 0.0

					IF @ProjectCurrencyCode = @CurrencyCode
						SET @continue = 0
					ELSE
						SET @continue = 1
				END
			END 
			ELSE IF @lineDocumentClass = @ExpenseClass
			BEGIN
				SELECT 
					@t1 = [Price], @t2 = [Amount], @vt = [VAT], @vi = [VATIsIncluded], @cc = [FromCurrencyCode]
				FROM
					[Expense]
				WHERE	
					[ID] = @lineDocumentID
				IF @cc = @CurrencyCode
				BEGIN
					SET @lineVATIsIncluded = @vi
					IF @lineVATIsIncluded = @ApplyVAT OR @lineVATIsIncluded = 0
						SET @linePrice = @t1 
					ELSE
						SET @linePrice = ROUND((@t1 * @t2 - @vt) / @t2, 2)
					IF @ApplyVAT = 1 SET @lineVAT = @vt ELSE SET @lineVAT = 0.0
					
					IF @ProjectCurrencyCode = @CurrencyCode
							SET @continue = 0
						ELSE
							SET @continue = 1
				END
			END
			IF @continue = 1
			BEGIN
				DECLARE	
					@TVWPC money,
					@TVW money,
					@Ttl money,
					@TtlPC money,
					@V money,
					@VPC money,
					@PVW money,
					@PVWPC money,
					@P money,
					@PPC money

				IF @lineEditedInPaymentCurrency = 0
				BEGIN
					IF @lineVATIsIncluded = 1
						SET @TVWPC = @linePricePC * @lineAmount
					ELSE
						SET @TVWPC = @linePricePC * @lineAmount + @lineVATPC

					IF @CurrencyCode = @NationalCurrencyCode
						SET @TVW = ROUND(@TVWPC * @CurrencyRate,2)
					ELSE
						SET @TVW = ROUND(@TVWPC / @CurrencyRate,2)
					SET @V = ROUND(@TVW * @lineVATRate / (1 + @lineVATRate), 2)
					SET @Ttl = @TVW - @V
					SET @PVW = ROUND(@TVW / @lineAmount, 2)
					SET @P = ROUND(@Ttl / @lineAmount, 2)

					IF @lineVATIsIncluded = 0
						SET @linePrice = @P
					ELSE
						SET @linePrice = @PVW

					SET @lineVAT = @V
				END
				ELSE
				BEGIN
					IF @lineVATIsIncluded = 1
						SET @TVW = @linePrice * @lineAmount
					ELSE
						SET @TVW = @linePrice * @lineAmount + @lineVAT

					IF @CurrencyCode = @NationalCurrencyCode
							SET @TVWPC = ROUND(@TVW / @CurrencyRate,2)
						ELSE
							SET @TVWPC = ROUND(@TVW * @CurrencyRate,2)
					SET @VPC = ROUND(@TVWPC * @lineVATRate / (1 + @lineVATRate), 2)
					SET @TtlPC = @TVWPC - @VPC
					SET @PVWPC = ROUND(@TVWPC / @lineAmount, 2)
					SET @PPC = ROUND(@TtlPC / @lineAmount, 2)

					IF @lineVATIsIncluded = 0
						SET @linePricePC = @PPC
					ELSE
						SET @linePricePC = @PVWPC

					SET @lineVATPC = @VPC
				END
			END
		END
		INSERT INTO @lines 
			(
			ID, DocumentClass, DocumentID, Description,
			Amount, VATRate, VATIsIncluded, Price, VAT, PricePC, VATPC, UOMID, ServiceTypeID, BasePrice, SortKey
			)
		VALUES 
			(@lineID, @lineDocumentClass, @lineDocumentID, @lineDescription,
			@lineAmount, @lineVATRate, @lineVATIsIncluded,
			@linePrice, @lineVAT, 
			@linePricePC, @lineVATPC, @lineUOMID, @lineServiceTypeID, @lineBasePrice, @lineSortKey
			)
			
		FETCH NEXT FROM lines INTO
			@lineID, 
			@lineInvoiceID, @lineDocumentClass, @lineDocumentID, @lineDescription,
			@lineAmount, @lineVATRate,
			@lineVATIsIncluded,
			@linePrice, @lineVAT, @linePricePC,
			@lineVATPC, @lineUOMID, @lineServiceTypeID, @lineBasePrice, @lineSortKey,
			@lineEditedInPaymentCurrency
	END
	CLOSE lines
	DEALLOCATE lines

	BEGIN TRANSACTION
	INSERT INTO [Statement]
		([Flag], [State], [Date], [Number], [FileAs], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], [CurrencyCode],
		 [Periodical], 
		 [PeriodStart], [PeriodEnd],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale])
	VALUES(0, @State, @Date, @Number, @FileAs, @ProjectID,
		@StatementCurrencyRate, @StatementBaseCurrencyRate, @CurrencyCode,
		0,
		@PeriodStart, @PeriodEnd,
		@SupplierCompanyID, @CustomerCompanyID,
		@Scale)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @StatementID = SCOPE_IDENTITY()

	INSERT INTO [StatementLine] (
		[StatementID], [DocumentClass], [DocumentID], [Description], [Amount], [VATIsIncluded], [VATRate], 
		[PricePC], [VATPC],
		[Price], [VAT], 
		[UOMID], [ServiceTypeID],
		[BasePrice],
		[SortKey],
		[EditedInPaymentCurrency])
	SELECT 
		@StatementID, 
		[L].[DocumentClass], [L].[DocumentID], [L].[Description], [L].[Amount], [L].[VATIsIncluded], 
		[L].[VATRate], 
		[L].[PricePC], [L].[VATPC],
		[L].[Price], [L].[VAT],
		[L].[UOMID], [L].[ServiceTypeID], [L].[BasePrice],[L].[SortKey], 
		[InvoiceLine].[EditedInPaymentCurrency]
	FROM 
		@lines as [L]
		INNER JOIN [InvoiceLine]
			ON [InvoiceLine].[ID] = [L].[ID]
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF @InvoiceIsAdvance = 0
	BEGIN
		INSERT [StatementAdvanceInvoice] ([StatementID], [AdvanceInvoiceID], 
			[StatementPaymentValue], [StatementPaymentVAT], [StatementPaymentValuePC], [StatementPaymentVATPC])
		SELECT
			@StatementID,
			[AdvanceInvoice].[AdvanceInvoiceID],
			ISNULL(SUM([PaymentDetail].[PaymentValue]), 0),
			ISNULL(SUM([PaymentDetail].[PaymentVAT]), 0),
			ISNULL(SUM([PaymentDetail].[Value]), 0),
			ISNULL(SUM([PaymentDetail].[VAT]), 0)
		FROM
			[AdvanceInvoice]
			INNER JOIN [Invoice]
				ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
			LEFT OUTER JOIN [PaymentDetail]
				ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		WHERE
			[AdvanceInvoice].[InvoiceID] = @ID
		GROUP BY
			[AdvanceInvoice].[AdvanceInvoiceID]
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END	
	END
	ELSE IF @InvoiceState IN (2, 5) AND @InvoiceCurrencyCode = @CurrencyCode
	BEGIN
		INSERT [StatementAdvanceInvoice] ([StatementID], [AdvanceInvoiceID],
			[StatementPaymentValue], [StatementPaymentVAT], [StatementPaymentValuePC], [StatementPaymentVATPC])
		SELECT 
			@StatementID, 
			[Invoice].[ID],
			ISNULL(SUM([PaymentDetail].[PaymentValue]), 0),
			ISNULL(SUM([PaymentDetail].[PaymentVAT]), 0),
			ISNULL(SUM([PaymentDetail].[Value]), 0),
			ISNULL(SUM([PaymentDetail].[VAT]), 0)
		FROM
			[Invoice]
			LEFT OUTER JOIN [PaymentDetail]
				ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		WHERE
			[Invoice].[ID] = @ID
		GROUP BY
			[Invoice].[ID]
			
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END	
	END
	IF @InvoiceIsAdvance = 0
	BEGIN
		INSERT INTO [Attachment]
			(
			[DocumentClass], [DocumentID], [Name],
			[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
			)
		VALUES
			(@Class, @StatementID, '',
			@InvoiceClass, @ID, 2)	
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END	
		
		INSERT INTO [Attachment]
			(
			[DocumentClass], [DocumentID], [Name],
			[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
			)
		VALUES
			(@InvoiceClass, @ID, '',
			@Class, @StatementID, 2)	
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END	
	END
	
	COMMIT TRANSACTION
	
	SELECT
		@Class			AS [Class],
		@StatementID	AS [ID],
		@State			AS [State],
		@FileAs			AS [FileAs]
		
	RETURN 0
GO

GRANT EXECUTE ON pjm5GenerateStatementFromInvoice TO PUBLIC
GO
 