IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6TimeEntryGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6TimeEntryGet'
		DROP PROCEDURE [dbo].[pjm6TimeEntryGet]
	END
GO

PRINT 'Creating procedure pjm6TimeEntryGet'
GO

/******************************************************************************
**		File: pjm6TimeEntryGet.sql
**		Name: pjm6TimeEntryGet
**
**              
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      26.03.09	ENB				      
**									,     
**									   
**								      Description
**
**		29.03.10	KOV				     
**									@DocumentClass = dbo.adfGetClassByName('...')
**		18.08.11	SYV				 accessdenied
**		05.04.13	SOV				. -       
**		13.05.13	SOV				. -    
**		23.08.13	SOV				      
**									     
**		27.08.13	SOV				      
**									    . 
*******************************************************************************/
CREATE PROCEDURE [pjm6TimeEntryGet]
	@ID TIdentifier
AS

	SET NOCOUNT ON

	DECLARE
		@TimeEntryClass				TClass,
		@ServiceAssignmentClass		TClass,
		@RecurrencePatternID		TIdentifier,
		@UserID						TIdentifier,
		@EmployeeID					TIdentifier,
		@Lang						TLanguage,
		@ViewAllFinance				TBool,
		@ViewAllProjects			TBool, 
		@Assistant					TBool,
		@CanViewTimeEntries			TBool,
		@DocumentID					TIdentifier,
		@DocumentClass				TIdentifier,
		@DocumentName				TName,
		@DocumentClassName			TName,
		@ProjectManagerEmployeeID	TIdentifier,
		@ProjectID					TIdentifier,
		@TimeEntryEmployeeID		TIdentifier,
		@TimeEntryProjectID			TIdentifier,
		@value						TVariant
	
	SET @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')	
	SET @UserID	= dbo.adfGetCurrentUserID()
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @Lang = dbo.adfGetLanguage()
	
	SET @ViewAllFinance = dbo.adfHasAccessRightByName('ViewAllFinance')
	SET @ViewAllProjects = dbo.adfHasAccessRightByName('ViewAllProjects')
	SET @Assistant = dbo.adfHasAccessRightByName('Assistant')
	
	IF (@ViewAllFinance = 1) OR (@ViewAllProjects = 1 AND @Assistant = 1)
		SET @CanViewtimeEntries = 1
	ELSE
		SET @CanViewtimeEntries = 0
		
	SELECT
		@ProjectManagerEmployeeID = [Project].[ProjectManagerEmployeeID],
		@ProjectID = [Project].[ID],
		@TimeEntryProjectID = [TimeEntry].[ProjectID],
		@TimeEntryEmployeeID = [TimeEntry].[EmployeeID],
		@DocumentID = [TimeEntry].[DocumentID],
		@DocumentClass = [TimeEntry].[DocumentClass]
	FROM
		[TimeEntry]
		LEFT OUTER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
	WHERE
		[TimeEntry].[ID] = @ID

	IF NOT(@CanViewTimeEntries = 1
		OR @ProjectManagerEmployeeID = @EmployeeID
		OR dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 1
		OR (@TimeEntryProjectID IS NULL AND @TimeEntryEmployeeID = @EmployeeID)
		OR dbo.fnPjm7IsManagerAssistant(@ProjectID, @EmployeeID) = 1
		OR dbo.fnPjm7IsFinanceManager(@ProjectID, @EmployeeID) = 1)
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
		
	IF @Lang = 'en'
		BEGIN
			SELECT @DocumentClassName = [ClassGlobal].[Name]
			FROM [ClassGlobal]
			WHERE [ClassGlobal].[Class] = @DocumentClass AND [ClassGlobal].[Language] = @Lang
			
			IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
				SET @DocumentClassName = 'Service'
		END
	ELSE IF @Lang = 'ru'
		BEGIN
			SELECT @DocumentClassName = [Class].[Name]
			FROM [Class]
			WHERE [Class].[Class] = @DocumentClass

			IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
				SET @DocumentClassName = ''
		END
		
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
		SELECT @DocumentName = [ServiceAssignment].[FileAs] FROM [ServiceAssignment] WHERE [ServiceAssignment].[ID] = @DocumentID
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.Issue')
		SELECT @DocumentName = [Issue].[FileAs] FROM [Issue] WHERE [Issue].[ID] = @DocumentID
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
		SELECT @DocumentName = [ServiceRequest].[FileAs] FROM [ServiceRequest] WHERE [ServiceRequest].[ID] = @DocumentID
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.TaskRequest')
		SELECT @DocumentName = [TaskRequest].[FileAs] FROM [TaskRequest] WHERE [TaskRequest].[ID] = @DocumentID

	--   
	DECLARE
		@AppSyncCalendars	TBool,
		@ExcnangeSync		TBool,
		@UserSyncCalendars	TBool

	SET @ExcnangeSync = 0
	SET @UserSyncCalendars = 0
	EXEC adfParameterGet @Name='ExchangeSyncCalendars', @Group='Pjm6', @Value = @value OUTPUT
	SET @AppSyncCalendars = CAST(@value as bit)
	
		
	IF @AppSyncCalendars = 1
	BEGIN
		DECLARE
			@TimeEntryUserID	TIdentifier

		SELECT @TimeEntryUserID = [UserID] FROM [Employee] WHERE [ID] = @TimeEntryEmployeeID 	

		SELECT @value = [Value] FROM [UserParameter] WHERE [Name] = 'SyncExchangeCalendar' AND [UserID] = @TimeEntryUserID
		SET @UserSyncCalendars = ISNULL(CAST(@value AS BIT), 0)

		IF EXISTS(SELECT *FROM [ExchangeDocumentSync] WHERE [DocumentClass] = @TimeEntryClass AND
			[DocumentID] = @ID AND [UserID] = @TimeEntryUserID) AND @UserSyncCalendars = 1
			SET @ExcnangeSync = 1
	END
	
	SELECT @RecurrencePatternID = [RecurrencePatternID] 
	FROM   [Document] 
    WHERE 
		[Document].[Class] = @TimeEntryClass AND 
		[Document].[ID]    = @ID

	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[ProjectID],
		[Class].[Code] as [DocumentClass],
		[TimeEntry].[DocumentID],
		[TimeEntry].[TaskID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		[TimeEntry].[BillableHour] * 60 AS [BillableDuration],
		[TimeEntry].[BillableHour],
		[TimeEntry].[Overtime],
		[TimeEntry].[Rate],
		CASE WHEN [TimeEntry].[DocumentClass] = @ServiceAssignmentClass 
		THEN dbo.fnPjm5GetEmployeeRate([TimeEntry].[EmployeeID], [TimeEntry].[ProjectID], 0, [TimeEntry].[DocumentID], 1) 
		ELSE dbo.fnPjm5GetEmployeeRate([TimeEntry].[EmployeeID], [TimeEntry].[ProjectID], 0, NULL, 1)
		END as [StandardRate],
		CASE WHEN [TimeEntry].[DocumentClass] = @ServiceAssignmentClass 
		THEN dbo.fnPjm5GetEmployeeRate([TimeEntry].[EmployeeID], [TimeEntry].[ProjectID], 1, [TimeEntry].[DocumentID], 1) 
		ELSE dbo.fnPjm5GetEmployeeRate([TimeEntry].[EmployeeID], [TimeEntry].[ProjectID], 1, NULL, 1)
		END as [OvertimeRate],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		[Project].[RatesWithVAT],
		@RecurrencePatternID AS [RecurrencePatternID],
		ISNULL([UserReminder].[State], CAST(0 as int)) AS [ReminderState],
		ISNULL([UserReminder].[OriginalInterval], dbo.fnPjm5GetReminderInterval([TimeEntry].[Class], 'ES', @UserID)) AS [ReminderInterval],
		[TimeEntry].[MeetingRequestID],
		[TaskAssignment].[RemainingWork],
		[TaskAssignment].[RemainingOvertimeWork],
		1 AS [CanViewTimeEntries],
		@DocumentName AS [DocumentName],
		@DocumentClassName AS [DocumentClassName],
		@ExcnangeSync AS [ExchangeSync],
		@UserSyncCalendars & dbo.fnPjm5AllowCreateProjectEntry([TimeEntry].[ProjectID], @TimeEntryEmployeeID) AS [ExchangeSyncCalendar],
		[exch].[ExchangeLink].[SyncTime] AS [ExchangeLastSyncDate],
		[EntryAmount].[Modified] AS [BillableModified],
		[EntryAmount].[ModifiedBy] AS [BillableModifiedBy],
		[EntryAmount].[ModifiedInFinance] AS [BillableModifiedInFinance],
		[EntryAmount].[ModifiedByInFinance] AS [BillableModifiedByInFinance]
	FROM
		[vwTimeEntry] AS [TimeEntry]
		LEFT OUTER JOIN [Class]
			ON [Class].[Class] = [TimeEntry].[DocumentClass]
		LEFT OUTER JOIN [Project]
			ON ([Project].[ID] = [TimeEntry].[ProjectID])
		LEFT OUTER JOIN [Reminder]
			ON ([Reminder].[DocumentClass] = [TimeEntry].[Class] AND
				[Reminder].[DocumentID] = [TimeEntry].[ID] AND
				[Reminder].[Subtype] = 'ES')
		LEFT OUTER JOIN [UserReminder]
			ON ([Reminder].[ID] = [UserReminder].[ReminderID] AND
				[UserReminder].[UserID] = @UserID)
		LEFT OUTER JOIN [Task]
			ON [Task].[ID] = [TimeEntry].[TaskID]
		LEFT OUTER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [Task].[ID] AND
			   [TaskAssignment].[AssignmentID] = [TimeEntry].[AssignmentID]
		LEFT OUTER JOIN [exch].[ExchangeLink]
			ON [exch].[ExchangeLink].[DocumentClass] = [TimeEntry].[Class] AND
				[exch].[ExchangeLink].[DocumentID] = [TimeEntry].[ID] AND
				[exch].[ExchangeLink].[UserID] = @UserID
		INNER JOIN [EntryAmount]
			ON [TimeEntry].[ID] = [EntryAmount].[ID]
	WHERE
		[TimeEntry].[ID] = @ID

	IF @@ROWCOUNT = 0
		RETURN 1
		
	SELECT
		[RecurrencePattern].[ID],
		[RecurrencePattern].[StartDate],
		[RecurrencePattern].[EndDate],
		[RecurrencePattern].[Occurrences],
		[RecurrencePattern].[RecurrenceType],
		[RecurrencePattern].[Interval],
		[RecurrencePattern].[DayOfWeekMask],
		[RecurrencePattern].[Instance],
		[RecurrencePattern].[MonthOfYear],
		[RecurrencePattern].[DayOfMonth]
	FROM
		[RecurrencePattern]
	WHERE
		[RecurrencePattern].[ID] = @RecurrencePatternID

	RETURN 0
GO

GRANT EXECUTE ON [pjm6TimeEntryGet] TO PUBLIC
GO

 
