IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTimeEntryForTfaCreate')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTimeEntryForTfaCreate'
		DROP  Trigger pjm6trTimeEntryForTfaCreate
	END
GO

/******************************************************************************
**		File:	pjm6trTimeEntryForTfaCreate.sql
**		Name:	pjm6trTimeEntryForTfaCreate
**		Desc:	    
**				     
**
**		This template can be customized:
**              
**
**		Auth: pavel.svintsov
**		Date: 02.06.2009
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		02.06.09	SPV					 
**		22.10.10	SYV					  "Object Deleted?"
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTimeEntryForTfaCreate'
GO
CREATE TRIGGER pjm6trTimeEntryForTfaCreate 
ON [TimeEntry] FOR INSERT
AS
BEGIN
    IF @@rowcount = 0
       RETURN
	SET NOCOUNT ON

	DECLARE
		@ServiceRequestClass TClass,
		@TaskRequestClass TClass,
		@IssueClass TClass,
		@ServiceAssignmentClass TClass,
		@Invalid int

	SET @ServiceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET @TaskRequestClass = dbo.adfGetClassByName('Pjm5.TaskRequest')
	SET @IssueClass = dbo.adfGetClassByName('Pjm5.Issue')
	SET @ServiceAssignmentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	SET @invalid = 0

	DECLARE @forAdd TABLE
	(
		[ID] TIdentifier,
		[DocumentClass] TClass,
		[DocumentID] TIdentifier,
		[Duration] TCount,
		[Cost] TMoney
	)

	INSERT INTO @forAdd
	([ID], [DocumentClass], [DocumentId], [Duration], [Cost])
	SELECT
		[inserted].[ID],
		[inserted].[DocumentClass],
		[inserted].[DocumentID],
		[inserted].[Duration],
		(CASE WHEN [inserted].[Billable] = 1 THEN [inserted].[Duration] * [inserted].[Rate] / 60 ELSE 0 END)
	FROM
		[inserted]
	WHERE
	(	
		[inserted].[State] in (2, 3, 6)
	) AND
	(
		[inserted].[DocumentClass] in (@TaskRequestClass, @ServiceRequestClass, @IssueClass, @ServiceAssignmentClass)
	)

	------------------------- Task Request ----------------------
	SELECT @invalid = count(*)
	FROM
		[TaskRequest]
		INNER JOIN [inserted] AS [Add]
			ON [TaskRequest].[ID] = [Add].[DocumentID] AND
				[TaskRequest].[Class] = [Add].[DocumentClass] AND
				[TaskRequest].[State] not in (2)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	ELSE
		BEGIN
			UPDATE [TaskRequest]
			SET
				[TaskRequest].[ActualManHour] = [TaskRequest].[ActualManHour] + [Add].[Duration],
				[TaskRequest].[ActualBudget] = [TaskRequest].[ActualBudget] + [Add].[Cost]
			FROM
				[TaskRequest]
				INNER JOIN @ForAdd AS [Add]
					ON [TaskRequest].[ID] = [Add].[DocumentID] AND
						[TaskRequest].[Class] = [Add].[DocumentClass]
				IF @@error != 0
					BEGIN
						ROLLBACK TRANSACTION
						RETURN
					END
		END

	---------------------- Service Request ------------------------------
	SELECT @invalid = count(*)
	FROM
		[ServiceRequest]
		INNER JOIN [inserted] AS [Add]
			ON [ServiceRequest].[ID] = [Add].[DocumentID] AND
				[ServiceRequest].[Class] = [Add].[DocumentClass] AND
				[ServiceRequest].[State] not in (2, 3)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
		BEGIN
			RAISERROR('#tfaCreateInvalidJobState', 18, -1)
			ROLLBACK TRANSACTION
		END
		ELSE
		BEGIN
			UPDATE [ServiceRequest]
			SET
				[ServiceRequest].[ActualManHour] = [ServiceRequest].[ActualManHour] + [Add].[Duration],
				[ServiceRequest].[ActualBudget] = [ServiceRequest].[ActualBudget] + [Add].[Cost]
			FROM
				[ServiceRequest]
				INNER JOIN @ForAdd AS [Add]
					ON [ServiceRequest].[ID] = [Add].[DocumentID] AND
						[ServiceRequest].[Class] = [Add].[DocumentClass]
				IF @@error != 0
					BEGIN
						ROLLBACK TRANSACTION
						RETURN
					END
		END
	------------------------- Issue ----------------------
	SELECT @invalid = count(*)
	FROM
		[Issue]
		INNER JOIN [inserted] AS [Add]
			ON [Issue].[ID] = [Add].[DocumentID] AND
				[Issue].[Class] = [Add].[DocumentClass] AND
				[Issue].[State] not in (2, 3, 4, 6)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	ELSE
	BEGIN
		UPDATE [Issue]
		SET
			[Issue].[ActualManHour] = ISNULL([Issue].[ActualManHour], 0) + [Add].[Duration],
			[Issue].[ActualBudget] = ISNULL([Issue].[ActualBudget], 0) + [Add].[Cost]
		FROM
			[Issue]
			INNER JOIN @ForAdd AS [Add]
				ON [Issue].[ID] = [Add].[DocumentID] AND
					[Issue].[Class] = [Add].[DocumentClass]
			IF @@error != 0
				BEGIN
					ROLLBACK TRANSACTION
					RETURN
				END
	END
	---------------------- Service Assignment ------------------------------
	SELECT @invalid = count(*)
	FROM
		[ServiceAssignment]
		INNER JOIN [inserted] AS [Add]
			ON [ServiceAssignment].[ID] = [Add].[DocumentID] AND
				[ServiceAssignment].[Class] = [Add].[DocumentClass] AND
				[ServiceAssignment].[State] not in (1)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	ELSE
	BEGIN
		UPDATE [ServiceAssignment]
		SET
			[ServiceAssignment].[ActualManHour] = [ServiceAssignment].[ActualManHour] + [Add].[Duration],
			[ServiceAssignment].[ActualBudget] = [ServiceAssignment].[ActualBudget] + [Add].[Cost]
		FROM
			[ServiceAssignment]
			INNER JOIN @ForAdd AS [Add]
				ON [ServiceAssignment].[ID] = [Add].[DocumentID] AND
					[ServiceAssignment].[Class] = [Add].[DocumentClass]
			IF @@error != 0
				BEGIN
					ROLLBACK TRANSACTION
					RETURN
				END
	END
END
GO
